@@ -1,5 +1,5 @@
 /* The main program of the curses interface to Xconq.
-   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -10,6 +10,8 @@ any later version.  See the file COPYING.  */
 extern void auto_pick_new_research(Unit *unit);
 extern int auto_pick_new_build_task(Unit *unit);
 extern void auto_pick_new_plan(Unit *unit);
+void unit_research_dialog(Unit *unit);
+void side_research_dialog(Side *side, Unit *unit, int s);
 #include "kpublic.h"
 #include "cmdline.h"
 #include "cconq.h"
@@ -634,8 +636,7 @@ Unit *unit, *unit2;
 }
 
 void
-move_survey(nx, ny)
-int nx, ny;
+move_survey(int nx, int ny)
 {
     if (inside_area(nx, ny)) {
 	make_current_at(nx, ny);
@@ -648,8 +649,7 @@ int nx, ny;
 /* Ensure that given location is visible. */
 
 void
-put_on_screen(x, y)
-int x, y;
+put_on_screen(int x, int y)
 {
     if (!in_middle(x, y)) {
 	set_view_focus(mvp, x, y);
@@ -664,9 +664,7 @@ int x, y;
 /* Prompt for a yes/no answer with a settable default. */
 
 int
-ask_bool(question, dflt)
-char *question;
-int dflt;
+ask_bool(char *question, int dflt)
 {
     char ch;
 
@@ -688,9 +686,7 @@ int dflt;
    vector of unit types, so as to be able to map back when done. */
 
 int
-ask_unit_type(prompt, possibles)
-char *prompt;
-short *possibles;
+ask_unit_type(char *prompt, short *possibles)
 {
     char ch;
     int numtypes = 0, u;
@@ -699,8 +695,8 @@ short *possibles;
 	bvec[u] = 0;
 	if (possibles == NULL || possibles[u]) {
 	    bvec[u] = 1;
-	    ustr[numtypes] = utype_name_n(u, 1)[0];
 	    uvec[numtypes] = u;
+	    ustr[numtypes] = unitchars[u];
 	    numtypes++;
 	}
     }
@@ -736,9 +732,7 @@ short *possibles;
    when done. */
 
 int
-ask_terrain_type(prompt, possibles)
-char *prompt;
-short *possibles;
+ask_terrain_type(char *prompt, short *possibles)
 {
     char ch;
     int numtypes = 0, t, type;
@@ -747,9 +741,8 @@ short *possibles;
 	bvec[t] = 0;
 	if (possibles == NULL || possibles[t]) {
 	    bvec[t] = 1;
-	    ustr[numtypes]
-	      = (t_char(t) ? t_char(t)[0] : t_type_name(t)[0]);
 	    uvec[numtypes] = t;
+	    ustr[numtypes] = terrchars[t];
 	    numtypes++;
 	}
     }
@@ -780,9 +773,7 @@ short *possibles;
 /* Ask for a direction. */
 
 int
-ask_direction(prompt, dirp)
-char *prompt;
-int *dirp;
+ask_direction(char *prompt, int *dirp)
 {
     char ch;
 
@@ -818,9 +809,7 @@ int *dirp;
    '.' designates the final position. */
 
 int
-ask_position(prompt, xp, yp)
-char *prompt;
-int *xp, *yp;
+ask_position(char *prompt, int *xp, int *yp)
 {
     char ch;
     int dir, nx, ny;
@@ -1577,6 +1566,18 @@ global_advance_dialog(Side *side, Unit *unit, int s)
     auto_pick_new_research(unit);
 }
 
+void
+unit_research_dialog(Unit *unit)
+{
+    auto_pick_new_research(unit);
+}
+
+void
+side_research_dialog(Side *side, Unit *unit, int s)
+{
+    auto_pick_new_research(unit);
+}
+
 int
 unit_build_dialog(Unit *unit)
 {
