@@ -1,5 +1,5 @@
 /* Implementations of Xconq actions.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@ extern int type_can_sit_on_conn(int u, int x, int y);
 #include "kpublic.h"
 
 static int check_create_common(Unit *unit, Unit *unit2, int u3,
-					int x, int y);
+			       int x, int y);
 static void set_created_unit_props(Unit *unit, int u2, Side *side,
-					    int u2mor);
+				   int u2mor);
 static int give_away(Unit *unit, int m, int amt);
 static void notify_action(Unit *unit, Action *action);
 static void play_action_movies(Unit *unit, Action *action);
@@ -716,9 +716,7 @@ int u2, oldtp, newtp;
 /* This action creates the (incomplete) unit. */
 
 int
-prep_create_in_action(unit, unit2, u3, dest)
-Unit *unit, *unit2, *dest;
-int u3;
+prep_create_in_action(Unit *unit, Unit *unit2, int u3, Unit *dest)
 {
     if (unit == NULL || unit->act == NULL || unit2 == NULL || dest == NULL)
       return FALSE;
@@ -730,9 +728,7 @@ int u3;
 }
 
 int
-net_prep_create_in_action(unit, unit2, u3, dest)
-Unit *unit, *unit2, *dest;
-int u3;
+net_prep_create_in_action(Unit *unit, Unit *unit2, int u3, Unit *dest)
 {
     int rslt;
 
@@ -742,9 +738,7 @@ int u3;
 }
 
 int
-do_create_in_action(unit, unit2, u3, dest)
-Unit *unit, *unit2, *dest;
-int u3;
+do_create_in_action(Unit *unit, Unit *unit2, int u3, Unit *dest)
 {
     int u2 = unit2->type, m, consum, consum2;
     Unit *newunit;
@@ -752,9 +746,21 @@ int u3;
     /* Doublecheck that the new unit is still allowed. */
 
     /* has_advance_to_build no longer included by type_allowed_on_side. */
+    /* (why not in check routine only?) */
     if (!new_unit_allowed_on_side(u3, unit->side)
 	|| !has_advance_to_build(unit->side, u3))
       return A_ANY_ERROR;
+    if (u_advanced(u3)) {
+	Unit *oldunit = unit_at(unit2->x, unit2->y);
+	if (oldunit->type == u3) {
+	    /* (should test that this kind of joining is allowed) */
+	    oldunit->size += 1;
+	    update_unit_display(oldunit->side, oldunit, TRUE);
+	    garrison_unit(unit2, oldunit);
+	    use_up_acp(unit, uu_acp_to_create(u2, u3));
+	    return A_ANY_DONE;
+	}
+    }
     /* Make the new unit. */
     newunit = create_unit(u3, FALSE);
     if (newunit != NULL) {
@@ -808,9 +814,7 @@ int u3;
 }
 
 int
-check_create_in_action(unit, unit2, u3, dest)
-Unit *unit, *unit2, *dest;
-int u3;
+check_create_in_action(Unit *unit, Unit *unit2, int u3, Unit *dest)
 {
     int rslt;
 
@@ -819,6 +823,11 @@ int u3;
     rslt = check_create_common(unit, unit2, u3, dest->x, dest->y);
     if (rslt != A_ANY_OK)
       return rslt;
+    if (u_advanced(u3)) {
+	Unit *oldunit = unit_at(unit2->x, unit2->y);
+	if (oldunit->type == u3)
+	  return A_ANY_OK;
+    }
     if (!type_can_occupy(u3, dest))
       return A_ANY_ERROR;
     return A_ANY_OK;
@@ -827,9 +836,7 @@ int u3;
 /* Test for the constraints common to create-in and create-at. */
 
 static int
-check_create_common(unit, unit2, u3, x, y)
-Unit *unit, *unit2;
-int u3;
+check_create_common(Unit *unit, Unit *unit2, int u3, int x, int y)
 {
     int u, u2, m, tp, totsup;
 
@@ -844,8 +851,8 @@ int u3;
       return A_ANY_CANNOT_DO;
     if (!can_have_enough_acp(unit, uu_acp_to_create(u2, u3)))
       return A_ANY_CANNOT_DO;
-   /* No longer included in type_allowed_on_side. */
-   if (!has_advance_to_build(unit->side, u3))
+    /* No longer included in type_allowed_on_side. */
+    if (!has_advance_to_build(unit->side, u3))
       return A_ANY_CANNOT_DO;
     /* Don't permit the creation of units that are not allowed on this
        side. */
@@ -886,10 +893,7 @@ int u3;
 }
 
 static void
-set_created_unit_props(newunit, u2, side, u2mor)
-Unit *newunit;
-int u2, u2mor;
-Side *side;
+set_created_unit_props(Unit *newunit, int u2, Side *side, int u2mor)
 {
     int u3 = newunit->type, m, amt, mfrac, mor;
 
@@ -934,9 +938,7 @@ Side *side;
 /* Create a new unit of a given type, out in the open at a given location. */
 
 int
-prep_create_at_action(unit, unit2, u3, x, y, z)
-Unit *unit, *unit2;
-int u3, x, y, z;
+prep_create_at_action(Unit *unit, Unit *unit2, int u3, int x, int y, int z)
 {
     if (unit == NULL || unit->act == NULL || unit2 == NULL)
       return FALSE;
@@ -950,9 +952,7 @@ int u3, x, y, z;
 }
 
 int
-net_prep_create_at_action(unit, unit2, u3, x, y, z)
-Unit *unit, *unit2;
-int u3, x, y, z;
+net_prep_create_at_action(Unit *unit, Unit *unit2, int u3, int x, int y, int z)
 {
     int rslt;
 
@@ -962,9 +962,7 @@ int u3, x, y, z;
 }
 
 int
-do_create_at_action(unit, unit2, u3, x, y, z)
-Unit *unit, *unit2;
-int u3, x, y, z;
+do_create_at_action(Unit *unit, Unit *unit2, int u3, int x, int y, int z)
 {
     int u2 = unit2->type, m, consum, consum2;
     Unit *newunit;
@@ -1039,9 +1037,7 @@ int u3, x, y, z;
 }
 
 int
-check_create_at_action(unit, unit2, u3, x, y, z)
-Unit *unit, *unit2;
-int u3, x, y, z;
+check_create_at_action(Unit *unit, Unit *unit2, int u3, int x, int y, int z)
 {
     int rslt, t;
 
