@@ -37,23 +37,23 @@ init_ai_types(void)
     all_ai_ops[2] = &iplayer_ops;
 }
 
+/* Given an AI type name, return the next name in the list of types,
+   or NULL if the name is the last in the list. */
+
 char *
 next_ai_type(char *typename)
 {
-  int i;
-  char *name;
+    int i;
+    char *name;
 
-  if (typename == NULL)
-    return all_ai_ops[1]->name;
-  for (i = 1; i < numaitypes; ++i) {
-    name = (all_ai_ops[i])->name;
-    if (strcmp(name, typename) == 0) {
-      if (i == (numaitypes - 1))
-	return NULL;
-      else
-	return (all_ai_ops[i+1])->name;
+    if (typename == NULL)
+      return all_ai_ops[1]->name;
+    for (i = 1; i < numaitypes - 1; ++i) {
+	name = (all_ai_ops[i])->name;
+	if (strcmp(name, typename) == 0)
+	  return (all_ai_ops[i+1])->name;
     }
-  }
+    return NULL;
 }
 
 /* Given a side that wants to have an AI running its units, find and
@@ -108,6 +108,7 @@ void
 set_side_ai(Side *side, char *typename)
 {
     Unit *unit;
+    extern int num_local_ais;
 
     if (!empty_string(typename) && strcmp(typename, "ai") == 0) {
 	/* (should use the "best" default for this game and side) */
@@ -147,6 +148,7 @@ set_side_ai(Side *side, char *typename)
 	    unit->autobuild = TRUE;
 	}
     }
+    num_local_ais = -1;
 }
 
 /* The following functions dispatch on AI type. */
