@@ -13,8 +13,6 @@ any later version.  See the file COPYING.  */
 int autofinish_start;
 int autofinish_count;
 
-extern int has_advance_to_research(Side *side, int a);
-
 static int parse_advance_spec(char *str);
 
 /* The command table is an array of all the commands. */
@@ -318,21 +316,26 @@ do_ai_side(Side *side)
 	    rest = get_next_arg(rest, tmpbuf, &arg);
 	}
 	aitypename = arg;
-	}
+    }
     if (empty_string(aitypename)) {
     	/* Toggle AI between mplayer, iplayer and NULL. */
     	if (side->player->aitypename == NULL) {
-	      net_set_side_ai(side, "mplayer");
-		} else if (strcmp(side->player->aitypename, "mplayer") == 0) {   	    
-	      net_set_side_ai(side, "iplayer");
-		} else {
-	      net_set_side_ai(side, NULL);
+	    net_set_side_ai(side, "mplayer");
+	} else if (strcmp(side->player->aitypename, "mplayer") == 0) {
+	    net_set_side_ai(side, "iplayer");
+	} else {
+	    net_set_side_ai(side, NULL);
     	}
+    } else if (strcmp(aitypename, "none") == 0) {
 	/* Special case to handle command "AI None" in Side menu. */
-	} else if (strcmp(aitypename, "none") == 0) {
-		net_set_side_ai(side, NULL);
+	net_set_side_ai(side, NULL);
     } else {
-		net_set_side_ai(side, aitypename);
+	net_set_side_ai(side, aitypename);
+    }
+    if (!empty_string(side->player->aitypename)) {
+	notify(side, "AI %s is running this side.", side->player->aitypename);
+    } else {
+	notify(side, "No AI is running this side.");
     }
 }
 
