@@ -1,13 +1,13 @@
 /* Command line parsing for Xconq.
-   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
-/* This is a command-line parser that may be used in implementations that
-   get a command line from somewhere. */
+/* This is a command-line parser that may be used in implementations
+   that get a command line from somewhere. */
 
 /* Command lines get parsed in several stages, since for instance the
    choice of game module will decide which variants are available. */
@@ -15,6 +15,7 @@ any later version.  See the file COPYING.  */
 #include "conq.h"
 extern short initially_no_ai;
 #include "cmdline.h"
+extern void make_default_player_spec(void);
 
 static void version_info(void);
 static void general_usage_info(void);
@@ -46,6 +47,10 @@ static char *default_ai_type = ",mplayer";
 
 static int game_chosen = FALSE;
 
+/* Use this to record the options used to set up a game, so it can be
+   reported to users. */
+/* (should flush? only useful for multi-X-display case) */
+
 char *args_used;
 
 /* The list of asked-for players. */
@@ -55,11 +60,11 @@ struct raw_spec {
   struct raw_spec *next;
 } *raw_player_specs, *last_raw_player_spec;
 
-static char *raw_default_player_spec;
+char *raw_default_player_spec;
 
 char *default_player_spec;
 
-/* The list of modules to loaded in addition to the main one. */
+/* The list of modules to be loaded in addition to the main one. */
 
 struct module_spec {
   Module *module;
@@ -74,7 +79,7 @@ struct gdl_spec {
 } *pre_gdl_specs, *last_pre_gdl_spec, *post_gdl_specs, *last_post_gdl_spec;
 
 static void add_a_gdl_spec(char *specstr, struct gdl_spec **first,
-				    struct gdl_spec **last);
+			   struct gdl_spec **last);
 
 /* The list of accumulated variant choices. */
 
@@ -90,33 +95,34 @@ static int version_wanted = FALSE;
 
 static int had_error = FALSE;
 
-/* Set the most basic of defaults on the dynamically-settable options. */
+/* Set the most basic of defaults on the dynamically-settable
+   options. */
 
-/* (need flags to indicate which options were actually used, so variant
-   handling can warn about improper use) */
+/* (need flags to indicate which options were actually used, so
+   variant handling can warn about improper use) */
 
 void
-init_options()
+init_options(void)
 {
     option_add_default_player = TRUE;
     variant_settings = lispnil;
 }
 
-/* Generic command line parsing.  This is used by several different programs,
-   so it just collects info, doesn't process it much.  This is called
-   several times, because the validity of some args depends on which
-   game modules are loaded and which players are to be in the game,
-   and interfaces may need to do some of their own processing in between. */
+/* Generic command line parsing.  This is used by several different
+   programs, so it just collects info, doesn't process it much.  This
+   is called several times, because the validity of some args depends
+   on which game modules are loaded and which players are to be in the
+   game, and interfaces may need to do some of their own processing in
+   between. */
 
 void
-parse_command_line(argc, argv, spec)
-int argc, spec;
-char *argv[];
+parse_command_line(int argc, char *argv[], int spec)
 {
     char *arg, *aispec, tmpspec[100];
     int i, n, numused, total_arg_space;
 
-/* This macro just checks that a required next argument is actually there. */
+/* This macro just checks that a required next argument is actually
+   there. */
 
 #define REQUIRE_ONE_ARG  \
   if (i + 1 >= argc) {  \
@@ -126,8 +132,8 @@ char *argv[];
   }  \
   numused = 2;
 
-/* Each of these causes argument parsing to skip over the option if it's
-   not the right time to look at it. */
+/* Each of these causes argument parsing to skip over the option if
+   it's not the right time to look at it. */
 
 #define GENERAL_OPTION if (spec != general_options) continue;
 #define VARIANT_OPTION if (spec != variant_options) continue;
@@ -183,8 +189,8 @@ char *argv[];
 		REQUIRE_ONE_ARG;
 		PLAYER_OPTION;
 		n = atoi(argv[i+1]);
-		/* A comma indicates that the name of a particular desired
-		   AI type follows. */
+		/* A comma indicates that the name of a particular
+		   desired AI type follows. */
 		if (strlen(arg) > 2) {
 		    aispec = arg + 2;
 		    if (*aispec != ',') {
@@ -208,6 +214,7 @@ char *argv[];
 		REQUIRE_ONE_ARG;
 		PLAYER_OPTION;
 		n = atoi(argv[i+1]);
+		option_num_to_wait_for += n;
 		while (n-- > 0)
 		  add_a_raw_player_spec("x@");
 	    } else if (strcmp(arg, "-help") == 0) {
@@ -216,12 +223,14 @@ char *argv[];
 		/* Will display help info later. */
 	    } else if (strcmp(arg, "-host") == 0) {
 		REQUIRE_ONE_ARG;
-		PLAYER_OPTION;
+		GENERAL_OPTION;
 		option_game_to_host = copy_string(argv[i+1]);
+		fprintf(stderr, "-host is currently broken, use interactive setup for network games\n");
 	    } else if (strcmp(arg, "-join") == 0) {
 		REQUIRE_ONE_ARG;
 		GENERAL_OPTION;
 		option_game_to_join = copy_string(argv[i+1]);
+		fprintf(stderr, "-join is currently broken, use interactive setup for network games\n");
 	    } else if (strcmp(arg, "-L") == 0) {
 		REQUIRE_ONE_ARG;
 		GENERAL_OPTION;
@@ -334,13 +343,21 @@ char *argv[];
 	  load_all_modules();
 	if (had_error || help_wanted)
 	  general_usage_info();
-	if (had_error || help_wanted || variant_help_wanted)
-	  game_usage_info();
 	if (had_error || help_wanted)
 	  player_usage_info();
 	if (help_wanted && mainmodule != NULL) {
-	    /* (should display other random info about the game here) */
+	    printf("\nGame info:\n\n");
+	    if (!empty_string(mainmodule->title))
+	      printf("%s (%s)\n", mainmodule->title, mainmodule->name);
+	    else
+	      printf("%s\n", mainmodule->name);
+	    printf("    %s\n",
+		   (mainmodule->blurb ? mainmodule->blurb : "(no description)"));
 	}
+	/* Display variant info here so it comes after basic info
+	   about the game module. */
+	if (had_error || help_wanted || variant_help_wanted)
+	  game_usage_info();
     }
     if (had_error || help_wanted || variant_help_wanted || version_wanted) {
 	exit(had_error);
@@ -351,8 +368,7 @@ char *argv[];
    to load. */
 
 void
-add_a_module(name, filename)
-char *name, *filename;
+add_a_module(char *name, char *filename)
 {
     Module *module;
     struct module_spec *extra;
@@ -377,9 +393,11 @@ char *name, *filename;
     game_chosen = TRUE;
 }
 
+/* Glue an unprocessed player spec onto the list of other specs found
+   on the command line. */
+
 static void
-add_a_raw_player_spec(specstr)
-char *specstr;
+add_a_raw_player_spec(char *specstr)
 {
     struct raw_spec *spec =
       (struct raw_spec *) xmalloc (sizeof(struct raw_spec));
@@ -393,9 +411,8 @@ char *specstr;
 }
 
 static void
-add_a_gdl_spec(specstr, firstp, lastp)
-char *specstr;
-struct gdl_spec **firstp, **lastp;
+add_a_gdl_spec(char *specstr, struct gdl_spec **firstp,
+	       struct gdl_spec **lastp)
 {
     struct gdl_spec *spec =
       (struct gdl_spec *) xmalloc (sizeof(struct gdl_spec));
@@ -409,7 +426,7 @@ struct gdl_spec **firstp, **lastp;
 }
 
 static void
-version_info()
+version_info(void)
 {
     printf("Xconq (%s) version %s\n", program_name, version_string());
 }
@@ -417,7 +434,7 @@ version_info()
 /* This routine prints out help info about all the possible arguments. */
 
 static void
-general_usage_info()
+general_usage_info(void)
 {
     printf("Usage:\n\t%s [ -options ... ]\n\n", program_name);
     printf("General options:\n\n");
@@ -428,14 +445,17 @@ general_usage_info()
     printf("    -host <game@host>\thost the given game\n");
     printf("    -join <game@host>\tconnect to the given game\n");
     printf("    -L pathname\t\tset <pathname> to be library location\n");
-    printf("    -mail\t\tset up game as play-by-email\n");
     printf("    -w\t\t\tsuppress warnings\n");
+    printf("    -x\t\t\tuse game setup dialogs to choose game and options\n");
     printf("    -design\t\tmake every player a designer");
 #ifndef DESIGNERS
     printf(" (not available)");
 #endif
     printf("\n");
-    printf("Long options:\n");
+    /* We don't display the debugging options -D*, -pre, -post, and
+       -R, on the theory that only hackers should try to use them. */
+    /* Group the long options together, but don't identify them
+       specially. */
     printf("    --help\t\tdisplay this help info\n");
     printf("    --version\t\tdisplay version info\n");
 }
@@ -443,7 +463,7 @@ general_usage_info()
 /* Describe the available variants for a game. */
 
 static void
-game_usage_info()
+game_usage_info(void)
 {
     int i, wid, hgt, circumf, lat, lon, pergame, perside, perturn;
     char *varname = "?", *vartypename = NULL;
@@ -473,10 +493,10 @@ game_usage_info()
 		    (c_number(eval(vardflt)) ? "true" : "false")));
 	    break;
 	  case K_SEQUENTIAL:
-	    printf("    -seq\t\t\tmove sequentially (default %s)\n",
+	    printf("    -seq\t\tmove sequentially (default %s)\n",
 		   (vardflt == lispnil ? "false" :
 		    (c_number(eval(vardflt)) ? "false" : "true")));
-	    printf("    -sim\t\t\tmove simultaneously (default %s)\n",
+	    printf("    -sim\t\tmove simultaneously (default %s)\n",
 		   (vardflt == lispnil ? "true" :
 		    (c_number(eval(vardflt)) ? "true" : "false")));
 	    break;
@@ -565,8 +585,7 @@ game_usage_info()
    name in lowercase. */
 
 static void
-unixify_variant_name(buf, varname)
-char *buf, *varname;
+unixify_variant_name(char *buf, char *varname)
 {
     int i, slen;
 
@@ -580,8 +599,11 @@ char *buf, *varname;
     }
 }
 
+/* Dump info about player setup options.  These can only get used when
+   the game has been loaded and variants chosen. */
+
 static void
-player_usage_info()
+player_usage_info(void)
 {
     printf("\nPlayer setup options:\n\n");
     printf("    [[name][,ai][/config]@]host[+advantage]\tadd player\n");
@@ -591,17 +613,16 @@ player_usage_info()
     printf("        advantage\t= numerical initial advantage (default 1)\n");
     printf("    -e number[,ai]\tadd <number> computer players\n");
     printf("    -h number[,ai]\tadd <number> human players\n");
-    printf("    -noai\tsuppress all AIs\n");
+    printf("    -noai\t\tsuppress all AIs\n");
     printf("    -r\t\t\tno default player on local display\n");
-    printf("    -wait minutes\t\twait time for players to join\n");
+    /* (should available AI types here) */
 }
 
-/* Given a string representing world dimensions, extract various components
-   and compose a variant setting. */
+/* Given a string representing world dimensions, extract various
+   components and compose a variant setting. */
 
 static void
-parse_world_option(str)
-char *str;
+parse_world_option(char *str)
 {
     int width, height, circumference;
     char *str2;
@@ -630,8 +651,7 @@ char *str;
 }
 
 static void
-parse_realtime_option(subopt, arg)
-char *subopt, *arg;
+parse_realtime_option(char *subopt, char *arg)
 {
     if (strcmp(subopt, "-tgame") == 0) {
 	option_totalgametime = 60 * atoi(arg);
@@ -647,8 +667,7 @@ char *subopt, *arg;
 /* Given a variant, turn it into a list "(name val)". */
 
 static void
-parse_variant(str)
-char *str;
+parse_variant(char *str)
 {
     char *varname = NULL, *str2;
     Obj *varval = lispnil;
@@ -677,7 +696,7 @@ char *str;
 /* Load all the game modules that were asked for on cmd line. */
 
 void
-load_all_modules()
+load_all_modules(void)
 {
     struct module_spec *extra;
     struct gdl_spec *gdlspec;
@@ -706,7 +725,7 @@ load_all_modules()
 /* Set module variants from command line options. */
 
 void
-set_variants_from_options()
+set_variants_from_options(void)
 {
     Obj *varval;
 
@@ -732,7 +751,7 @@ set_variants_from_options()
 /* Set player characteristics from command-line options. */
 
 void
-set_players_from_options()
+set_players_from_options(void)
 {
     int mergespecs;
     Player *player;
@@ -740,30 +759,21 @@ set_players_from_options()
 
     /* Only the host of a networked game can set up players. */
     if (option_game_to_join != NULL) {
-	if (default_player_spec == NULL)
-	  default_player_spec = xmalloc(BUFSIZE);
-	default_player_spec[0] = '\0';
-	if (!empty_string(getenv("USER"))) {
-	    strcpy(default_player_spec, getenv("USER"));
-	    strcat(default_player_spec, "@");
-	}
-	if (!empty_string(raw_default_player_spec)
-	    && raw_default_player_spec[0] == '@') {
-	    strcat(default_player_spec, raw_default_player_spec);
-	} else if (!empty_string(getenv("DISPLAY"))) {
-	    strcat(default_player_spec, getenv("DISPLAY"));
-	}
+	make_default_player_spec();
 	return;
     }
     player = NULL;
     /* Assume that if any players exist already, then this is a restored
        game of some sort, and merge instead of adding new players. */
     mergespecs = (numplayers > 0);
+    /* Add a player for the indepside if none found. */
+    if (find_player(0) == NULL)
+      player = add_player();
+    /* If we're merging specs, skip over the indepside player. */
     if (mergespecs)
-      player = playerlist;
+      player = playerlist->next;
     /* Add the default player. */
     if (raw_player_specs == NULL || option_add_default_player) {
-	add_player(); /* indep */
 	if (!mergespecs)
 	  player = add_default_player();
 	parse_player_spec(player, raw_default_player_spec);
@@ -774,7 +784,7 @@ set_players_from_options()
     for (spec = raw_player_specs; spec != NULL; spec = spec->next) {
 	if (mergespecs) {
 	    if (player == NULL) {
-		fprintf(stderr, "Excess player spec \"%s\", ignoring\n",
+		fprintf(stderr, "Excess player spec `%s', ignoring\n",
 			spec->spec);
 		continue;
 	    }
@@ -799,7 +809,7 @@ set_players_from_options()
    useful. */
 
 void
-print_instructions()
+print_instructions(void)
 {
     Obj *instructions, *rest;
 
