@@ -415,15 +415,67 @@ one_attack(Unit *atker, Unit *defender)
     return (alive(atker) && unit_at(ox, oy) == NULL);
 }
 
+/* Implement "combat model 1", which emulates Civ-type games.  Combat
+   is multi-round, ending in the demise of one or the other combatant,
+   plus anything stacked with it. */
+
+int total_encounter_weights;
+
 static void
 model_1_attack(Unit *unit, int x, int y)
 {
-    int u = unit->type, u2, d, maxdef, def, att, winround, limit, dmg;
+    int u = unit->type, u2, u3, d, maxdef, def, att, winround, limit, dmg;
+    Obj *choice, *chtype, *chutype, *chside;
     Unit *unit2, *defender, *occ, *defocc, *victim;
     char *hitmovietype;
     Side *side3;
     SideMask sidemask;    
 
+    for_all_stack(x, y, unit2) {
+	u2 = unit2->type;
+	if (u_encounter_result(u2) != lispnil) {
+	    /* The encounter result overrides any other outcome. */
+	    choice = choose_from_weighted_list(u_encounter_result(u2),
+					       &total_encounter_weights,
+					       FALSE);
+	    if (consp(choice))
+	      chtype = car(choice);
+	    else
+	      chtype = choice;
+	    if (match_keyword(chtype, K_UNIT)) {
+		/* Dig out a unit type spec. */
+		chutype = cadr(choice);
+		if (consp(chutype)) {
+		    chside = cadr(chutype);
+		    chutype = car(chutype);
+		} else {
+		    chside = lispnil;
+		}
+		u3 = utype_from_name(c_string(chutype));
+		/* Change the unit's type. */
+		change_unit_type(unit2, u3, H_UNIT_TYPE_CHANGED);
+		unit2->hp = unit2->hp2 = u_hp(u3);
+		/* Pick out a side if one was specified. */
+		if (numberp(chside)) {
+		    side3 = side_n(c_number(chside));
+		} else {
+		    side3 = unit->side;
+		}
+		change_unit_side(unit2, side3, -1, unit);
+		/* The unit is changing side voluntarily, so set the
+		   original side also. */
+		unit2->origside = unit2->side;
+	    } else if (match_keyword(chtype, K_VANISH)) {
+		kill_unit(unit2, H_UNIT_VANISHED);
+	    } else {
+		run_warning("Unknown encounter type %s", c_string(chtype));
+	    }
+	    if (consp(choice) && stringp(caddr(choice))) {
+		notify(unit->side, "%s", c_string(caddr(choice)));
+	    }
+	    return;
+	}
+    }
     /* Non-combat units can't do anything. */
     if (u_attack(u) == 0)
       return;
@@ -445,6 +497,7 @@ model_1_attack(Unit *unit, int x, int y)
     /* If the location is empty for some reason, escape quietly. */
     if (defender == NULL)
       return;
+    /* For cities, find a defender. */
     if (u_advanced(defender->type)) {
 	maxdef = -1;
 	defocc = NULL;
@@ -488,14 +541,14 @@ model_1_attack(Unit *unit, int x, int y)
 	/* Make up the list of sides that will see it. */
 	sidemask = NOSIDES;
 	for_all_sides(side3) {
-	  /* Let all sides that can see the attacker's cell see it. */
-	  if (units_visible(side3, victim->x, victim->y))
-	    sidemask = add_side_to_set(side3, sidemask);
+	    /* Let all sides that can see the attacker's cell see it. */
+	    if (units_visible(side3, victim->x, victim->y))
+	      sidemask = add_side_to_set(side3, sidemask);
 	}
 	/* Show the movie. */
 	for_all_sides(side3) {
-	  if (side_in_set(side3, sidemask))
-	    schedule_movie(side3, hitmovietype, victim->id);
+	    if (side_in_set(side3, sidemask))
+	      schedule_movie(side3, hitmovietype, victim->id);
 	}
 	play_movies(ALLSIDES);
 	damage_unit(unit, combat_dmg, defender);
@@ -504,11 +557,21 @@ model_1_attack(Unit *unit, int x, int y)
     /* The whole stack dies if its defender dies. */
     if (!alive(defender) && defender->transport == NULL) {
 	for_all_stack(x, y, unit2) {
-	    /* (should except spies etc?) */
-	    unit2->hp2 = 0;
-	    report_combat(unit, unit2, "destroy");
+	    if (!u_advanced(unit2->type)) {
+		/* (should except spies etc?) */
+		unit2->hp2 = 0;
+		report_combat(unit, unit2, "destroy");
+	    }
 	}
 	reckon_damage_here(x, y);
+	/* But capture cities instead of destroying them. */
+	for_all_stack(x, y, unit2) {
+	    if (u_advanced(unit2->type)) {
+		attempt_to_capture_unit(unit, unit2);
+	    }
+	}
+	/* Occupants of city may be damaged. */
+	reckon_damage_here(x, y);
     }
 }
 
@@ -667,9 +730,7 @@ check_fire_at_action(Unit *unit, Unit *unit2, Unit *unit3, int m)
 /* Shooting at a given location. */
 
 int
-prep_fire_into_action(unit, unit2, x, y, z, m)
-Unit *unit, *unit2;
-int x, y, z, m;
+prep_fire_into_action(Unit *unit, Unit *unit2, int x, int y, int z, int m)
 {
     if (unit == NULL || unit->act == NULL || unit2 == NULL)
       return FALSE;
@@ -683,9 +744,7 @@ int x, y, z, m;
 }
 
 int
-net_prep_fire_into_action(unit, unit2, x, y, z, m)
-Unit *unit, *unit2;
-int x, y, z, m;
+net_prep_fire_into_action(Unit *unit, Unit *unit2, int x, int y, int z, int m)
 {
     int rslt;
 
@@ -699,9 +758,7 @@ int x, y, z, m;
    results might not be visible to the shooter. */
 
 int
-do_fire_into_action(unit, unit2, x, y, z, m)
-Unit *unit, *unit2;
-int x, y, z, m;
+do_fire_into_action(Unit *unit, Unit *unit2, int x, int y, int z, int m)
 {
     int ux = unit->x, uy = unit->y, ox, oy, oz;
     SideMask sidemask;
@@ -756,12 +813,13 @@ int x, y, z, m;
 /* Test a shoot action for plausibility. */
 
 int
-check_fire_into_action(unit, unit2, x, y, z, m)
-Unit *unit, *unit2;
-int x, y, z, m;
+check_fire_into_action(Unit *unit, Unit *unit2, int x, int y, int z, int m)
 {
     int u, u2, u2x, u2y, u2z, acp, dist, m2;
 
+    /* In combat model 1, we can't fire at anything. */
+    if (g_combat_model() == 1)
+      return A_ANY_ERROR;
     if (!in_play(unit))
       return A_ANY_ERROR;
     if (!in_play(unit2))
@@ -831,8 +889,8 @@ elevation_blocks(int x, int y)
 }
 
 int
-found_blocking_elevation(u, ux, uy, uz, u2, u2x, u2y, u2z)
-int u, ux, uy, uz, u2, u2x, u2y, u2z;
+found_blocking_elevation(int u, int ux, int uy, int uz,
+			 int u2, int u2x, int u2y, int u2z)
 {
     int t, weaponheight, bodyheight, rslt, x1, y1;
 
@@ -866,8 +924,7 @@ int u, ux, uy, uz, u2, u2x, u2y, u2z;
 }
  
 static void
-fire_on_unit(atker, other)
-Unit *atker, *other;
+fire_on_unit(Unit *atker, Unit *other)
 {
     int m, dist = distance(atker->x, atker->y, other->x, other->y), consump;
 
@@ -894,8 +951,7 @@ Unit *atker, *other;
    enough of *all* types - semi-bogus but too complicated otherwise?  */
 
 int
-enough_ammo(unit, other)
-Unit *unit, *other;
+enough_ammo(Unit *unit, Unit *other)
 {
     int m;
 
@@ -912,8 +968,7 @@ Unit *unit, *other;
    involved. */
 
 static void
-attack_unit(atker, other)
-Unit *atker, *other;
+attack_unit(Unit *atker, Unit *other)
 {
     int m;
 
@@ -995,27 +1050,24 @@ maybe_hit_unit(Unit *atker, Unit *other, int fire, int fallsoff)
        when triple-A protects all nearby units (including itself)
        against bombers, or when a city wall protects all other
        occupants against ground attack. */
-
     for_all_stack_with_occs(other->x, other->y, unit2) {
 	if (is_active(unit2)
 	    /* We also extend protection to our buddies! */
 	    && trusted_side(unit2->side, other->side)) {
-
-		/* This is when a unit, such as triple-A, extends
-		   unique protection against a specific attacker, such
-		   as bombers, to all other units in the cell. */
-		prot = uu_cellwide_protection_against(unit2->type, a);
-		if (prot != 100)
-		  chance = (chance * prot) / 100;
-
-		/* This is when a unit (such as a garrison)
-		   specifically protects a second unit, such as a fort
-		   (but not other nearby units), against all forms of
-		   attack. It thus works the same way as uu_protection
-		   and uu_stack_protection. */
-		prot = uu_cellwide_protection_for(unit2->type, o);	    
-		if (prot != 100)
-		  chance = (chance * prot) / 100;
+	    /* This is when a unit, such as triple-A, extends unique
+	       protection against a specific attacker, such as
+	       bombers, to all other units in the cell. */
+	    prot = uu_cellwide_protection_against(unit2->type, a);
+	    if (prot != 100)
+	      chance = (chance * prot) / 100;
+	    /* This is when a unit (such as a garrison) specifically
+	       protects a second unit, such as a fort (but not other
+	       nearby units), against all forms of attack. It thus
+	       works the same way as uu_protection and
+	       uu_stack_protection. */
+	    prot = uu_cellwide_protection_for(unit2->type, o);	    
+	    if (prot != 100)
+	      chance = (chance * prot) / 100;
 	}
     }
     if (fallsoff) {
@@ -1370,8 +1422,7 @@ rescue_one_occupant(Unit *occ)
    damage during combat. It bypasses some of the normal move rules. */
 
 static int
-retreat_unit(unit, atker)
-Unit *unit, *atker;
+retreat_unit(Unit *unit, Unit *atker)
 {
     int dir;
     extern int retreating_from;
@@ -1403,9 +1454,7 @@ Unit *unit, *atker;
 }
 
 static int
-retreat_in_dir(unit, dir)
-Unit *unit;
-int dir;
+retreat_in_dir(Unit *unit, int dir)
 {
     int nx, ny, rslt;
     Unit *other;
@@ -1441,8 +1490,7 @@ int dir;
 /* Prepare a capture action to be executed later. */
 
 int
-prep_capture_action(unit, unit2, unit3)
-Unit *unit, *unit2, *unit3;
+prep_capture_action(Unit *unit, Unit *unit2, Unit *unit3)
 {
     if (unit == NULL || unit->act == NULL || unit2 == NULL)
       return FALSE;
@@ -1453,8 +1501,7 @@ Unit *unit, *unit2, *unit3;
 }
 
 int
-net_prep_capture_action(unit, unit2, unit3)
-Unit *unit, *unit2, *unit3;
+net_prep_capture_action(Unit *unit, Unit *unit2, Unit *unit3)
 {
     int rslt;
 
@@ -1466,8 +1513,7 @@ Unit *unit, *unit2, *unit3;
 /* Execute a capture action. */
 
 int
-do_capture_action(unit, unit2, unit3)
-Unit *unit, *unit2, *unit3;
+do_capture_action(Unit *unit, Unit *unit2, Unit *unit3)
 {
     int rslt;
 
@@ -1483,11 +1529,13 @@ Unit *unit, *unit2, *unit3;
 /* Check the validity of a capture action. */
 
 int
-check_capture_action(unit, unit2, unit3)
-Unit *unit, *unit2, *unit3;
+check_capture_action(Unit *unit, Unit *unit2, Unit *unit3)
 {
     int u, u2, u3, acp, m;
 
+    /* In combat model 1, we can't capture units directly. */
+    if (g_combat_model() == 1)
+      return A_ANY_ERROR;
     if (!in_play(unit))
       return A_ANY_ERROR;
     if (!in_play(unit2))
@@ -1533,8 +1581,7 @@ Unit *unit, *unit2, *unit3;
    success == death.) */
 
 static void
-attempt_to_capture_unit(atker, other)
-Unit *atker, *other;
+attempt_to_capture_unit(Unit *atker, Unit *other)
 {
     int a = atker->type, o = other->type, chance, prot;
     int ox = other->x, oy = other->y;
@@ -1580,26 +1627,25 @@ Unit *atker, *other;
 		  chance = (chance * prot) / 100;
 	    }
 	}
-    /* Note that this code differs from that above in that it treats
-       all units in the same cell equally, whether occs, suboccs or
-       part of the stack. This also means that one occ can protect
-       another occ in the same transport. Moreover, the protective
-       unit also protects itself. These rules simulate real situations
-       such as when triple-A protects all nearby units (including
-       itself) against bombers, or when a city wall protects all other
-       occupants against ground attack. */
-
-    for_all_stack_with_occs(other->x, other->y, unit2) {
-	if (is_active(unit2)
-	    /* We also extend protection to our buddies! */
-	    && trusted_side(unit2->side, other->side)) {
-
+	/* Note that this code differs from that above in that it
+	   treats all units in the same cell equally, whether occs,
+	   suboccs or part of the stack. This also means that one occ
+	   can protect another occ in the same transport. Moreover,
+	   the protective unit also protects itself. These rules
+	   simulate real situations such as when triple-A protects all
+	   nearby units (including itself) against bombers, or when a
+	   city wall protects all other occupants against ground
+	   attack. */
+	for_all_stack_with_occs(other->x, other->y, unit2) {
+	    if (is_active(unit2)
+		/* We also extend protection to our buddies! */
+		&& trusted_side(unit2->side, other->side)) {
 		/* This is when a unit, such as triple-A, provides
 		   unique protection against a specific attacker, such
 		   as bombers, to all other units in the cell. */
 		prot = uu_cellwide_protection_against(unit2->type, a);
 		if (prot != 100)
-			chance = (chance * prot) / 100;
+		  chance = (chance * prot) / 100;
 
 		/* This is when a unit (such as a garrison)
 		   specifically protects a second unit, such as a fort
@@ -1608,9 +1654,9 @@ Unit *atker, *other;
 		   and uu_stack_protection. */
 		prot = uu_cellwide_protection_for(unit2->type, o);	    
 		if (prot != 100)
-			chance = (chance * prot) / 100;
+		  chance = (chance * prot) / 100;
+	    }
 	}
-    }
 	/* Test whether the capture actually happens. */
 	if (probability(chance)) {
 	    capture_unit(atker, other, H_UNIT_CAPTURED);
@@ -1636,9 +1682,7 @@ Unit *atker, *other;
 }
 
 int
-capture_chance(u, u2, side2)
-int u, u2;
-Side *side2;
+capture_chance(int u, int u2, Side *side2)
 {
     int chance, indepchance;
 
@@ -1652,9 +1696,7 @@ Side *side2;
 /* There are many consequences of a unit being captured. */
 
 void
-capture_unit(unit, pris, captype)
-Unit *unit, *pris;
-int captype;
+capture_unit(Unit *unit, Unit *pris, int captype)
 {
     int u = unit->type, px = pris->x, py = pris->y;
     Unit *occ;
@@ -1712,9 +1754,7 @@ int captype;
    will do. */
 
 static void
-capture_occupant(unit, pris, occ, newside)
-Unit *unit, *pris, *occ;
-Side *newside;
+capture_occupant(Unit *unit, Unit *pris, Unit *occ, Side *newside)
 {
     int u = unit->type;
     Unit *subocc;
@@ -2016,6 +2056,8 @@ hit_unit_with_detonation(Unit *unit, int hit, Unit *atker)
     }
 }
 
+/* Do the effect of detonation on the terrain at the given location. */
+
 void
 damage_terrain(int u, int x, int y)
 {
@@ -2040,8 +2082,8 @@ damage_terrain(int u, int x, int y)
 		/* We already did this one. */
 	        break;
 	      case bordersubtype:
-		for_all_directions(dir) {
-		    if (1) {
+		if (1 /* any damage possible */) {
+		    for_all_directions(dir) {
 			if (border_at(x, y, dir, t)
 			    && probability(ut_detonation_damage(u, t))) {
 			    t2 = damaged_terrain_type(t);
@@ -2050,21 +2092,23 @@ damage_terrain(int u, int x, int y)
 			    } else if (t2 != t) {
 				set_border_at(x, y, dir, t, FALSE);
 				set_border_at(x, y, dir, t2, TRUE);
-				/* There is potentially a problem with some
-				   game designs here; if the new type t2 can
-				   also be damaged by the detonation, then
-				   the loop here will damage it in turn, at
-				   least if t2 *follows* t in the list of terrain
-				   types.  Preventing this would require a lot of
-				   buffering, so it's left as a limitation for now. */
+				/* There is potentially a problem with
+				   some game designs here; if the new
+				   type t2 can also be damaged by the
+				   detonation, then the loop here will
+				   damage it in turn, at least if t2
+				   *follows* t in the list of terrain
+				   types.  Preventing this would
+				   require a lot of buffering, so it's
+				   left as a limitation for now. */
 			    }
 			}
 		    }
 		}
 	        break;
 	      case connectionsubtype:
-		for_all_directions(dir) {
-		    if (1) {
+		if (1 /* any damage possible */) {
+		    for_all_directions(dir) {
 			if (connection_at(x, y, dir, t)
 			    && probability(ut_detonation_damage(u, t))) {
 			    t2 = damaged_terrain_type(t);
@@ -2073,6 +2117,8 @@ damage_terrain(int u, int x, int y)
 			    } else if (t2 != t) {
 				set_connection_at(x, y, dir, t, FALSE);
 				set_connection_at(x, y, dir, t2, TRUE);
+				/* Same issue here as with border
+                                   damage. */
 			    }
 			}
 		    }
