@@ -1,5 +1,5 @@
 /* Main include file for Xconq.
-   Copyright (C) 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -296,6 +296,7 @@ extern void parse_player_spec(Player *player, char *spec);
 extern int get_synth_method_uses(int methkey, int *calls, int *runs);
 
 extern void kick_out_enemy_users(Side *side, int x, int y);
+extern int has_advance_to_research(Side *side, int a);
 
 /* run2.c */
 
@@ -369,6 +370,7 @@ extern void hp_desc(char *buf, Unit *unit, int label);
 extern void acp_desc(char *buf, Unit *unit, int label);
 extern void cxp_desc(char *buf, Unit *unit, int label);
 extern void morale_desc(char *buf, Unit *unit, int label);
+extern void point_value_desc(char *buf, Unit *unit, int label);
 extern void plan_desc(char *buf, Unit *unit);
 extern void task_desc(char *buf, Side *side, Unit *unit, Task *task);
 extern void time_desc(char *buf, int time, int maxtime);
