@@ -21,16 +21,6 @@ extern int bhw_max;
 /* Needed in iplayer_adjust_plan. */
 extern short any_auto_repair;
 
-/* what does the game look like? */
-typedef enum a_game_class {
-    gc_none,
-    gc_standard,
-    gc_time,
-    gc_advanced
-} GameClass;
-
-static GameClass game_class = gc_none;
-
 /* Strategy is what a side uses to make decisions. */
 
 typedef struct a_strategy {
@@ -71,7 +61,9 @@ static void assign_to_defense(Side *side, Unit *unit);
 static void assign_to_defense_support(Side *side, Unit *unit);
 static int build_depot_for_self(Side *side, Unit *unit);
 static void assign_to_colonize(Side *side, Unit *unit);
+#if 0
 static void assign_to_improve(Side *side, Unit *unit);
+#endif
 static void iplayer_react_to_task_result(Side *side, Unit *unit, Task *task, TaskOutcome rslt);
 static int desired_direction_impassable(Unit *unit, int x, int y);
 static int blocked_by_enemy(Unit *unit, int x, int y, int shortest);
@@ -79,14 +71,15 @@ static int attack_blockage(Side *side, Unit *unit, int x, int y, int shortest);
 static void iplayer_react_to_new_side(Side *side, Side *side2);
 static void iplayer_finish_movement(Side *side);
 static void assign_to_defend_unit(Unit *unit, Unit *unit2);
+#if 0
 static void assign_to_defend_cell(Unit *unit, int x, int y);
 static void assign_to_defend_vicinity(Unit *unit, int x, int y, int w, int h);
+#endif
 static void rethink_plan(Unit *unit);
 static int enemy_close_by(Side *side, Unit *unit, int dist, int *xp, int *yp);
 static void iplayer_receive_message(Side *side, Side *sender, char *str);
 static char *iplayer_at_desig(Side *side, int x, int y);
 static int iplayer_theater_at(Side *side, int x, int y);
-static int iplayer_read_strengths(Side *side);
 static Obj *iplayer_save_state(Side *side);
 
 /* This is the set of operations that generic code will use. */
@@ -113,37 +106,11 @@ AI_ops iplayer_ops = {
 
 static int iplayerinited = FALSE;
 
-/* Determine game type from name of included modules. */
-
-static GameClass find_game_class(void);
-
-static GameClass
-find_game_class(void)
-{
-    Module *m;
-
-    for_all_modules(m) {
-	if (strcmp(m->name, "time") == 0
-	    || (m->origmodulename && strcmp(m->origmodulename, "time") == 0))
-	  return gc_time;
-    	else if (strcmp(m->name, "advanced") == 0
-		 || (m->origmodulename
-		     && strcmp(m->origmodulename, "advanced") == 0))
-	  return gc_advanced;
-    }
-    return gc_standard;
-}
-
 static void
-iplayer_init(side)
-Side *side;
+iplayer_init(Side *side)
 {
     Unit *unit;
 
-    if (game_class == gc_none) {
-	game_class = find_game_class();
-    }
-
     /* (should do this only when absolutely needed - iplayer might
        never actually be used) */
     if (!iplayerinited) {
@@ -170,11 +137,8 @@ Side *side;
 /* At the beginning of each turn, make plans and review the situation. */
 
 static void
-iplayer_init_turn(side)
-Side *side;
+iplayer_init_turn(Side *side)
 {
-    int u, u2;
-
     /* Cases where we no longer need to run. */
     if (!side->ingame)
       return;
@@ -217,9 +181,9 @@ static void
 review_units(side)
 Side *side;
 {
-    int u, u2, cp, cpmin, any;
+    int u;
     int numoffensive[MAXUTYPES], numdefensive[MAXUTYPES];
-    Unit *unit, *occ, *unit2;
+    Unit *unit;
     Plan *plan;
 
     for_all_unit_types(u) {
@@ -352,11 +316,9 @@ iplayer_decide_plan(Side *side, Unit *unit)
 }
 
 static int
-iplayer_adjust_plan(side, unit)
-Side *side;
-Unit *unit;
+iplayer_adjust_plan(Side *side, Unit *unit)
 {
-    int u3, lowm;
+    int u3;
     Task *task;
 
     /* Plans for advanced units are (for now) handled in run.c instead. */
@@ -469,94 +431,91 @@ defensive_reaction(Unit *unit)
     }
 }
 
-/* Returns true if unit is busy defending or recapturing unit2, 
-false if it needs a new goal. */
+/* Returns true if unit is busy defending or recapturing unit2, false
+   if it needs a new goal. */
 
 static int
 keep_defensive_goal(Unit *unit, Unit *unit2)
 {
-	Plan 	*plan = unit->plan;
-	int	garrison = 0;
-	Unit 	*unit3;
+    Plan *plan = unit->plan;
+    int garrison = 0;
+    Unit *unit3;
 
-	/* unit2 has been destroyed. */
-	if (!in_play(unit2)) {
-		return FALSE;
+    /* unit2 has been destroyed. */
+    if (!in_play(unit2)) {
+	return FALSE;
+    } else if (!occ_can_defend_transport(unit->type, unit2->type)) {
 	/* We can't defend unit2 (should never happen). */
-	} else if (!occ_can_defend_transport(unit->type, unit2->type)) {
-		return FALSE;
+	return FALSE;
+    } else if (enemy_side(unit->side, unit2->side)) {
 	/* unit2 is held by the enemy. */
-	} else if (enemy_side(unit->side, unit2->side)) {
-	    /* Don't interfere if we are trying to recapture unit2. */
-	    if (plan->tasks
-		&& (((plan->tasks->type == TASK_HIT_UNIT
-			&& plan->tasks->args[0] == unit2->x
-			&& plan->tasks->args[1] == unit2->y
-			&& plan->tasks->args[2] == unit2->type)
-		    || (plan->tasks->type == TASK_CAPTURE
-			&& plan->tasks->args[0] == unit2->x
-			&& plan->tasks->args[1] == unit2->y
-			&& plan->tasks->args[2] == unit2->type))
-		    /* Or if we are on our way to recapture unit2. */
-		    || (plan->tasks->type == TASK_MOVE_TO
-			&& plan->tasks->args[0] == unit2->x
-			&& plan->tasks->args[1] == unit2->y
-			&& plan->tasks->next
-			&& ((plan->tasks->next->type == TASK_HIT_UNIT
-				&& plan->tasks->args[0] == unit2->x
-				&& plan->tasks->args[1] == unit2->y
-				&& plan->tasks->args[2] == unit2->type)
-			     || plan->tasks->next->type == TASK_CAPTURE
-				&& plan->tasks->args[0] == unit2->x
-				&& plan->tasks->args[1] == unit2->y
-				&& plan->tasks->args[2] == unit2->type)))) {
-		    return TRUE;
-	    }
-	    /* Try to recapture unit2 directly if we have a decent chance. */
-	    if (real_capture_chance(unit, unit2) > 20) {
-		net_set_capture_task(unit, unit2->x, unit2->y);
-    		DMprintf("%s tries to recapture %s directly\n",
-	     					unit_desig(unit), unit_desig(unit2));
-		    return TRUE;
-	    /* Otherwise attack unit2 if possible. */
-	    } else if (attack_can_damage_or_capture(unit, unit2) 
-		       || fire_can_damage_or_capture(unit, unit2)) {
-		net_set_hit_unit_task(unit, unit2->x, unit2->y, 
-				      unit2->type, unit2->side->id);
-    		DMprintf("%s tries to take %s back by attacking it\n",
-	     					unit_desig(unit), unit_desig(unit2));
-		    return TRUE;
-	    }
-	/* Check if unit2 is adequately defended by OTHER occupants. */
-	} else {
-		for_all_occupants(unit2, unit3) {
-		    if (is_active(unit3)
-			&& unit3 != unit
-			&& unit3->plan
-			&& unit3->plan->maingoal
-			&& unit3->plan->maingoal->type == GOAL_UNIT_OCCUPIED
-			&& unit3->plan->maingoal->args[0] == unit2->id
-			/* Occs that cannot defend the transport should never
-			   have been assigned to occupy it, but check
-			   anyway. */
-			&& occ_can_defend_transport(unit3->type, unit2->type)) {
-			++garrison;
-		    }
-		}
-		/* If so, release our unit from its duty. */
-		if (enough_to_garrison(unit2, garrison)) {
-			return FALSE;
-		/* Else make sure we have the occupy task set if we are not there. */
-		} else if (unit->transport != unit2
-			&& plan->tasks
-		         && plan->tasks->type != TASK_OCCUPY) {
-		    	net_set_occupy_task(unit, unit2);
-			return TRUE;
-		/* Else just keep defending unit2. */
-		} else {
-			return TRUE;
-		}			
+	/* Don't interfere if we are trying to recapture unit2. */
+	if (plan->tasks
+	    && (((plan->tasks->type == TASK_HIT_UNIT
+		  && plan->tasks->args[0] == unit2->x
+		  && plan->tasks->args[1] == unit2->y
+		  && plan->tasks->args[2] == unit2->type)
+		 || (plan->tasks->type == TASK_CAPTURE
+		     && plan->tasks->args[0] == unit2->x
+		     && plan->tasks->args[1] == unit2->y
+		     && plan->tasks->args[2] == unit2->type))
+		/* Or if we are on our way to recapture unit2. */
+		|| (plan->tasks->type == TASK_MOVE_TO
+		    && plan->tasks->args[0] == unit2->x
+		    && plan->tasks->args[1] == unit2->y
+		    && plan->tasks->next
+		    && ((plan->tasks->next->type == TASK_HIT_UNIT
+			 && plan->tasks->args[0] == unit2->x
+			 && plan->tasks->args[1] == unit2->y
+			 && plan->tasks->args[2] == unit2->type)
+			|| (plan->tasks->next->type == TASK_CAPTURE
+			    && plan->tasks->args[0] == unit2->x
+			    && plan->tasks->args[1] == unit2->y
+			    && plan->tasks->args[2] == unit2->type))))) {
+	    return TRUE;
 	}
+	/* Try to recapture unit2 directly if we have a decent chance. */
+	if (real_capture_chance(unit, unit2) > 20) {
+	    net_set_capture_task(unit, unit2->x, unit2->y);
+	    DMprintf("%s tries to recapture %s directly\n",
+		     unit_desig(unit), unit_desig(unit2));
+	} else if (attack_can_damage_or_capture(unit, unit2) 
+		   || fire_can_damage_or_capture(unit, unit2)) {
+	    /* Otherwise attack unit2 if possible. */
+	    net_set_hit_unit_task(unit, unit2->x, unit2->y, 
+				  unit2->type, unit2->side->id);
+	    DMprintf("%s tries to take %s back by attacking it\n",
+		     unit_desig(unit), unit_desig(unit2));
+	}
+    } else {
+	/* Check if unit2 is adequately defended by OTHER occupants. */
+	for_all_occupants(unit2, unit3) {
+	    if (is_active(unit3)
+		&& unit3 != unit
+		&& unit3->plan
+		&& unit3->plan->maingoal
+		&& unit3->plan->maingoal->type == GOAL_UNIT_OCCUPIED
+		&& unit3->plan->maingoal->args[0] == unit2->id
+		/* Occs that cannot defend the transport should never
+		   have been assigned to occupy it, but check
+		   anyway. */
+		&& occ_can_defend_transport(unit3->type, unit2->type)) {
+		++garrison;
+	    }
+	}
+	/* If so, release our unit from its duty. */
+	if (enough_to_garrison(unit2, garrison)) {
+	    return FALSE;
+	} else if (unit->transport != unit2
+		   && plan->tasks
+		   && plan->tasks->type != TASK_OCCUPY) {
+	    /* Else make sure we have the occupy task set if we are
+               not there. */
+	    net_set_occupy_task(unit, unit2);
+	}			
+    }
+    /* Else just keep defending unit2. */
+    return TRUE;
 }
 
 /* Returns true if we decide to defend it. */
@@ -620,39 +579,37 @@ undefended_neighbour(Unit *unit)
 static int
 maybe_defend_other_transport(Unit *unit, Unit *unit2)
 {
-	Plan 	*plan = unit->plan;
-	Unit 	*unit3;
-	int	garrison = 0;
+    Unit *unit3;
+    int garrison = 0;
 
-	/* Check if other defenders on their way are closer or same distance. 
-	This prevents buzzing of flocks of defenders in and out of a city without 
-	adequate defense. */
-	for_all_side_units(unit->side, unit3) {
-
-		    if (is_active(unit3)
-			/* Should never happen, but check. */
-			&& unit3 != unit
-			&& unit3->plan
-			&& unit3->plan->maingoal
-			&& unit3->plan->maingoal->type == GOAL_UNIT_OCCUPIED
-			&& unit3->plan->maingoal->args[0] == unit2->id
-			&& occ_can_defend_transport(unit3->type, unit2->type)
-			/* (should take unit speeds into consideration here). */
-			&& distance(unit2->x, unit2->y, unit3->x, unit3->y) <=
-			      distance(unit2->x, unit2->y, unit->x, unit->y)) {
-				/* This is really the potential garrison as soon as
-				all defenders get there. */
-				++garrison;
-			}							
-		}
-	        /* If not enough defenders, assign our unit to the city's defense. */
-	        if (!enough_to_garrison(unit2, garrison)) { 
-    			assign_to_defend_unit(unit, unit2);
-	    		DMprintf("%s assigned to defend neighbour transport %s\n",
-		     					unit_desig(unit), unit_desig(unit2));
-		return TRUE;
-	}				
-	return FALSE;
+    /* Check if other defenders on their way are closer or same
+       distance.  This prevents buzzing of flocks of defenders in and
+       out of a city without adequate defense. */
+    for_all_side_units(unit->side, unit3) {
+	if (is_active(unit3)
+	    /* Should never happen, but check. */
+	    && unit3 != unit
+	    && unit3->plan
+	    && unit3->plan->maingoal
+	    && unit3->plan->maingoal->type == GOAL_UNIT_OCCUPIED
+	    && unit3->plan->maingoal->args[0] == unit2->id
+	    && occ_can_defend_transport(unit3->type, unit2->type)
+	    /* (should take unit speeds into consideration here). */
+	    && distance(unit2->x, unit2->y, unit3->x, unit3->y) <=
+	    distance(unit2->x, unit2->y, unit->x, unit->y)) {
+	    /* This is really the potential garrison as soon as all
+	       defenders get there. */
+	    ++garrison;
+	}							
+    }
+    /* If not enough defenders, assign our unit to the city's defense. */
+    if (!enough_to_garrison(unit2, garrison)) { 
+	assign_to_defend_unit(unit, unit2);
+	DMprintf("%s assigned to defend neighbour transport %s\n",
+		 unit_desig(unit), unit_desig(unit2));
+	return TRUE;
+    }				
+    return FALSE;
 }
 
 /* Deal with tactical emergencies such as enemy units that suddenly
@@ -838,17 +795,6 @@ iplayer_fire_at_opportunity(Unit *unit)
     return rslt;
 }
 
-/* Set the unit up as an explorer and let it go. */
-
-static void
-assign_to_exploration(Side *side, Unit *unit)
-{
-    int numweights = 0, weight, i, dist;
-
-    /* Unit's goal in life will be to see that the world is all known. */
-    net_set_unit_plan_type(side, unit, PLAN_EXPLORATORY);
-}
-
 /* Unit's goal in life will be to colonize the world. */
 
 static void
@@ -888,6 +834,7 @@ assign_to_colonize(Side *side, Unit *unit)
 	}
 }
 
+#if 0 /* unused */
 static void
 assign_to_improve(side, unit)
 Side *side;
@@ -899,15 +846,13 @@ Unit *unit;
     net_set_unit_main_goal(side, unit, NULL);
     DMprintf("%s assigned to improve\n", unit_desig(unit));
 }
+#endif
 
 static void
 assign_to_offense(side, unit)
 Side *side;
 Unit *unit;
 {
-    int numweights = 0, weight;
-    Goal *goal;
-
     net_set_unit_plan_type(side, unit, PLAN_OFFENSIVE);
     net_clear_task_agenda(side, unit);
 }
@@ -943,17 +888,13 @@ int u;
    unit to build. */
 
 static int
-preferred_build_type(side, unit, plantype)
-Side *side;
-Unit *unit;
-int plantype;
+preferred_build_type(Side *side, Unit *unit, int plantype)
 {
     int u = unit->type, u2, u3, t;
     int x, y, dir, x1, y1, blockedallaround, uview, est, rslt;
     int prefs[MAXUTYPES];
     int fringeterrain[MAXTTYPES], sumfringe, totfringe;
     int enemytypes[MAXUTYPES];
-    int numtotransport[MAXUTYPES];
     Unit *unit2, *occ;
 
     if (plantype == PLAN_EXPLORATORY) {
@@ -1150,6 +1091,7 @@ assign_to_defend_unit(Unit *unit, Unit *unit2)
 	     unit_desig(unit), unit_desig(unit2));
 }
 
+#if 0
 /* Assign unit to defend cell at (x, y). */
 
 void
@@ -1190,6 +1132,7 @@ assign_to_defend_vicinity(Unit *unit, int x, int y, int w, int h)
 	DMprintf("%s now assigned to defense the vicinity of (%d, %d)\n",
 		 unit_desig(unit), x, y);
 }
+#endif
 
 static void
 assign_to_defense_support(side, unit)
@@ -1357,10 +1300,8 @@ iplayer_react_to_new_side(Side *side, Side *side2)
    the situation changed. */
 
 static void
-iplayer_finish_movement(side)
-Side *side;
+iplayer_finish_movement(Side *side)
 {
-    int u, scan;
     Unit *unit;
 
     for_all_side_units(side, unit) {
@@ -1376,13 +1317,10 @@ Side *side;
    current plan/tasks. */
 
 static void
-rethink_plan(unit)
-Unit *unit;
+rethink_plan(Unit *unit)
 {
-    int dist, x1, y1;
+    int x1, y1;
     Task *toptask = unit->plan->tasks, *nexttask = NULL;
-    Plan *plan = unit->plan;
-    Unit *transport;
 
     if (toptask)
       nexttask = toptask->next;
@@ -1400,7 +1338,8 @@ Unit *unit;
     /* If we see somebody that could be captured and help us explore, set up
        to produce capturers. */
     if (!mobile(unit->type)
-	&& (unit->plan->type == PLAN_EXPLORATORY || unit->plan->type == PLAN_OFFENSIVE)
+	&& (unit->plan->type == PLAN_EXPLORATORY
+	    || unit->plan->type == PLAN_OFFENSIVE)
 	) {
 	int range = 4, rslt, x, y;
 
@@ -1498,65 +1437,6 @@ iplayer_theater_at(Side *side, int x, int y)
     return 0;
 }
 
-/* Collect initial strength information stored in the iplayer's
-   private saved data. */
-
-static int
-iplayer_read_strengths(Side *side)
-{
-    int sn1, u, found = FALSE;
-    char *propname;
-    Obj *props, *bdg, *rest, *sidebdg, *urest;
-    Side *side1;
-
-    props = find_at_key(side->aidata, "iplayer");
-    for (; props != lispnil; props = cdr(props)) {
-	bdg = car(props);
-	propname = c_string(car(bdg));
-	if (strcmp(propname, "strengths0") == 0) {
-	    found = TRUE;
-	    rest = cdr(bdg);
-	    for_all_sides(side1) {
-		sn1 = side1->id;
-		sidebdg = car(rest);
-		urest = cadr(sidebdg);
-		for_all_unit_types(u) {
-		    urest = cdr(urest);
-		}
-		rest = cdr(rest);
-	    }
-	} else if (strcmp(propname, "alstrengths0") == 0) {
-	    found = TRUE;
-	    rest = cdr(bdg);
-	    for_all_sides(side1) {
-		sn1 = side1->id;
-		sidebdg = car(rest);
-		urest = cadr(sidebdg);
-		for_all_unit_types(u) {
-		    urest = cdr(urest);
-		}
-		rest = cdr(rest);
-	    }
-	} else if (strcmp(propname, "points0") == 0) {
-	    found = TRUE;
-	    rest = cdr(bdg);
-	    for_all_sides(side1) {
-		sn1 = side1->id;
-		rest = cdr(rest);
-	    }
-	} else if (strcmp(propname, "alpoints0") == 0) {
-	    found = TRUE;
-	    rest = cdr(bdg);
-	    for_all_sides(side1) {
-		sn1 = side1->id;
-		rest = cdr(rest);
-	    }
-	} else {
-	}
-    }
-    return found;
-}
-
 /* Write out any state that the iplayer must preserve.  We don't
    actually write; instead we build a Lisp object and pass that back
    to the writing routines. */
