@@ -15,25 +15,12 @@ any later version.  See the file COPYING.  */
 
 /* This is how we do optional prototypes and const decls. */
 
-#ifdef MSDOS
-#define PARAMS(ARGS) ARGS
-#define CONST const
-#endif
-
 #ifndef PARAMS
-#ifdef ANSI_PROTOTYPES
 #define PARAMS(ARGS) ARGS
-#else
-#define PARAMS(ARGS) ()
-#endif /* ANSI_PROTOTYPES */
 #endif /* PARAMS */
 
 #ifndef CONST
-#ifdef __STDC__
 #define CONST const
-#else
-#define CONST
-#endif /* __STDC__ */
 #endif /* CONST */
 
 #ifndef ABS
