@@ -78,9 +78,10 @@ static int numholes;
 
 /* Should add a cheap erosion simulator. */
 
+static void add_random_changes(void);
+
 int
-make_fractal_terrain(calls, runs)
-int calls, runs;
+make_fractal_terrain(int calls, int runs)
 {
     int actualcells, altnumblobs, altblobradius, altblobalt;
     int wetnumblobs, wetblobradius, wetblobalt;
@@ -135,6 +136,7 @@ int calls, runs;
     /* Put it all together. */
     partdone += stepsize;
     compose_area();
+    add_random_changes();
     fix_adjacent_terrain();
     add_edge_terrain();
     flatten_liquid_terrain();
@@ -152,9 +154,7 @@ int calls, runs;
 }
 
 static void
-make_blobs(layer, numblobs, blobradius, blobalt)
-short *layer;
-int numblobs, blobradius, blobalt;
+make_blobs(short *layer, int numblobs, int blobradius, int blobalt)
 {
     int x0, y0, x1, y1, x2, y2, updown, x, y, xw;
     int maxdz, i, dz, oz;
@@ -213,9 +213,7 @@ int numblobs, blobradius, blobalt;
 /* Ensure that area values stay within given range. */
 
 static void
-limit_layer(layer, hi, lo)
-short *layer;
-int hi, lo;
+limit_layer(short *layer, int hi, int lo)
 {
     int x, y, m;
     
@@ -228,9 +226,7 @@ int hi, lo;
 /* Average each cell with its neighbors, using tmp3 as scratch layer. */
 
 static void
-smooth_layer(layer, times)
-short *layer;
-int times;
+smooth_layer(short *layer, int times)
 {
     int i, x, y, nx, px, dir, x1, y1, ndirs, sum;
 
@@ -282,9 +278,7 @@ int times;
    value, and save them all away.  */
 
 static void
-percentile(layer, percentiles)
-short *layer;
-int *percentiles;
+percentile(short *layer, int *percentiles)
 {
     int i, x, y, total;
     
@@ -312,7 +306,7 @@ int *percentiles;
 /* Final creation and output of the area. */
 
 static void
-compose_area()
+compose_area(void)
 {
     int x, y, t, t2, t3;
     int elev, elevrange[MAXTTYPES], elevlo[MAXTTYPES], elevhi[MAXTTYPES];
@@ -401,8 +395,7 @@ compose_area()
    there. */
 
 static int
-terrain_from_percentiles(x, y)
-int x, y;
+terrain_from_percentiles(int x, int y)
 {
     int t, rawalt = tmp1_at(x, y), rawwet = tmp2_at(x, y);
 
@@ -424,8 +417,7 @@ int x, y;
    random elevations. */
 
 int
-make_random_terrain(calls, runs)
-int calls, runs;
+make_random_terrain(int calls, int runs)
 {
     int t, x, y, cellsum, cellsumtable[MAXTTYPES];
     int i, numcells, n, elevrange, elev, occur, dir;
@@ -1055,6 +1047,33 @@ random_passage_terrain()
     return (xrandom(numttypes));
 }
 
+static void
+add_random_changes(void)
+{
+    int t1, t2, anychanges = FALSE, x, y, dens;
+
+    /* Might not be anything to do, scan the table. */
+    for_all_terrain_types(t1) {
+	for_all_terrain_types(t2) {
+	    if (tt_density(t1, t2) > 0) {
+		anychanges = TRUE;
+		break;
+	    }
+	}
+    }
+    if (!anychanges)
+      return;
+    for_all_cells(x, y) {
+	for_all_terrain_types(t2) {
+	    dens = tt_density(terrain_at(x, y), t2);
+	    if (dens > 0 && dens > xrandom(10000)) {
+		set_terrain_at(x, y, t2);
+		break;
+	    }
+	}
+    }
+}
+
 /* This method adds some randomly named geographical features. */
 
 /* (This needs to interact properly with convex region finder eventually) */
