@@ -40,15 +40,11 @@ create_game_module(char *name)
     Module *module = (Module *) xmalloc(sizeof(Module));
 
     /* Fill in nonzero slots. */
+    copy_module(module, NULL);
     /* The module's name must never be NULL. */
     if (name == NULL)
       name = "";
     module->name = name;
-    module->instructions = lispnil;
-    module->notes = lispnil;
-    module->designnotes = lispnil;
-    module->startlineno = 1;
-    module->endlineno = 1;
     /* Add to front of module list. */
     module->next = modulelist;
     modulelist = module;
@@ -438,6 +434,62 @@ do_one_variant(Module *module, Variant *var, Obj *varsetdata)
 	var->intvalue = val;
 	set_g_use_side_priority(val);
 	break;
+      case K_PEOPLE:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_people(val);
+	break;
+      case K_ECONOMY:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_economy(val);
+	break;
+      case K_SUPPLY:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_supply(val);
+	break;
+      case K_INDEPSIDE_HAS_AI:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_indepside_has_ai(val);
+	break;
+      case K_INDEPSIDE_CAN_BUILD:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_indepside_can_build(val);
+	break;
+      case K_INDEPSIDE_CAN_RESEARCH:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_indepside_can_research(val);
+	break;
+      case K_INDEPSIDE_HAS_TREASURY:
+	val = (varsetdata == lispnil ?
+	       (var->dflt == lispnil ? FALSE : c_number(eval(var->dflt))) :
+	       c_number(eval(car(varsetdata))));
+	var->hasintvalue = TRUE;
+	var->intvalue = val;
+	set_g_indepside_has_treasury(val);
+	break;
       case K_WORLD_SIZE:
       	filler = lispnil;
 	if (varsetdata != lispnil) {
@@ -554,6 +606,58 @@ do_one_variant(Module *module, Variant *var, Obj *varsetdata)
     var->used = TRUE;
 }
 
+/* Given a module and a original, copy over properties of the original
+   module. */
+
+void
+copy_module(Module *module, Module *origmodule)
+{
+    char *name;
+    Module *next, *incl, *nextincl, *lastincl;
+
+    /* No matter what, preserve the existing name. */
+    name = module->name;
+    if (origmodule != NULL) {
+	/* Save away the module's links to other modules. */
+	next = module->next;
+	incl = module->include;
+	nextincl = module->nextinclude;
+	lastincl = module->lastinclude;
+	memcpy(module, origmodule, sizeof(Module));
+	/* By default, we copy everything through; but keep a separate
+	   copy of the original name and variants, because the calling
+	   routine may overwrite with other values. */
+	/* (should test each property individually here?) */
+	if (empty_string(origmodule->origmodulename)) {
+	    /* If no original module, use the main module. */
+	    module->origmodulename = origmodule->name;
+	    module->origvariants = origmodule->variants;
+	    module->origversion = origmodule->version;
+	}
+	/* Kill off caches that should not be replicated. */
+	module->contents = NULL;
+	module->sp = NULL;
+	module->fp = NULL;
+	module->open = FALSE;
+	module->loaded = FALSE;
+	/* Restore links. */
+	module->next = next;
+	module->include = incl;
+	module->nextinclude = nextincl;
+	module->lastinclude = lastincl;
+    } else {
+	/* If there is no original from which to copy, just do some
+	   generic clearing/init. */
+	memset(module, 0, sizeof(Module));
+	module->instructions = lispnil;
+	module->notes = lispnil;
+	module->designnotes = lispnil;
+	module->startlineno = 1;
+	module->endlineno = 1;
+    }
+    module->name = name;
+}
+
 void
 init_module_reshape(Module *module)
 {
@@ -567,7 +671,6 @@ init_module_reshape(Module *module)
     module->final_subarea_x = module->final_subarea_y = 0;
     module->final_width = area.width;  module->final_height = area.height;
     module->final_circumference = world.circumference;
-    module->fill_type = 0;
 }
 
 /* This is true if any actual reshaping is required. */
