@@ -14,6 +14,9 @@ extern int border_slide_possible(int u2, int ox, int oy, int nx, int ny);
 #include "kernel.h"
 #include "kpublic.h"
 
+int unit_traverse_blockable_by(Unit *unit, Unit *unit2);
+int any_friendly_at(Unit *unit, int x, int y);
+
 enum {
     over_nothing = 0,
     over_own = 1,
@@ -259,7 +262,7 @@ check_move_action(Unit *unit, Unit *unit2, int x, int y, int z)
       return A_ANY_TOO_FAR;
     /* Check if the destination is in a blocking ZOC. */
     if (in_blocking_zoc(unit, x, y, z))
-      return A_ANY_ERROR;
+      return A_MOVE_BLOCKING_ZOC;
     /* Now start looking at the move costs. */
     u3 = (unit2->transport ? unit2->transport->type : NONUTYPE);
     totcost = total_move_cost(u2, u3, ox, oy, oz, x, y, z);
@@ -309,15 +312,13 @@ can_move_via_conn(Unit *unit, int nx, int ny)
 
     if (numconntypes == 0)
       return FALSE;
-    for_all_terrain_types(c) {
-	    if (t_is_connection(c)
-		&& aux_terrain_defined(c)
-		&& (dir = closest_dir(nx - unit->x, ny - unit->y)) >= 0
-		&& connection_at(unit->x, unit->y, dir, c)
-		&& !ut_vanishes_on(unit->type, c)
-		&& !ut_wrecks_on(unit->type, c)) {
-		return TRUE;
-	    }
+    for_all_connection_types(c) {
+	if (aux_terrain_defined(c)
+	    && (dir = closest_dir(nx - unit->x, ny - unit->y)) >= 0
+	    && connection_at(unit->x, unit->y, dir, c)
+	    && !ut_vanishes_on(unit->type, c)
+	    && !ut_wrecks_on(unit->type, c))
+	  return TRUE;
     }
     return FALSE;
 }
@@ -356,9 +357,8 @@ border_slide_possible(int u, int ox, int oy, int nx, int ny)
     }
     bdir = left_dir(left_dir(dir));
     point_in_dir(ox, oy, dir, &bx, &by);
-    for_all_terrain_types(b) {
-	if (t_is_border(b)
-	    && aux_terrain_defined(b)
+    for_all_border_types(b) {
+	if (aux_terrain_defined(b)
 	    && border_at(bx, by, bdir, b)
 	    && ut_mp_to_traverse(u, b) >= 0)
 	  return TRUE;
@@ -556,7 +556,7 @@ change_control_side_around(int x, int y, int u, Side *side)
 	    }
 	}
 	update_cell_display_all_sides(x, y, UPDATE_ALWAYS | UPDATE_ADJ);
-	/* Previous side(s) lose free coverage. */
+	/* Previousn side(s) lose free coverage. */
 	for_all_sides(side2) {
 	    if (!trusted_side(side, side2)
 		&& (oldside == side2 || trusted_side(oldside, side2))) {
@@ -584,7 +584,7 @@ static void test_blocking_zoc(int x, int y);
 int
 in_blocking_zoc(Unit *unit, int x, int y, int z)
 {
-    int u = unit->type, t = terrain_at(x, y), dir, x1, y1, u2, range;
+    int u = unit->type, t = terrain_at(x, y), dir, x1, y1, t1, u2, range;
     Unit *unit2;
 
     if (max_zoc_range < 0)
@@ -605,14 +605,25 @@ in_blocking_zoc(Unit *unit, int x, int y, int z)
     if (max_zoc_range >= 1) {
 	for_all_directions(dir) {
 	    if (point_in_dir(x, y, dir, &x1, &y1)) {
-		for_all_stack(x, y, unit2) {
+		for_all_stack(x1, y1, unit2) {
 		    u2 = unit2->type;
 		    range = zoc_range(unit2, u);
+		    t1 = terrain_at(x1, y1);
 		    if (range >= 1
 			&& is_active(unit2)
 			&& unit_blockable_by(unit, unit2)
 			&& ut_zoc_into(u2, t)
-			&& ut_zoc_from_terrain(u2, terrain_at(x1, y1)) > 0)
+			&& ut_zoc_from_terrain(u2, t1) > 0)
+		      return TRUE;
+		    if (range >= 1
+			&& is_active(unit2)
+			&& unit_traverse_blockable_by(unit, unit2)
+			&& distance(unit->x, unit->y, x1, y1) <= range
+			/* (should check that zoc goes into old terrain) */
+			&& ut_zoc_into(u2, t)
+			&& ut_zoc_from_terrain(u2, t1) > 0
+			&& !any_friendly_at(unit, x, y)
+			)
 		      return TRUE;
 		}
 	    }
@@ -650,10 +661,35 @@ test_blocking_zoc(int x, int y)
 int
 unit_blockable_by(Unit *unit, Unit *unit2)
 {
-    return (!trusted_side(unit->side, unit2->side) /* should make a better test */
+    /* should make a better test than just trust - some types
+       might not need to side relationship? */
+    return (!trusted_side(unit->side, unit2->side)
 	    && uu_mp_to_enter_zoc(unit->type, unit2->type) < 0);
 }
 
+/* This is true if unit2 wants to block unit from moving. */
+
+int
+unit_traverse_blockable_by(Unit *unit, Unit *unit2)
+{
+    /* should make a better test than just trust - some types
+       might not need to side relationship? */
+    return (!trusted_side(unit->side, unit2->side)
+	    && uu_mp_to_traverse_zoc(unit->type, unit2->type) < 0);
+}
+
+int
+any_friendly_at(Unit *unit, int x, int y)
+{
+    Unit *unit2;
+
+    for_all_stack(x, y, unit2) {
+	if (unit_trusts_unit(unit, unit2))
+	  return TRUE;
+    }
+    return FALSE;
+}
+
 /* Compute the number of move points that will be needed to do the given
    move. */
 
@@ -707,9 +743,8 @@ total_move_cost(int u, int u2, int x1, int y1, int z1, int x2, int y2, int z2)
 	/* Add any necessary border crossing costs. */
 	dir = closest_dir(x2 - x1, y2 - y1);
 	if (dir >= 0) {
-	    for_all_terrain_types(b) {
-		if (t_is_border(b)
-		    && aux_terrain_defined(b)
+	    for_all_border_types(b) {
+		if (aux_terrain_defined(b)
 		    && border_at(x1, y1, dir, b)) {
 		    cost += ut_mp_to_enter(u, b);
 		}
@@ -737,9 +772,8 @@ total_move_cost(int u, int u2, int x1, int y1, int z1, int x2, int y2, int z2)
 	/* Try each connection type to see if it's better. */
 	dir = closest_dir(x2 - x1, y2 - y1);
 	if (dir >= 0) {
-	    for_all_terrain_types(c) {
-		if (t_is_connection(c)
-		    && aux_terrain_defined(c)
+	    for_all_connection_types(c) {
+		if (aux_terrain_defined(c)
 		    && connection_at(x1, y1, dir, c)
 		    && ((travcost = ut_mp_to_traverse(u, c)) >= 0)) {
 		    conncost = ut_mp_to_enter(u, c)
@@ -1200,9 +1234,8 @@ int u1, u3, x1, y1, z1, u2, x2, y2, z2;
     if (numbordtypes > 0 && ferryout < over_border && ferryin < over_border) {
 	dir = closest_dir(x2 - x1, y2 - y1);
 	if (dir >= 0) {
-	    for_all_terrain_types(b) {
-		if (t_is_border(b)
-		    && aux_terrain_defined(b)
+	    for_all_border_types(b) {
+		if (aux_terrain_defined(b)
 		    && border_at(x1, y1, dir, b)) {
 		    cost += ut_mp_to_enter(u1, b);
 		}
@@ -1222,9 +1255,8 @@ int u1, u3, x1, y1, z1, u2, x2, y2, z2;
 	/* Try each connection type to see if it's better. */
 	dir = closest_dir(x2 - x1, y2 - y1);
 	if (dir >= 0) {
-	    for_all_terrain_types(c) {
-		if (t_is_connection(c)
-		    && aux_terrain_defined(c)
+	    for_all_connection_types(c) {
+		if (aux_terrain_defined(c)
 		    && connection_at(x1, y1, dir, c)
 		    && ((travcost = ut_mp_to_traverse(u1, c)) >= 0)) {
 		    conncost = ut_mp_to_enter(u1, c)
