@@ -1031,7 +1031,9 @@ plan_colonize_support(Unit *unit)
 static void
 plan_improve(Unit *unit)
 {
+#if 0
     int u, type[MAXUTYPES], numtypes = 0;
+#endif
 
     /* Execute the task if we have one. */
     if (unit->plan->tasks) {
@@ -1118,7 +1120,7 @@ good_cell_to_colonize(int u, Unit *unit)
 	    if (!inside_area(x1, y1))
 	      continue;
 	    /* Don't count supply in cells already used by others. */
-	    if (user_at(x1, y1) != NOUSER)
+	    if (user_defined() && user_at(x1, y1) != NOUSER)
 	      continue;
 	    /* Add the supply of materials from this cell. */
 	    for_all_material_types (m)
@@ -2716,8 +2718,7 @@ int x0, y0, maxdist, (*pred)(int x, int y), *rxp, *ryp;
 /* True if the given unit is a sort that can build other units. */
 
 int
-can_build(unit)
-Unit *unit;
+can_build(Unit *unit)
 {
     int u2;
 
@@ -2729,8 +2730,7 @@ Unit *unit;
 }
 
 int
-can_build_or_help(unit)
-Unit *unit;
+can_build_or_help(Unit *unit)
 {
     int u2;
 
@@ -2744,20 +2744,16 @@ Unit *unit;
 }
 
 int
-can_research(unit)
-Unit *unit;
+can_research(Unit *unit)
 {
-	int a;
-
-	/* Kind of crude, but works for now. */
-	if (u_advanced(unit->type))
-	    return TRUE;
-	return FALSE;
+    /* Kind of crude, but works for now. */
+    if (u_advanced(unit->type))
+      return TRUE;
+    return FALSE;
 }
 
 int
-can_produce(unit)
-Unit *unit;
+can_produce(Unit *unit)
 {
     int m;
 
@@ -2772,8 +2768,7 @@ Unit *unit;
 /* Test if unit can move out into adjacent cells. */
 
 int
-can_move(unit)
-Unit *unit;
+can_move(Unit *unit)
 {
     int d, x, y;
 
@@ -2787,18 +2782,16 @@ Unit *unit;
     return FALSE;
 }
 
-/* Returns the type of missing supplies. Not great routine if first */
-/* material is a type of ammo. */
+/* Returns the type of missing supplies. */
 
 int
-out_of_ammo(unit)
-Unit *unit;
+out_of_ammo(Unit *unit)
 {
-    int u = unit->type, r;
+    int u = unit->type, m;
 
-    for_all_material_types(r) {
-	if (um_consumption_per_attack(u, r) > 0 && unit->supply[r] <= 0)
-	    return r;
+    for_all_material_types(m) {
+	if (um_consumption_per_attack(u, m) > 0 && unit->supply[m] <= 0)
+	    return m;
     }
     return (-1);
 }
@@ -2806,8 +2799,7 @@ Unit *unit;
 /* Check how long a unit can sit where it is */
 
 int
-survival_time(unit)
-Unit *unit;
+survival_time(Unit *unit)
 {
     int u = unit->type, m, least = 99999, rate, tmp;
     int t = terrain_at(unit->x, unit->y);
