@@ -56,7 +56,6 @@ Piazza Torricelli 2, I56126 Pisa, Italy  ||  Phone: (+39)(50)911272
 Internet: campo@sunthpi3.difi.unipi.it   ||  Fax:   (+39)(50)48277  */
 
 #include "conq.h"
-extern int num_features(void);
 #include "print.h"
 #include "imf.h"
 #include "ui.h"
@@ -972,10 +971,7 @@ Side *side;
 /* This routine could still use a cleanup */
 
 void
-dump_ps_view(side, ipp, filename)
-Side *side;
-PrintParameters *ipp;
-char *filename;
+dump_ps_view(Side *side, PrintParameters *ipp, char *filename)
 {
     int x, y, xx, i, j, t, nx, utype, page, d, cx, cy, skip, nsp;
     int f, nf, tw, th, font, named_unit_max=100, xmin, ymin, xmin1;
@@ -999,7 +995,7 @@ char *filename;
     
     /* Compute position of legends of geographical features. */
     if (pp->features) {
-	nf = num_features();
+	nf = numfeatures;
 	if (nf > 0) {
 	    legs = (Legend *) malloc((nf + 1) * sizeof(Legend));
 	    if (legs)
@@ -1108,8 +1104,8 @@ char *filename;
 		    if (!in_area(x, y))
 		      continue;
 
-		    for_all_terrain_types(t) {
-			if (t_is_border(t) && aux_terrain_defined(t)) {
+		    for_all_border_types(t) {
+			if (aux_terrain_defined(t)) {
 			    for_all_directions(d) {
 				if (border_at(x, y, d, t) &&
 				    (!side
@@ -1144,8 +1140,8 @@ char *filename;
 		    x = wrapx(x);
 		    if (!in_area(x, y))
 		      continue;
-		    for_all_terrain_types(t) {
-			if (t_is_connection(t) && aux_terrain_defined(t)) {
+		    for_all_connection_types(t) {
+			if (aux_terrain_defined(t)) {
 			    for_all_directions(d) {
 				if (connection_at(x, y, d, t) &&
 				    (!side || g_see_all() ||
