@@ -997,8 +997,7 @@ void run_ai_plan_adjust(Side *side);
 /* (should decide on useful return value and use, or make void) */
 
 int
-run_local_ai(when, maxplanning)
-int when, maxplanning;
+run_local_ai(int when, int maxplanning)
 {
     Side *side;
     Unit *unit;
@@ -1057,8 +1056,8 @@ int when, maxplanning;
     
     /* This code finds a new plan for any unit with a passive plan.
     
-    Executed after each plan execution, during forced replanning
-    and at the start of each turn. */
+       Executed after each plan execution, during forced replanning
+       and at the start of each turn. */
 
     if (need_ai_planning) {
 	for_all_sides(side) {
@@ -1077,10 +1076,10 @@ int when, maxplanning;
     }
     
     /* This code does two things:
-    1) Reacts to failed move tasks as approprite.
-    2) Reacts to failed resupply tasks by trying to build a depot.
+       1) Reacts to failed move tasks as approprite.
+       2) Reacts to failed resupply tasks by trying to build a depot.
     
-    Executed after each task execution. */
+       Executed after each task execution. */
 
     if (need_ai_task_reaction) {
 	for_all_sides(side) {
@@ -1090,7 +1089,8 @@ int when, maxplanning;
 			&& unit->plan
 			&& unit->plan->aicontrol
 			&& unit->plan->last_task_outcome != TASK_UNKNOWN) {
-			ai_react_to_task_result(side, unit, &(unit->plan->last_task),
+			ai_react_to_task_result(side, unit,
+						&(unit->plan->last_task),
 						unit->plan->last_task_outcome);
 			unit->plan->last_task_outcome = TASK_UNKNOWN;
 		    }
@@ -1101,10 +1101,10 @@ int when, maxplanning;
     }
 
     /* This code does two things:
-    1) Reevaluates the defense of cities and assigns or releases defenders.
-    2) Sets (not pushes) hit tasks etc. for enemy units that appear nearby.
+       1) Reevaluates the defense of cities and assigns or releases defenders.
+       2) Sets (not pushes) hit tasks etc. for enemy units that appear nearby.
     
-    Executed after certain actions. */
+       Executed after certain actions. */
 
     if (need_ai_action_reaction) {
 	for_all_sides(side) {
@@ -1125,11 +1125,11 @@ int when, maxplanning;
     }
 
     /* This code does three things:
-    1) Sets build tasks for stationary units with zero or non-build tasks.
-    2) Forces units that are waiting for tasks to replan.
-    3) Forces units with too many plan execs this turn into reserve.
+       1) Sets build tasks for stationary units with zero or non-build tasks.
+       2) Forces units that are waiting for tasks to replan.
+       3) Forces units with too many plan execs this turn into reserve.
     
-    Executed each round. */ 
+       Executed each round. */ 
 
     if (1) {
 	for_all_sides(side) {
@@ -1140,14 +1140,14 @@ int when, maxplanning;
     }
     
     /* This code does four things:
-    1) Organizes pickup of any units already known to need transport.
-    2) Checks if any other units need transport (rethink_plan).
-    3) Pushes a hit task for offensive units with move tasks if an enemy 
-    	appears nearby (rethink_plan).
-    4) Pushes a build task for capturer if a stationary unit sees a useful 
-    	capture nearby (rethink_plan).
+       1) Organizes pickup of any units already known to need transport.
+       2) Checks if any other units need transport (rethink_plan).
+       3) Pushes a hit task for offensive units with move tasks if an enemy 
+    	  appears nearby (rethink_plan).
+       4) Pushes a build task for capturer if a stationary unit sees a useful 
+    	  capture nearby (rethink_plan).
     
-    Executed at each end of turn. */
+       Executed at each end of turn. */
 
     if (need_ai_finish_movement) {
 	for_all_sides(side) {
@@ -1162,8 +1162,7 @@ int when, maxplanning;
 }
 
 void
-run_ai_plan_adjust(side)
-Side *side;
+run_ai_plan_adjust(Side *side)
 {
     int curactor, domore;
     Unit *unit;
@@ -1183,8 +1182,7 @@ Side *side;
 }
 
 void
-set_play_rate(slow, fast)
-int slow, fast;
+set_play_rate(int slow, int fast)
 {
     if (slow < 0 || fast < 0 || fast < slow) {
 	run_warning("Bad play rates slow=%d fast=%d, ignoring", slow, fast);
@@ -1197,8 +1195,7 @@ int slow, fast;
 /* Resignation, possibly giving away any remaining units. */
 
 void
-resign_game(side, side2)
-Side *side, *side2;
+resign_game(Side *side, Side *side2)
 {
     /* Nothing to do if we're not in the game. */
     if (!side->ingame)
@@ -1210,7 +1207,7 @@ Side *side, *side2;
 /* This is true if there is any kind of realtime limit on the game. */
 
 int
-realtime_game()
+realtime_game(void)
 {
     return (g_rt_for_game() > 0
     	    || g_rt_per_side() > 0
@@ -1220,8 +1217,7 @@ realtime_game()
 /* Pass NULL to see if all sides are now willing to save the game. */
 
 int
-all_others_willing_to_save(side)
-Side *side;
+all_others_willing_to_save(Side *side)
 {
     Side *side2;
 
@@ -1235,8 +1231,7 @@ Side *side;
 /* Pass NULL to see if all sides are now willing to declare a draw. */
 
 int
-all_others_willing_to_quit(side)
-Side *side;
+all_others_willing_to_quit(Side *side)
 {
     Side *side2;
 
@@ -1250,7 +1245,7 @@ Side *side;
 /* This forces an end to the game directly. */
 
 void
-end_the_game()
+end_the_game(void)
 {
     Side *side;
 
@@ -1292,9 +1287,9 @@ extern void free_used_cells(Unit *unit);
 extern void unit_research_dialog(Unit *unit);
 extern void side_research_dialog(Side *side, Unit *unit, int advance);
 extern void auto_pick_new_research(Unit *unit);
+extern void auto_pick_side_research(Side *side);
 
 extern void unit_plan_dialog(Unit *unit);
-extern int has_advance_to_research(Side *side, int a);
 extern int select_by_weight(int *arr, int numvals);
 extern int unit_build_dialog(Unit *unit);
 
@@ -1354,7 +1349,8 @@ run_advanced_units()
 	  unit->size = 1;
 	oldsize = unit->size;
 
-	/* Make sure the city's side can see everything in visible cells within its reach. */
+	/* Make sure the city's side can see everything in visible
+           cells within its reach. */
 	for_all_cells_within_reach(unit, x, y) {
 	    if (!inside_area(x, y))
 		continue;
@@ -1365,6 +1361,9 @@ run_advanced_units()
 	if (!nummtypes)
 	  continue;
 
+	if (!user_defined())
+	  allocate_area_users();
+
 	/* Make sure landuse is optimize before collecting materials. */
 	allocate_used_cells(unit);
 
@@ -1493,15 +1492,15 @@ run_advanced_units()
 int
 production_at(int x, int y, int m)
 {
-    int prod, t;
+    int prod, c;
 
     prod = tm_production(terrain_at(x, y), m);
-    for_all_terrain_types(t) {
-	if (t_is_connection(t)
-	    && aux_terrain_defined(t)
-	    && any_connections_at(x, y, t)
-	    && tm_production(t, m) > 0)
-	  prod += tm_production(t, m);
+    /* Add bonuses for connection types. */
+    for_all_connection_types(c) {
+	if (aux_terrain_defined(c)
+	    && any_connections_at(x, y, c)
+	    && tm_production(c, m) > 0)
+	  prod += tm_production(c, m);
     }
     return prod;
 }
@@ -1940,27 +1939,29 @@ allocate_used_cells(Unit *unit)
     }
 }
 
+/* Can't use a cell occupied by an enemy unit. */
+
 void
 kick_out_enemy_users(Side *side, int x, int y)
 {
     Unit *unit;
-	
+
+    /* Nothing to do if no user layer. */
+    if (!user_defined())
+      return;
     /* Return if nobody is using the cell. */
     if (user_at(x, y) == NOUSER)
       return;
-
     /* Else find the user. */
     unit = find_unit(user_at(x, y));
-
     /* Return if the user belongs to the same or a friendly side. */
-    if (unit && trusted_side(unit->side, side))
+    if (in_play(unit) && trusted_side(unit->side, side))
       return;
 
     /* Mark the cell as unused. */
     set_user_at(x, y, NOUSER);
-	
     /* Reduce the former user's cells. */
-    if (unit)
+    if (in_play(unit))
       unit->usedcells -= 1;	
 }
 
@@ -2004,6 +2005,30 @@ auto_pick_new_research(Unit *unit)
       unit->curadvance = NOADVANCE;
 }
 
+/* Now picks new advance at random rather than by number. */
+
+void
+auto_pick_side_research(Side *side)
+{
+    int a;
+    int type[MAXUTYPES];
+    int numtypes = 0;
+
+    /* Get researchable advance types. */
+    for_all_advance_types(a) {
+	if (has_advance_to_research(side, a)
+	    && !has_advance(side, a)) {
+	    /* Add to list of researchable advances. */
+	    type[numtypes++] = a;
+	}
+    }
+    if (numtypes)
+      /* Pick one of them at random. */
+      side->research_topic = type[xrandom(numtypes)];
+    else
+      side->research_topic = NOADVANCE;
+}
+
 int
 auto_pick_new_build_task(Unit *unit)
 {
