@@ -2432,7 +2432,7 @@ change_people_side_around(int x, int y, int u, Side *side)
    remove so as to bring the numbers back in line. */
 
 static void
-run_people_limits()
+run_people_limits(void)
 {
     int m, t, x, y, num, ratio, amt, newamt;
 
@@ -2478,8 +2478,7 @@ run_people_limits()
 }
 
 void
-update_cell_display_all_sides(x, y, flags)
-int x, y, flags;
+update_cell_display_all_sides(int x, int y, int flags)
 {
     Side *side;
 
@@ -2495,8 +2494,9 @@ int x, y, flags;
 /* See if it's time for any scheduled arrivals to appear. */
 
 static void
-run_appearances()
+run_appearances(void)
 {
+    char abuf[BUFSIZE];
     int curturn, nx, ny, nw, nh, nx0, ny0, nx1, ny1, tries;
     int need_rescan, scan_tries;
     Unit *unit, *transport;
@@ -2516,6 +2516,9 @@ run_appearances()
       return;
     Dprintf("Running appearances\n");
     curturn = g_turn();
+    /* The unit may be blocked from appearing for some reason, such
+       as a stacking limit, so scan the list of appearances several
+       times. */
     need_rescan = TRUE;
     scan_tries = 5;
     while (need_rescan && scan_tries-- > 0) {
@@ -2532,7 +2535,8 @@ run_appearances()
 		nw = unit_appear_var_x(unit);  nh = unit_appear_var_y(unit);
 		tries = ((nw >= 0 && nh >= 0) ? 100 : 1);
 		while (tries-- > 0) {
-		    if (nw >= 0 && nh >= 0 && random_point_in_area(nx0, ny0, nw, nh, &nx1, &ny1)) {
+		    if (nw >= 0 && nh >= 0
+			&& random_point_in_area(nx0, ny0, nw, nh, &nx1, &ny1)) {
 			nx = nx1;  ny = ny1;
 		    }
 		    /* Do the usual steps to place the unit. */
@@ -2559,11 +2563,16 @@ run_appearances()
 		if (inside_area(unit->x, unit->y)) {
 		    init_unit_actorstate(unit, FALSE);
 		    init_unit_plan(unit);
+		    /* (should use generic event notification mech? */
+		    destination_desc(abuf, unit->side, unit,
+				     unit->x, unit->y, 0);
+		    notify(unit->side, "%s has appeared at %s.",
+			   unit_handle(unit->side, unit), abuf);
 		} else {
 		    /* We've got a problem, put the unit back. */
 		    unit->cp = (- unit->cp);
-		    /* Go around again, perhaps a plausible transport appeared during
-		       this pass. */
+		    /* Go around again, perhaps a plausible transport
+		       appeared during this pass. */
 		    need_rescan = TRUE;
 		}
 	    }
@@ -2574,8 +2583,9 @@ run_appearances()
 /* Perform any prescheduled disappearances. */
 
 static void
-run_disappearances()
+run_disappearances(void)
 {
+    char buf1[BUFSIZE], buf2[BUFSIZE];
     int curturn;
     Unit *unit;
 
@@ -2602,8 +2612,12 @@ run_disappearances()
     	if (in_play(unit)
 	    && unit_disappear_turn(unit) >= 0
 	    && unit_disappear_turn(unit) <= curturn) {
+	    strcpy(buf1, unit_handle(unit->side, unit));
+	    destination_desc(buf2, unit->side, unit, unit->x, unit->y, 0);
 	    /* (should eject occupants first if possible) */
 	    kill_unit(unit, H_UNIT_LEFT_WORLD);
+	    /* (should use generic event notification mech? */
+	    notify(unit->side, "%s has disappeared from %s.", buf1, buf2);
 	}
     }
 }
@@ -2702,7 +2716,7 @@ run_hp_recovery(void)
 /* Some types of units can repair others without doing actions. */
 
 static void
-run_auto_repair()
+run_auto_repair(void)
 {
     int u1, u2, u, hpmax, oldhp;
     Unit *unit, *occ;
@@ -2735,7 +2749,8 @@ run_auto_repair()
 		if (uu_auto_repair(u2, u1) > 0) {
 		    will_be_auto_repaired[u1] = TRUE;
 		    auto_repair_range_max[u1] =
-		      max(auto_repair_range_max[u1], uu_auto_repair_range(u2, u1));
+		      max(auto_repair_range_max[u1],
+			  uu_auto_repair_range(u2, u1));
 		}
 	    }
 	}
@@ -2746,28 +2761,33 @@ run_auto_repair()
 	    u = unit->type;
 	    hpmax = u_hp(u);
 	    /* (should only do for one part of multi-part unit?) */
-	    if (unit->hp < u_hp(u) && will_be_auto_repaired[u]) {
+	    if (unit->hp < hpmax && will_be_auto_repaired[u]) {
 		oldhp = unit->hp;
 		if (auto_repair_range_max[u] < 0) {
-		    if (unit->transport && uu_auto_repair(unit->transport->type, u) > 0) {
+		    if (unit->transport
+			&& uu_auto_repair(unit->transport->type, u) > 0) {
 			auto_repair_unit(unit->transport, unit);
-		    /* If unit is inside a transport inside a base, also let the base 
-		    repair the unit. */
 		    } else if (unit->transport
-		    	    && unit->transport->transport
-		    	    && uu_auto_repair(unit->transport->transport->type, u) > 0) {
+			       && unit->transport->transport
+			       && uu_auto_repair(unit->transport->transport->type,
+						 u) > 0) {
+			/* If unit is inside a transport inside a base,
+			   also let the base repair the unit. */
 			auto_repair_unit(unit->transport->transport, unit);
 		    } else {
-			/* Also let units within transports repair a base if the can. */
+			/* Also let units within transports repair a
+                           base if they can. */
 			for_all_occs_with_occs(unit, occ) {
-			    if (is_active(occ) && uu_auto_repair(occ->type, u) > 0) {
+			    if (is_active(occ)
+				&& uu_auto_repair(occ->type, u) > 0) {
 				auto_repair_unit(occ, unit);
 			    }
 			}
 		    }
 		} else {
 		    tmpunit = unit;
-		    apply_to_area(unit->x, unit->y, auto_repair_range_max[u], auto_repair_from_here);
+		    apply_to_area(unit->x, unit->y, auto_repair_range_max[u],
+				  auto_repair_from_here);
 		}
 		/* Inform the player if the unit's hp changed. */
 		if (unit->hp != oldhp) {
@@ -2778,14 +2798,14 @@ run_auto_repair()
     }
 }
 
-/* Try to auto-repair using anything found at the given location. */
+/* Try to auto-repair the tmpunit using anything found at the given
+   location.  Both top-level units and occupants will be tried. */
 
 static void
-auto_repair_from_here(x, y)
-int x, y;
+auto_repair_from_here(int x, int y)
 {
     int dist;
-    Unit *unit2;
+    Unit *unit2, *occ;
 
     /* Skip out if we're all repaired. */
     if (tmpunit->hp == u_hp(tmpunit->type)) {
@@ -2793,6 +2813,7 @@ int x, y;
 	return;
     }
     for_all_stack(x, y, unit2) {
+	/* Try a unit at the location. */
 	if (unit2 != tmpunit
 	    && trusted_side(unit2->side, tmpunit->side)
 	    && uu_auto_repair(unit2->type, tmpunit->type) > 0) {
@@ -2801,20 +2822,32 @@ int x, y;
 		auto_repair_unit(unit2, tmpunit);
 	    }
 	}
+	/* Try all the occupants we can find. */
+	for_all_occs_with_occs(unit2, occ) {
+	    if (occ != tmpunit
+		&& trusted_side(occ->side, tmpunit->side)
+		&& uu_auto_repair(occ->type, tmpunit->type) > 0) {
+		dist = distance(tmpunit->x, tmpunit->y, occ->x, occ->y);
+		if (dist <= uu_auto_repair_range(occ->type, tmpunit->type)) {
+		    auto_repair_unit(occ, tmpunit);
+		}
+	    }
+	}
     }
 }
 
-/* Do the actual auto-repair. */
+/* Do the actual auto-repair.  This may be called on a healthy unit. */
 
 static void
-auto_repair_unit(unit, unit2)
-Unit *unit, *unit2;
+auto_repair_unit(Unit *unit, Unit *unit2)
 {
     int u = unit->type, u2 = unit2->type, m, repair;
 
     /* Check the basic restrictions on repair. */
+    /* Repairer itself might be too damaged to do anything. */
     if (unit->hp < uu_hp_to_repair(u, u2))
       return;
+    /* We must have any required materials. */
     for_all_material_types(m) {
 	if (unit->supply[m] < um_to_repair(u, m))
 	  return;
@@ -2823,22 +2856,6 @@ Unit *unit, *unit2;
     add_to_unit_hp(unit2, prob_fraction(repair));
 }
 
-/* (should move to unit.c?) */
-
-void
-add_to_unit_hp(Unit *unit, int hp)
-{
-    int hpmax;
-
-    unit->hp += hp;
-    hpmax = u_hp(unit->type);
-    if (unit->hp > hpmax)
-      unit->hp = hpmax;
-    unit->hp2 += hp;
-    if (unit->hp2 > hpmax)
-      unit->hp2 = hpmax;
-}
-
 /* Some types of units recover lost morale spontaneously. */
 
 static void
