@@ -1,5 +1,5 @@
 /* Sides in Xconq.
-   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ static int mistaken_type(int u2);
 
 Side *sidelist;
 
-/* Pointer to the side representing independence. */
+/* Pointer to the side representing independent units. */
 
 Side *indepside;
 
@@ -95,15 +95,17 @@ Doctrine *last_doctrine;
 
 int next_doctrine_id;
 
-/* Init side machinery. Don't fill in indepside yet since numutypes etc. may 
-not be defined.  */
+/* Init side machinery. Don't fill in indepside yet since numutypes
+   etc. may not be defined.  */
 
 void
 init_sides(void)
 {
     /* Set up the list of sides. */
     sidelist = lastside = (Side *) xmalloc(sizeof(Side));
-    /* The independent units' side will be the first one, is always created. */
+    /* The independent units' side will be the first one in the list,
+       is always created.  It cannot be filled in yet, because the
+       numbers of the various types is not yet known. */
     indepside = sidelist;
     /* Note: indepside is included in numtotsides, but not numsides. */
     numtotsides = 0;
@@ -143,8 +145,8 @@ create_side(void)
 	newside->colorscheme = "black,black,white";
 	newside->emblemname = "none";
     } else {
-    /* Else allocate a new side object and increase numsides. */
-    newside = (Side *) xmalloc(sizeof(Side));
+	/* Else allocate a new side object and increase numsides. */
+	newside = (Side *) xmalloc(sizeof(Side));
 	/* numsides does not include indepside, thus increment it here. */
     	++numsides;
     }
@@ -192,6 +194,7 @@ create_side(void)
    	 newside->advance = (short *) xmalloc(numatypes * sizeof(short));
     	 newside->numadvances = 0;
 	 newside->research_topic = NOADVANCE;
+	 newside->autoresearch = FALSE;
     }
     if (nummtypes > 0) {
 	/* Set up the side's supply of materials. */
@@ -226,8 +229,8 @@ create_side(void)
     newside->next = NULL;
     /* Important to avoid the indepside->next = indepside loop! */
     if (newside != indepside) {
-    lastside->next = newside;
-    lastside = newside;
+	lastside->next = newside;
+	lastside = newside;
     }
     init_side_unithead(newside);
     /* numtotsides also includes indepside. */
@@ -235,8 +238,9 @@ create_side(void)
     return newside;
 }
 
-/* To make the double links work, we have to have one pseudo-unit to serve
-   as a head.  This unit should not be seen by any outside code. */
+/* To make the double links work, we have to have one pseudo-unit to
+   serve as a head.  This unit should not be seen by any outside
+   code. */
 
 void
 init_side_unithead(Side *side)
@@ -270,8 +274,10 @@ init_doctrine(Side *side)
 	side->default_doctrine = new_doctrine(0);
     }
     if (side->udoctrine == NULL) {
-	/* Make each individual unit doctrine point to the generic doctrine by default. */
-	side->udoctrine = (Doctrine **) xmalloc(numutypes * sizeof(Doctrine *));
+	/* Make each individual unit doctrine point to the generic
+           doctrine by default. */
+	side->udoctrine =
+	  (Doctrine **) xmalloc(numutypes * sizeof(Doctrine *));
     }
     for_all_unit_types(u) {
 	if (side->udoctrine[u] == NULL)
@@ -1245,6 +1251,16 @@ int value;
     side->autofinish = value;
 }
 
+/* What interfaces should use to tweak the autoresearch flag. */
+
+void
+set_autoresearch(side, value)
+Side *side;
+int value;
+{
+    side->autoresearch = value;
+}
+
 /* Being at war requires only ones of the sides to consider itself so. */
 
 /* (Should the other side's relationships be tweaked also?) */
@@ -1970,7 +1986,7 @@ calc_coverage(Side *side)
     }
 }
 
-/* (what is this for?) */
+/* Look for and clear out any bogus view data. */
 
 void
 reset_all_views(void)
@@ -1990,6 +2006,7 @@ reset_view(Side *side)
     int x, y, uview;
 
     for_all_cells(x, y) {
+	/* Remove any leftover images of our own units. */
 	if (cover(side, x, y) == 0
 	    && ((uview = unit_view(side, x, y)) != EMPTY)
 	    && vside(uview) == side_number(side)) {
@@ -1999,10 +2016,7 @@ reset_view(Side *side)
 }
 
 void
-react_to_seen_unit(side, unit, x, y)
-Side *side;
-Unit *unit;
-int x, y;
+react_to_seen_unit(Side *side, Unit *unit, int x, int y)
 {
     int uview, eu;
     Unit *eunit;
