@@ -336,12 +336,20 @@ download_to_player(Player *player)
     /* If errors, should set player rid back to zero */
 }
 
+/* Given the id of a remote program that has just connected,
+   download our own current state, as a module. */
+
 void
 download_game_module(int rid)
 {
     int rslt;
     Module *module;
 
+    /* The indepside might not have been filled in yet (such as when
+       connecting before sides/players have been set up), but we need
+       it to be correct before going into write_game_module. */
+    if (numtotsides == 0)
+      create_side();
     /* Record the rid in a global so the module-writing code knows
        where to send all the packets. */
     tmprid = rid;
@@ -542,7 +550,8 @@ net_resign_game(Side *side, Side *side2)
 	resign_game(side, side2);
     }
     if (numremotes > 0) {
-	broadcast_side_property(side, "resign", side_number(side2));
+      broadcast_side_property(side, "resign",
+			      (side2 ? side_number(side2) : 0));
     }
 }
 
@@ -691,6 +700,17 @@ net_set_autofinish(Side *side, int value)
     }
 }
 
+void
+net_set_autoresearch(Side *side, int value)
+{
+    if (my_rid == master_rid) {
+	set_autoresearch(side, value);
+    }
+    if (numremotes > 0)  {
+	broadcast_side_property(side, "ar", value);
+    }
+}
+
 void
 net_set_willing_to_save(Side *side, int flag)
 {
@@ -2380,6 +2400,10 @@ receive_side_prop(char *str)
 	str += 3;
 	val = strtol(str, &nstr, 10);
 	set_autofinish(side, val);
+    } else if (strncmp(str, "ar ", 3) == 0) {
+	str += 3;
+	val = strtol(str, &nstr, 10);
+	set_autoresearch(side, val);
     } else if (strncmp(str, "ai ", 3) == 0) {
 	str += 3;
 	set_side_ai(side, str);
@@ -2426,7 +2450,7 @@ receive_side_prop(char *str)
     } else if (strncmp(str, "resign ", 7) == 0) {
 	str += 7;
 	val = strtol(str, &nstr, 10);
-	resign_game(side, side_n(val));
+	resign_game(side, (val ? side_n(val) : NULL));
     } else if (strncmp(str, "save ", 5) == 0) {
 	str += 5;
 	val = strtol(str, &nstr, 10);
