@@ -1,5 +1,5 @@
 /* Graphics support not specific to any Xconq interface.
-   Copyright (C) 1992-1999 Stanley T. Shebs.
+   Copyright (C) 1992-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -15,20 +15,12 @@ any later version.  See the file COPYING.  */
    all new graphical interfaces use these. */
 
 #include "conq.h"
+extern char *apparent_unit_handle(Side *side, Unit *unit, Side *side2);
 #include "kpublic.h"
 #include "ai.h"
 #include "imf.h"
 #include "ui.h"
 
-#ifdef MAC /* temporary */
-#ifdef NEW_HEADERS
-#include <MacTypes.h>
-#else
-#include <Types.h>
-#endif /* NEW_HEADERS */
-#include <Resources.h>
-#endif /* MAC */
-
 extern int error_is_bug;
 
 static void compute_q(void);
@@ -220,8 +212,7 @@ module_name_compare(CONST void *a1, CONST void *a2)
 }
 
 static int
-special_strcmp(str1, str2)
-char *str1, *str2;
+special_strcmp(char *str1, char *str2)
 {
     if (strcmp(str1, second_game_name) == 0) {
 	if (strcmp(str2, second_game_name) == 0)
@@ -239,9 +230,9 @@ char *str1, *str2;
 static int max_possible_games;
 
 void
-collect_possible_games()
+collect_possible_games(void)
 {
-    int len, numresources;
+    int len;
     char *modulename = NULL, *modulecontents = NULL;
     Obj *lis;
     Module *module, *basemodule;
@@ -249,7 +240,7 @@ collect_possible_games()
     int startline = 0, endline = 0;
 
     if (numgames == 0 && numutypes == 0 /* !game_already_loaded() */) {
-	len = numresources = 0;
+	len = 0;
 	lis = lispnil;
 	fp = open_library_file("game.dir");
 	if (fp != NULL) {
@@ -261,10 +252,7 @@ collect_possible_games()
 	    }
 	    fclose(fp);
 	}
-#ifdef MAC
-	numresources = CountResources('XCgm');
-#endif /* MAC */
-	max_possible_games = 2 + (len + numresources) * 2;
+	max_possible_games = 2 + len * 2;
 	/* Make enough room to record all the possible games. */
 	possible_games =
 	  (Module **) xmalloc(max_possible_games * sizeof(Module *));
@@ -291,43 +279,6 @@ collect_possible_games()
 		}
 	    }
 	}
-#ifdef MAC
-	{
-	  int i;
-	  Handle modulehandle;
-	  short moduleid;
-	  ResType restype;
-	  Str255 resname;
-
-	  /* Pick up game modules that are specified as resources. */
-	  for (i = 0; i < numresources; ++i) {
-	    modulehandle = GetIndResource('XCgm', i + 1);
-	    /* (should test for resource validity?) */
-	    if (0 /* size > 0 */) {
-		/* set modulecontents from resource */
-		modulecontents = NULL;
-	    }
-	    /* Try to pick up module name from its resource name, otherwise
-	       assume its name in its content. */
-	    GetResInfo(modulehandle, &moduleid, &restype, resname);
-	    if (resname[0] > 0) {
-		resname[resname[0]+1] = '\0';
-		modulename = copy_string((char *) resname+1);
-	    } else {
-		modulename = NULL;
-	    }
-	    if (modulename != NULL) {
-		module = get_game_module(modulename);
-		module->contents = modulecontents;
-		add_to_possible_games(module);
-		if (module->basemodulename != NULL) {
-		    basemodule = get_game_module(module->basemodulename);
-		    add_to_possible_games(basemodule);
-		}
-	    }
-	  }
-        }
-#endif /* MAC */
 	if (numgames > 1) {
 	    /* Sort all but the first game into alphabetical order
 	       by displayed name. */
@@ -340,8 +291,7 @@ collect_possible_games()
 /* Load a game's description and add it to the list of games. */
 
 void
-add_to_possible_games(module)
-Module *module;
+add_to_possible_games(Module *module)
 {
     int i;
 
@@ -365,9 +315,7 @@ Module *module;
    centered on. */
 
 void
-pick_a_focus(side, xp, yp)
-Side *side;
-int *xp, *yp;
+pick_a_focus(Side *side, int *xp, int *yp)
 {
     int tmpx, tmpy, dist, closest = area.maxdim;
     Unit *unit, *closestunit = NULL;
@@ -409,7 +357,7 @@ int *xp, *yp;
 }
 
 int
-num_active_displays()
+num_active_displays(void)
 {
     int n = 0;
     Side *side;
@@ -731,9 +679,7 @@ int sx, sy, sw, sh, *sxp, *syp, *swp, *shp;
 /* Scale one viewport box to its position in another. */
 
 void
-scale_vp(vp, vp2, sxp, syp, swp, shp)
-VP *vp, *vp2;
-int *sxp, *syp, *swp, *shp;
+scale_vp(VP *vp, VP *vp2, int *sxp, int *syp, int *swp, int *shp)
 {
     *sxp = (vp2->sx * vp->hw) / vp2->hw - vp->sx;
     *syp = (vp2->sy * vp->hch) / vp2->hch - vp->sy;
@@ -742,9 +688,7 @@ int *sxp, *syp, *swp, *shp;
 }
 
 int
-nearest_cell(vp, sx, sy, xp, yp, xfp, yfp)
-VP *vp;
-int sx, sy, *xp, *yp, *xfp, *yfp;
+nearest_cell(VP *vp, int sx, int sy, int *xp, int *yp, int *xfp, int *yfp)
 {
     int sxadj, syadj, sxfrac, syflipped, syfrac;
 
@@ -798,9 +742,7 @@ int sx, sy, *xp, *yp, *xfp, *yfp;
 }
 
 int
-nearest_boundary(vp, sx, sy, xp, yp, dirp)
-VP *vp;
-int sx, sy, *xp, *yp, *dirp;
+nearest_boundary(VP *vp, int sx, int sy, int *xp, int *yp, int *dirp)
 {
     int sx2, sy2, ydelta, hexslope;
 
@@ -823,11 +765,8 @@ int sx, sy, *xp, *yp, *dirp;
 }
 
 Unit *
-find_unit_or_occ(side, vp, unit, usx, usy, usw, ush, sx, sy)
-Side *side;
-VP *vp;
-Unit *unit;
-int usx, usy, usw, ush, sx, sy;
+find_unit_or_occ(Side *side, VP *vp, Unit *unit, int usx, int usy,
+		 int usw, int ush, int sx, int sy)
 {
     int usx1, usy1, usw1, ush1;
     Unit *occ, *rslt;
@@ -857,10 +796,7 @@ int usx, usy, usw, ush, sx, sy;
 }
 
 Unit *
-find_unit_at(side, vp, x, y, sx, sy)
-Side *side;
-VP *vp;
-int x, y, sx, sy;
+find_unit_at(Side *side, VP *vp, int x, int y, int sx, int sy)
 {
     int usx, usy, usw, ush;
     Unit *unit, *rslt;
@@ -875,11 +811,7 @@ int x, y, sx, sy;
 }
 
 int
-nearest_unit(side, vp, sx, sy, unitp)
-Side *side;
-VP *vp;
-int sx, sy;
-Unit **unitp;
+nearest_unit(Side *side, VP *vp, int sx, int sy, Unit **unitp)
 {
     int x, y;
     
@@ -1113,14 +1045,13 @@ static int any_borders_in_dir(int x, int y, int dir);
 static int
 any_borders_in_dir(int x, int y, int dir)
 {
-    int t;
+    int b;
 
     if (!any_aux_terrain_defined())
       return FALSE;
-    /* (should iterate only over border types) */
-    for_all_terrain_types(t) {
-	if (t_is_border(t)
-	    && border_at(x, y, dir, t))
+    for_all_border_types(b) {
+	/* Note that border_at tests for layer existence. */
+	if (border_at(x, y, dir, b))
 	  return TRUE;
     }
     return FALSE;
@@ -1253,32 +1184,28 @@ int sx1, sy1, sx2, sy2, i, n, *xx, *yy, *dx, *dy;
    block==2  :  don't write over visible units. */
 
 void
-place_feature_legends(leg, nf, side, orient, block)
-Legend *leg;
-int nf;
-Side *side;
-int orient, block;
+place_feature_legends(Legend *legend, int nf, Side *side, int orient,
+		      int block)
 {
-    int x, y, x1, y1, dx, dy, f, i, i3, id, d, nd, d1, dc;
+    int x, y, x1, y1, dx, dy, f, i, i3, j, d, ndirstotry, d1, dc;
     double dist;
-    static int ndt[] = { 1, 3, 6 },
-    dt[] = { EAST, SOUTHEAST, NORTHEAST, NORTHEAST, SOUTHEAST, EAST },
-    da[] = { 0, -60, 60, 90, -30, 30 };
+    static int numdirstotry[] = { 1, 3, 6 };
+    static int dirstotry[] =
+    { EAST, SOUTHEAST, NORTHEAST, NORTHEAST, SOUTHEAST, EAST };
+    static int da[] = { 0, -60, 60, 90, -30, 30 };
     unsigned char *auxf_layer, dmask;
     
     if (!features_defined())
       return;
     
     orient = min(orient, 2);
-    nd = ndt[orient];
+    ndirstotry = numdirstotry[orient];
     
     for (f = 1; f <= nf; f++) {
-	leg[f-1].ox = 0;
-	leg[f-1].oy = 0;
-	leg[f-1].dx = 0;
-	leg[f-1].dy = 0;
-	leg[f-1].angle = 0;
-	leg[f-1].dist  = -1;
+	legend[f-1].ox = 0;  legend[f-1].oy = 0;
+	legend[f-1].dx = 0;  legend[f-1].dy = 0;
+	legend[f-1].angle = 0;
+	legend[f-1].dist  = -1;
     }
     
     /* Speedup: in auxf_layer we keep this information:
@@ -1291,7 +1218,7 @@ int orient, block;
     auxf_layer = (unsigned char *)
       malloc(area.height * area.width * sizeof(unsigned char));
     
-    if (!auxf_layer)
+    if (auxf_layer == NULL)
       return;
     
     for_all_cells(x, y) {
@@ -1308,24 +1235,24 @@ int orient, block;
 	if (f < 1 || f > nf)
 	  continue;
 
-	for (id = 0; id < nd; id++) {
-	    dmask = '\001' << id;
-	    d = dt[id];
-	    d1 = ((id < 3) ? d : left_dir(left_dir(d)));
+	for (j = 0; j < ndirstotry; j++) {
+	    dmask = '\001' << j;
+	    d = dirstotry[j];
+	    d1 = ((j < 3) ? d : left_dir(left_dir(d)));
 	    x1 = x;  y1 = y;
 	    dx = dy = 0;
 	    i3 = i = 0;
 	    dist = 0;
 	    while (raw_feature_at(x1, y1) == f &&
 		   !(aref(auxf_layer, x1, y1) &
-		     ((id < 3 || !i3) ? ('\200' | dmask) : '\200'))) {
-		if (dist > leg[f-1].dist && (id < 3 || !i3)) {
-		    leg[f-1].ox =  x;  leg[f-1].oy =  y;
-		    leg[f-1].dx = dx;  leg[f-1].dy = dy;
-		    leg[f-1].angle = da[id];
-		    leg[f-1].dist  = dist;
+		     ((j < 3 || !i3) ? ('\200' | dmask) : '\200'))) {
+		if (dist > legend[f-1].dist && (j < 3 || !i3)) {
+		    legend[f-1].ox = x;  legend[f-1].oy = y;
+		    legend[f-1].dx = dx;  legend[f-1].dy = dy;
+		    legend[f-1].angle = da[j];
+		    legend[f-1].dist  = dist;
 		}
-		if (id < 3 || !i3) {
+		if (j < 3 || !i3) {
 		    auxf_layer[area.width * y1 + x1] |= dmask;
 		}
 		dc = ((i3 == 1) ? d1 : d);
@@ -1333,7 +1260,7 @@ int orient, block;
 		x1 = wrapx(x1 + dirx[dc]);
 		dy += diry[dc];
 		y1 += diry[dc];
-		dist += ((id < 3) ? 1.0 : (i3 ? 0.5 * 1.73205080756888 : 0.0));
+		dist += ((j < 3) ? 1.0 : (i3 ? 0.5 * 1.73205080756888 : 0.0));
 		++i;
 		i3 = i % 3;
 	    }
@@ -1344,8 +1271,7 @@ int orient, block;
 }
 
 static int
-blocking_utype(u, block)
-int u, block;
+blocking_utype(int u, int block)
 {
     if (u == NONUTYPE || block == 0)
       return 0;
@@ -1355,26 +1281,48 @@ int u, block;
     return ((u_already_seen(u) > 99 || u_see_always(u)) && !mobile(u));
 }
 
+/* Set the spacing of the meridians of latitude and longitude. */
+
 void
-plot_meridians(vp, line_callback, text_callback)
-VP *vp;
-void (*line_callback)(int x1, int y1, int x1f, int y1f,
-			       int x2, int y2, int x2f, int y2f);
-void (*text_callback)(int x1, int y1, int x1f, int y1f, char *str);
+set_meridian_interval(VP *vp, int interval)
+{
+    vp->meridian_interval = interval;
+    /* Don't want to compute the lat/lon label spacing yet, we don't
+       necessarily have the window's size recorded in the viewport. */
+    vp->lat_label_lon_interval = vp->lon_label_lat_interval = 0;
+}
+
+/* Compute the location of meridians desired for the given viewport
+   and render the lines and labels using the two callback
+   functions. */
+
+/* (should attempt to draw the lines all the way to the edge of
+   the area, but formulas more complicated) */
+
+void vp_latlong(VP *vp, int *lat1p, int *lon1p, int *lat2p, int *lon2p);
+
+void
+plot_meridians(VP *vp,
+	       void (*line_callback)(int x1, int y1, int x1f, int y1f,
+				     int x2, int y2, int x2f, int y2f),
+	       void (*text_callback)(int x1, int y1, int x1f, int y1f,
+				     char *str))
 {
-    int xxmin, ymin, xmax, ymax;
     int lat1, lon1, lat2, lon2, latmin, latmax, lonmin, lonmax, incr, lat, lon;
     int latmid, lonmid, xmid, ymid, xmidf, ymidf;
     int x1, y1, x2, y2, x1f, y1f, x2f, y2f;
     int sx1, sy1, sx2, sy2;
+    int latdeg, latminu, londeg, lonminu;
+    char minbuf[10];
 
-    incr = vp->latlong_interval;
+    incr = vp->meridian_interval;
     /* Draw only if the interval is not too small. */
     xy_to_latlong(area.halfwidth, area.height - 2, 0, 0, &lat, &lon);
     latlong_to_xy(lat, lon, &x1, &y1, &x1f, &y1f);
     latlong_to_xy(lat - incr, lon, &x2, &y2, &x2f, &y2f);
-    /* If a single interval down from the top middle is off the map, then there
-       won't be any lines to plot anyway, so OK to escape. */
+    /* If a single interval down from the top middle of the area is
+       off the map, then there won't be any lines to plot anyway, so
+       OK to escape. */
     if (!in_area(x2, y2))
       return;
     xform_cell_fractional(vp, x1, y1, x1f, y1f, &sx1, &sy1);
@@ -1382,25 +1330,34 @@ void (*text_callback)(int x1, int y1, int x1f, int y1f, char *str);
     /* Don't draw if lines would be really closely spaced. */
     if (sy2 - sy1 < 20)
       return;
-    if (nearest_cell(vp, 0, vp->pxh, &xxmin, &ymin, NULL, NULL)
-	&& nearest_cell(vp, vp->pxw, 0, &xmax, &ymax, NULL, NULL)) {
-	xy_to_latlong(xxmin, ymin, 0, 0, &lat1, &lon1);
-	xy_to_latlong(xmax, ymax, 0, 0, &lat2, &lon2);
-    } else if (area.width < world.circumference) {
-	xxmin = 0;  ymin = 0;
-	xmax = area.width - 1;  ymax = area.height - 1;
-	xy_to_latlong(xxmin, ymin, 0, 0, &lat1, &lon1);
-	xy_to_latlong(xmax, ymax, 0, 0, &lat2, &lon2);
-    } else {
-	lat1 = -75 * 60 +  incr - 1;   lon1 = -180 * 60 +  incr - 1;
-	lat2 =  75 * 60 - (incr - 1);  lon2 =  180 * 60 - (incr - 1);
-    }
+    /* Find the closest meridians that will be visible in the
+       viewport. */
+    vp_latlong(vp, &lat1, &lon1, &lat2, &lon2);
+    /* Round to even multiples of the meridian interval. */
     latmin = (lat1 / incr) * incr;
     latmax = (lat2 / incr) * incr + incr;
     lonmin = (lon1 / incr) * incr;
     lonmax = (lon2 / incr) * incr + incr;
     if (lonmax <= lonmin)
       lonmax += 21600;
+    vp_latlong(vp, &lat1, &lon1, &lat2, &lon2);
+    /* Determine the spacing of the text labels.  They should be far
+       enough apart so that only one set of each is visible at any
+       time, although it's more OK for two sets to appear than for
+       none to be visible. */
+    /* This algorithm assumes that we first do a draw of the whole
+       viewport before using smaller viewports for incremental
+       updates. */
+    if (vp->lon_label_lat_interval == 0) {
+	vp->lon_label_lat_interval = (abs(lat2 - lat1) / incr) * incr;
+	if (vp->lon_label_lat_interval == 0)
+	  vp->lon_label_lat_interval = 1;
+	vp->lat_label_lon_interval = (abs(lon2 - lon1) / incr) * incr;
+	if (vp->lat_label_lon_interval == 0)
+	  vp->lat_label_lon_interval = 1;
+    }
+    /* Draw each line as an individual segment, because meridians may
+       not be straight lines. */
     for (lat = latmax; lat >= latmin; lat -= incr) {
 	for (lon = lonmin; lon <= lonmax; lon += incr) {
 	    latlong_to_xy(lat, lon, &x1, &y1, &x1f, &y1f);
@@ -1416,58 +1373,52 @@ void (*text_callback)(int x1, int y1, int x1f, int y1f, char *str);
 		    }
 		}
 		if (text_callback) {
-		    if (lon == lonmin || lon == lonmax) {
-				char minbuf[10];
-	    		int latdeg, latminu;
-
-				lonmid = lon + incr / 2;
-				latlong_to_xy(lat, lonmid,
-					      &xmid, &ymid, &xmidf, &ymidf);
-				/* If adding the incr goes off the world, subtract
-				   instead. */
-				if (!in_area(xmid, ymid)) {
-				    lonmid = lon - incr / 2;
-				    latlong_to_xy(lat, lonmid,
-						  &xmid, &ymid, &xmidf, &ymidf);
-				}
-				/* Give up if this did not work. */
-				if (in_area(xmid, ymid)) {
-					latdeg = abs(lat) / 60;
-					latminu = abs(lat) % 60;
-					minbuf[0] = '\0';
-					if (latminu != 0)
-					  sprintf(minbuf, "%dm", latminu);
-					sprintf(tmpbuf, "%dd%s%c",
-						latdeg, minbuf, (lat >= 0 ? 'N' : 'S'));
-
-					(*text_callback)(xmid, ymid, xmidf, ymidf, tmpbuf);
-				}
+		    if (lon % vp->lat_label_lon_interval == 0) {
+			lonmid = lon + incr / 2;
+			latlong_to_xy(lat, lonmid,
+				      &xmid, &ymid, &xmidf, &ymidf);
+			/* If adding the incr goes off the world,
+			   subtract instead. */
+			if (!in_area(xmid, ymid)) {
+			    lonmid = lon - incr / 2;
+			    latlong_to_xy(lat, lonmid,
+					  &xmid, &ymid, &xmidf, &ymidf);
+			}
+			/* Give up if this did not work. */
+			if (in_area(xmid, ymid)) {
+			    latdeg = abs(lat) / 60;
+			    latminu = abs(lat) % 60;
+			    minbuf[0] = '\0';
+			    if (latminu != 0)
+			      sprintf(minbuf, "%dm", latminu);
+			    sprintf(tmpbuf, "%dd%s%c",
+				    latdeg, minbuf, (lat >= 0 ? 'N' : 'S'));
+			    (*text_callback)(xmid, ymid, xmidf, ymidf, tmpbuf);
+			}
 		    }
-		    if (lat == latmin || lat == latmax) {
-				char minbuf[10];
-	    		int londeg, lonminu;
-
-				latmid = lat + incr / 2;
-				latlong_to_xy(latmid, lon,
-					      &xmid, &ymid, &xmidf, &ymidf);
-				/* If adding the incr goes off the world, subtract
-				   instead. */
-				if (!in_area(xmid, ymid)) {
-				    latmid = lat - incr / 2;
-				    latlong_to_xy(latmid, lon,
-						  &xmid, &ymid, &xmidf, &ymidf);
-				}
-				/* Give up if this did not work. */
-				if (in_area(xmid, ymid)) {
-					londeg = abs(lon) / 60;
-					lonminu = abs(lon) % 60;
-					minbuf[0] = '\0';
-					if (lonminu != 0)
-					  sprintf(minbuf, "%dm", lonminu);
-					sprintf(tmpbuf, "%dd%s%c",
-						londeg, minbuf, (lon >= 0 ? 'E' : 'W'));
-					(*text_callback)(xmid, ymid, xmidf, ymidf, tmpbuf);
-			    }
+		    if (lat % vp->lon_label_lat_interval == 0) {
+			latmid = lat + incr / 2;
+			latlong_to_xy(latmid, lon,
+				      &xmid, &ymid, &xmidf, &ymidf);
+			/* If adding the incr goes off the world,
+			   subtract instead. */
+			if (!in_area(xmid, ymid)) {
+			    latmid = lat - incr / 2;
+			    latlong_to_xy(latmid, lon,
+					  &xmid, &ymid, &xmidf, &ymidf);
+			}
+			/* If this position is valid, draw the
+                           longitude. */
+			if (in_area(xmid, ymid)) {
+			    londeg = abs(lon) / 60;
+			    lonminu = abs(lon) % 60;
+			    minbuf[0] = '\0';
+			    if (lonminu != 0)
+			      sprintf(minbuf, "%dm", lonminu);
+			    sprintf(tmpbuf, "%dd%s%c",
+				    londeg, minbuf, (lon >= 0 ? 'E' : 'W'));
+			    (*text_callback)(xmid, ymid, xmidf, ymidf, tmpbuf);
+			}
 		    }
 		}
 #if 0 /* use to debug meridian plotting */
@@ -1482,9 +1433,20 @@ void (*text_callback)(int x1, int y1, int x1f, int y1f, char *str);
 }
 
 void
-set_contour_interval(vp, n)
-VP *vp;
-int n;
+vp_latlong(VP *vp, int *lat1p, int *lon1p, int *lat2p, int *lon2p)
+{
+    int xmin, ymin, xmax, ymax, xminf, yminf, xmaxf, ymaxf;
+
+    /* The implementation of nearest_cell still does the correct
+       calculation, even if the pixel position is not in the area. */
+    nearest_cell(vp, 0, vp->pxh, &xmin, &ymin, &xminf, &yminf);
+    nearest_cell(vp, vp->pxw, 0, &xmax, &ymax, &xmaxf, &ymaxf);
+    xy_to_latlong(xmin, ymin, xminf, yminf, lat1p, lon1p);
+    xy_to_latlong(xmax, ymax, xmaxf, ymaxf, lat2p, lon2p);
+}
+
+void
+set_contour_interval(VP *vp, int n)
 {
     int ncontours;
 
@@ -1496,6 +1458,7 @@ int n;
     ncontours = (area.maxelev - area.minelev) / vp->contour_interval;
     if (ncontours != vp->num_contours) {
 	vp->num_contours = ncontours;
+	/* (should free it) */
 	vp->linebuf = NULL;
     }
 }
@@ -1511,12 +1474,11 @@ int n;
    actual positions of each endpoint of the line segment, then draw it. */
 
 void
-contour_lines_at(vp, x, y, sx, sy, lines, numlinesp)
-VP *vp;
-int x, y, sx, sy, *numlinesp;
-LineSegment **lines;
+contour_lines_at(VP *vp, int x, int y, int sx, int sy, LineSegment **lines,
+		 int *numlinesp)
 {
-    int el, dir, x1, y1, sum, n, lowest, liq0, liq, ecor[NUMDIRS], ec;
+    int el, el2, dir, x1, y1, sum, n, lowest, liq0, liq, ecor[NUMDIRS], ec;
+    int maxel;
     int sxcor[NUMDIRS], sycor[NUMDIRS], sxc, syc;
     int power = vp->power;
     int ecorr, ecorl, sxcorr, sycorr, sxcorl, sycorl;
@@ -1528,7 +1490,13 @@ LineSegment **lines;
     if (vp->linebuf == NULL)
       vp->linebuf = (LineSegment *) xmalloc ((vp->num_contours + 2) * 2 * NUMDIRS * sizeof(LineSegment));
     *lines = vp->linebuf;
+    /* It's possible that the contour intervals have not yet been
+       adjusted to account for all elevations in the world, so be
+       sure to clip. */ 
+    maxel = area.minelev + vp->num_contours * vp->contour_interval;
     el = elev_at(x, y);
+    if (el > maxel)
+      el = maxel;
     sxc = sx + vp->hw / 2;  syc = sy + vp->hh / 2;
     /* Compute the elevation at each corner of the cell. */
     liq0 = t_liquid(terrain_at(x, y));
@@ -1538,16 +1506,22 @@ LineSegment **lines;
 	lowest = el;
 	liq = liq0;
 	if (point_in_dir(x, y, dir, &x1, &y1)) {
-	    sum += elev_at(x1, y1);
+	    el2 = elev_at(x1, y1);
+	    if (el2 > maxel)
+	      el2 = maxel;
+	    sum += el2;
 	    ++n;
-	    lowest = min(lowest, elev_at(x1, y1));
+	    lowest = min(lowest, el2);
 	    if (t_liquid(terrain_at(x1, y1)))
 	      liq = TRUE;
 	}
 	if (point_in_dir(x, y, left_dir(dir), &x1, &y1)) {
-	    sum += elev_at(x1, y1);
+	    el2 = elev_at(x1, y1);
+	    if (el2 > maxel)
+	      el2 = maxel;
+	    sum += el2;
 	    ++n;
-	    lowest = min(lowest, elev_at(x1, y1));
+	    lowest = min(lowest, el2);
 	    if (t_liquid(terrain_at(x1, y1)))
 	      liq = TRUE;
 	}
@@ -1755,9 +1729,9 @@ void
 oneliner(Side *side, VP *vp, int sx, int sy)
 {
     int x, y, xf, yf;
-    Unit *unit, *user;
+    Unit *unit, *unit2, *user;
     int t2, uview, u, s, ps = NOBODY, cs = NOBODY, dep, sayin = FALSE, userid;
-    char *peopdesc = NULL, *sidedesc, *str;
+    char *peopdesc = NULL, /* *sidedesc, */ *str;
     char descbuf[80], ctrlbuf[80], buf[BUFSIZE];
     Side *side2, *side3;
     Feature *feature;
@@ -1811,6 +1785,13 @@ oneliner(Side *side, VP *vp, int sx, int sy)
 	}
 	if (vp->show_all || units_visible(side, x, y)) {
 	    if (unit != NULL) {
+		if (unit->side != side) {
+		    if (ps != NOBODY && ps == side_number(unit->side)) {
+			peopdesc = "own";
+		    }
+		}
+		strcat(tmpbuf, unit_handle(side, unit));
+#if 0  /* semi-replication of unit_handle code */
 		if (unit->side != side) {
 		    sidedesc = side_adjective(unit->side);
 		    if (ps != NOBODY && ps == side_number(unit->side)) {
@@ -1836,6 +1817,7 @@ oneliner(Side *side, VP *vp, int sx, int sy)
 		if (Debug || DebugG || DebugM) {
 		    tprintf(tmpbuf, " #%d", unit->id);
 		}
+#endif
 		sayin = TRUE;
 	    }
 	} else {
@@ -1844,9 +1826,24 @@ oneliner(Side *side, VP *vp, int sx, int sy)
 		if (ps != NOBODY && ps == s) {
 		    peopdesc = "own";
 		}
-		strcat(tmpbuf, side_adjective(side_n(s)));
-		strcat(tmpbuf, " ");
-		strcat(tmpbuf, u_type_name(u));
+		/* Display the real name of a non-mobile unit,
+		   even if it's not in view coverage. */
+		unit = NULL;
+		for_all_stack(x, y, unit2) {
+		    if (unit2->type == u
+			&& (!mobile(u) || u_acp(u) == 0)) {
+			unit = unit2;
+			break;
+		    }
+		}
+		if (unit != NULL) {
+		    strcat(tmpbuf,
+			   apparent_unit_handle(side, unit, side_n(s)));
+		} else {
+		    strcat(tmpbuf, side_adjective(side_n(s)));
+		    strcat(tmpbuf, " ");
+		    strcat(tmpbuf, u_type_name(u));
+		}
 		sayin = TRUE;
 	    }
 	}
@@ -1886,7 +1883,7 @@ oneliner(Side *side, VP *vp, int sx, int sy)
     strcat(tmpbuf, " @");
     if (1 /* drawxy */) {
 	tprintf(tmpbuf, "%d,%d", x, y);
-    } else if (vp->draw_latlong) {
+    } else if (vp->draw_meridians) {
 	latlong_desc(descbuf, x, y, xf, yf, 3);
 	strcat(tmpbuf, descbuf);
     }
@@ -1903,7 +1900,7 @@ oneliner(Side *side, VP *vp, int sx, int sy)
 	    }
 	}
     }
-    if (1 /* drawxy */ && vp->draw_latlong) {
+    if (1 /* drawxy */ && vp->draw_meridians) {
 	latlong_desc(descbuf, x, y, xf, yf, 3);
 	strcat(tmpbuf, " (");
 	strcat(tmpbuf, descbuf);
@@ -1912,13 +1909,15 @@ oneliner(Side *side, VP *vp, int sx, int sy)
     if (user_defined()
 	&& ((userid = user_at(x, y)) != NOUSER)) {
 	user = find_unit(userid);
-	strcat(tmpbuf, " (used by ");
-	if (user->name)
-	  strcat(tmpbuf, user->name);
-	else
-	  sprintf(tmpbuf+strlen(tmpbuf), "%s u#%d",
-		  u_type_name(user->type), user->id);
-	strcat(tmpbuf, ")");
+	if (in_play(user)) {
+	    strcat(tmpbuf, " (used by ");
+	    if (user->name != NULL)
+	      strcat(tmpbuf, user->name);
+	    else
+	      sprintf(tmpbuf+strlen(tmpbuf), "%s u#%d",
+		      u_type_name(user->type), user->id);
+	    strcat(tmpbuf, ")");
+	}
     }
     if (vp->draw_ai && side_has_ai(side)) {
 	strcat(tmpbuf, " ");
@@ -2303,9 +2302,12 @@ advance_into_cell(Side *side, Unit *unit, int x, int y, Unit *other)
     return TRUE;
 }
 
+/* For an advanced unit, toggle its use of the given cell. */
+
 void
 toggle_user_at(Unit *unit, int x, int y)
 {
+    Unit *unit2;
     Side *side2;
 
     /* Return if landuse is undefined. */
@@ -2315,17 +2317,22 @@ toggle_user_at(Unit *unit, int x, int y)
     if (!terrain_visible(unit->side, x, y))
       return;
     /* Return if the cell is used by another unit. */
-    if (user_at(x, y) != NOUSER && user_at(x, y) != unit->id)
-      return;
+    if (user_at(x, y) != NOUSER && user_at(x, y) != unit->id) {
+	/* (could be more helpful) */
+	notify(unit->side, "Cell at %d,%d is already in use", x, y);
+	return;
+    }
     /* Return if using maxcells and we are trying to add one more. */
-    if (unit->usedcells >= unit->maxcells && user_at(x, y) != unit->id)
-      return;
+    if (unit->usedcells >= unit->maxcells && user_at(x, y) != unit->id) {
+	notify(unit->side, "Cannot use any more cells");
+	return;
+    }
     /* Return if independents or untrusted side has a unit in the cell. */
     if (unit_at(x, y) != NULL) {
-	Unit *unit2;
-	for_all_stack(x, y, unit2)
-	  if (!trusted_side(unit->side, unit2->side))
-	    return;
+	for_all_stack(x, y, unit2) {
+	    if (!trusted_side(unit->side, unit2->side))
+	      return;
+	}
     }
     /* Toggle landuse by unit either on or off for the cell. */
     if (user_at(x, y) == NOUSER) {
@@ -2589,8 +2596,7 @@ int t;
 }
 
 ImageFamily *
-get_unseen_images(side)
-Side *side;
+get_unseen_images(Side *side)
 {
     if (!empty_string(g_unseen_color())) {
 	unseen_image = get_generic_images(g_unseen_color());
@@ -2606,17 +2612,22 @@ Side *side;
 }
 
 ImageFamily *
-get_emblem_images(side, side2)
-Side *side, *side2;
+get_emblem_images(Side *side, Side *side2)
 {
     char *name, tmpbuf[BUFSIZE];
     int s2 = side_number(side2);
     ImageFamily *imf;
 
-    if (side2 != NULL && !empty_string(side2->emblemname))
-      name = side2->emblemname;
-    else {
-	/* There is a set of default emblems named "s0", "s1", etc. */
+    if (side2 == NULL) {
+	name = "s0";
+    } else if (!empty_string(side2->emblemname)) {
+	name = side2->emblemname;
+    } else if (!empty_string(side2->colorscheme)
+	       && !strchr(side2->colorscheme, ',')) {
+	/* One-color color scheme can be a substitute emblem. */
+	name = side2->colorscheme;
+    } else {
+	/* There is a set of default emblems named "s1", etc. */
 	sprintf(tmpbuf, "s%d", s2);
 	name = copy_string(tmpbuf);
     }
