@@ -58,8 +58,10 @@ typedef struct a_vp {
     short draw_cover;
     short draw_feature_boundaries;
     short draw_feature_names;
-    short draw_latlong;		/* Draw latitude/longitude in view */
-    short latlong_interval;	/* Spacing of meridians in arc minutes */
+    short draw_meridians;	/* Draw latitude/longitude in view */
+    short meridian_interval;	/* Spacing of meridians in arc minutes */
+    short lat_label_lon_interval;
+    short lon_label_lat_interval;
     short draw_ai;		/* Draw AI info in view */
 } VP;
 
@@ -154,6 +156,7 @@ extern void compute_fire_line_segment(int sx1, int sy1, int sx2, int sy2,
 				      int *dx, int *dy);
 extern void place_feature_legends(Legend *leg, int nf, Side *side,
 				  int orient, int block);
+extern void set_meridian_interval(VP *vp, int interval);
 extern void plot_meridians
  (VP *vp,
   void (*line_callback)(int x1, int y1, int x1f, int y1f,
