@@ -1,5 +1,5 @@
 /* Units in Xconq.
-   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -400,6 +400,23 @@ change_unit_type(Unit *unit, int newtype, int reason)
     init_unit_actorstate(unit, FALSE);
     init_unit_plan(unit);
     unit->aihook = NULL;
+
+    /* Advanced unit support, but only if we're becoming an advanced type
+       and we weren't before. */
+    /* (should share with unit creation) */
+    if (u_advanced(newtype) && !u_advanced(oldtype)) {
+	unit->size = default_size;
+	unit->reach = u_reach(unit->type);
+	unit->usedcells = default_usedcells;
+	unit->maxcells = default_maxcells;
+	unit->population = default_population;
+	unit->curadvance = default_curadvance;
+	unit->autobuild = FALSE;		
+	unit->autoresearch = FALSE;
+	unit->autoplan = FALSE;
+	unit->cp_stash = 0;
+    }
+
     /* Increment viewing coverage. */
     cover_area(unit->side, unit, unit->transport, -1, -1, unit->x, unit->y);
     /* If vision range is 0, allow glimpses of adjacent cell terrain.
@@ -456,9 +473,7 @@ side_owns_occupant(Side *side, Unit *unit)
    used. */
 
 int
-enter_cell(unit, x, y)
-Unit *unit;
-int x, y;
+enter_cell(Unit *unit, int x, int y)
 {
 #ifdef DEBUGGING
     /* Not necessarily an error, but indicative of bugs elsewhere. */
@@ -495,9 +510,7 @@ int x, y;
 /* (should eventually account for variable-size units) */
 
 int
-can_occupy_cell(unit, x, y)
-Unit *unit;
-int x, y;
+can_occupy_cell(Unit *unit, int x, int y)
 {
     int u = unit->type, u2, u3, t = terrain_at(x, y), numthistype = 0;
     int fullness = 0, tcap, utcap, numtypes[MAXUTYPES];
@@ -529,8 +542,7 @@ int x, y;
 }
 
 int
-type_can_occupy_cell(u, x, y)
-int u, x, y;
+type_can_occupy_cell(int u, int x, int y)
 {
     int t = terrain_at(x, y), u2, u3, numthistype = 0, fullness = 0;
     int tcap, utcap, numtypes[MAXUTYPES];
@@ -560,11 +572,10 @@ int u, x, y;
 }
 
 /* Similar, but don't count a specific given unit when calculating. */
+/* (should share with can_occupy_cell, make unit3 be optional arg?) */
 
 int
-can_occupy_cell_without(unit, x, y, unit3)
-Unit *unit, *unit3;
-int x, y;
+can_occupy_cell_without(Unit *unit, int x, int y, Unit *unit3)
 {
     int u = unit->type, u2, u3, t = terrain_at(x, y), numthistype = 0;
     int fullness = 0, tcap, utcap, numtypes[MAXUTYPES];
@@ -598,9 +609,7 @@ int x, y;
 }
 
 int
-type_can_occupy_cell_without(u, x, y, unit3)
-int u, x, y;
-Unit *unit3;
+type_can_occupy_cell_without(int u, int x, int y, Unit *unit3)
 {
     int t = terrain_at(x, y), u2, u3, numthistype = 0, fullness = 0;
     int tcap, utcap, numtypes[MAXUTYPES];
@@ -636,9 +645,7 @@ Unit *unit3;
 int can_occupy_conn_1(Unit *unit, int nx, int ny, int c);
 
 int
-can_occupy_conn(unit, nx, ny, nz)
-Unit *unit;
-int nx, ny, nz;
+can_occupy_conn(Unit *unit, int nx, int ny, int nz)
 {
     int c;
 
@@ -652,9 +659,8 @@ int nx, ny, nz;
 	return can_occupy_conn_1(unit, nx, ny, c);
     } else {
 	/* Test each connection type to see if it will work. */
-	for_all_terrain_types(c) {
-	    if (t_is_connection(c)
-		&& aux_terrain_defined(c)
+	for_all_connection_types(c) {
+	    if (aux_terrain_defined(c)
 		&& can_occupy_conn_1(unit, nx, ny, c))
 	      return TRUE;
 	}
@@ -663,9 +669,7 @@ int nx, ny, nz;
 }
 
 int
-can_occupy_conn_1(unit, nx, ny, c)
-Unit *unit;
-int nx, ny, c;
+can_occupy_conn_1(Unit *unit, int nx, int ny, int c)
 {
     int u, u2, tcap, utcap, fullness, numthistype, numtypes[MAXUTYPES];
     Unit *unit2;
@@ -705,22 +709,16 @@ int nx, ny, c;
    the cell terrain is hostile. */
    
 int
-type_can_sit_on_conn(u, x, y)
-int u, x, y;
+type_can_sit_on_conn(int u, int x, int y)
 {
-    int c, dir;
+    int c;
 
-    if (numconntypes == 0)
-      return FALSE;
-    for_all_terrain_types(c) {
-	if (t_is_connection(c) && aux_terrain_defined(c)) {
-	    for_all_directions(dir) {
-		if (connection_at(x, y, dir, c)
-		    && !ut_vanishes_on(u, c)
-		    && !ut_wrecks_on(u, c))
-		  return TRUE;
-	    }
-	}
+    for_all_connection_types(c) {
+	if (aux_terrain_defined(c)
+	    && any_connections_at(x, y, c)
+	    && !ut_vanishes_on(u, c)
+	    && !ut_wrecks_on(u, c))
+	  return TRUE;
     }
     return FALSE;
 }
@@ -729,9 +727,7 @@ int u, x, y;
    two routines that modify actual unit positions (leaving is the other). */
 
 void
-enter_cell_aux(unit, x, y)
-Unit *unit;
-int x, y;
+enter_cell_aux(Unit *unit, int x, int y)
 {
     int u = unit->type;
     Unit *occ;
@@ -1610,6 +1606,24 @@ char *newname;
     /* (should also send to any other side directly viewing this unit!) */
 }
 
+/* Given an amount to add, add it to the unit's hp, being careful
+   to check the limits.  Expect the caller to update the unit's
+   display, for instance there may be a health bar to change. */
+
+void
+add_to_unit_hp(Unit *unit, int hp)
+{
+    int hpmax;
+
+    unit->hp += hp;
+    hpmax = u_hp(unit->type);
+    if (unit->hp > hpmax)
+      unit->hp = hpmax;
+    unit->hp2 += hp;
+    if (unit->hp2 > hpmax)
+      unit->hp2 = hpmax;
+}
+
 void
 change_morale(unit, sign, morchange)
 Unit *unit;
