@@ -1,5 +1,5 @@
 /* Definitions relating to worlds and areas in Xconq.
-   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -443,6 +443,8 @@ extern int numbordtypes;
 extern int numconntypes;
 extern int numcoattypes;
 
+extern int numfeatures;
+
 extern int minelev;
 extern int maxelev;
 extern int mintemp;
@@ -451,6 +453,7 @@ extern int minwindforce;
 extern int maxwindforce;
 
 extern int any_materials_in_terrain;
+extern int any_elev_variation;
 extern int any_temp_variation;
 extern int any_temp_variation_in_layer;
 extern int any_wind_variation;
