@@ -1,5 +1,5 @@
 /* Xconq game module writing.
-   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -194,7 +194,7 @@ write_entire_game_state(char *fname)
 }
 
 /* Given a game module telling what is in the module, write out a file
-   containing the requested content.  Return true if everything went OK. */
+   containing the requested content.  Return true if all went OK. */
 
 int
 write_game_module(Module *module)
@@ -537,8 +537,7 @@ write_tables(int compress)
   ((typ) == TTYP ? t_type_name(i) : a_type_name(i))))
 
 static void
-write_type_name_list(typ, flags, dim)
-int typ, *flags, dim;
+write_type_name_list(int typ, int *flags, int dim)
 {
     int j, first = TRUE, listlen = 0;
 
@@ -609,9 +608,8 @@ histo_compare(CONST void *x, CONST void *y)
    really large, but often have constant areas within them. */
 
 static void
-write_table(name, getter, dflt, typ1, typ2, valtype, compress)
-char *name;
-int (*getter)(int, int), dflt, typ1, typ2, valtype, compress;
+write_table(char *name, int (*getter)(int, int), int dflt, int typ1, int typ2,
+	    int valtype, int compress)
 {
     int i, j, k, colvalue, constcol, next;
     int numrandoms, nextrowdiffers, writeconst;
@@ -821,7 +819,7 @@ int (*getter)(int, int), dflt, typ1, typ2, valtype, compress;
 /* Write info about the whole world. */
 
 static void
-write_world()
+write_world(void)
 {
     newline_form();
     start_form(key(K_WORLD));
@@ -843,17 +841,18 @@ write_world()
    back in. */
 
 static void
-write_areas(module)
-Module *module;
+write_areas(Module *module)
 {
     int all = module->def_all, compress = module->compress_layers;
 
     newline_form();
     /* Write the basic dimensions. */
     start_form(key(K_AREA));
-    /* K_WIDTH, K_HEIGHT always written. */
-    add_num_to_form((doreshape ? reshaper->final_width : area.width));
-    add_num_to_form((doreshape ? reshaper->final_height : area.height));
+    /* K_WIDTH, K_HEIGHT written if nonzero. */
+    if (area.width > 0 || area.height > 0) {
+	add_num_to_form((doreshape ? reshaper->final_width : area.width));
+	add_num_to_form((doreshape ? reshaper->final_height : area.height));
+    }
     /* Write all the scalar properties. */
     write_num_prop(key(K_LATITUDE), area.latitude, 0, 0, FALSE);
     write_num_prop(key(K_LONGITUDE), area.longitude, 0, 0, FALSE);
@@ -898,28 +897,29 @@ Module *module;
       write_area_users(compress);
 }
 
+/* Write out the city usage layer. */
+
 static void
 write_area_users(int compress)
 {
-	extern int nextid;
+    extern int nextid;
 
-	if (!user_defined())
-		return;
-	start_form(key(K_AREA));
-	space_form();
-	start_form(key(K_USER));
-	newline_form();
-	write_rle(fn_user_at, NOUSER, nextid, NULL, compress);
-	space_form();
-	space_form();
-	end_form();
-	end_form();
-	newline_form();
+    if (!user_defined())
+      return;
+    start_form(key(K_AREA));
+    space_form();
+    start_form(key(K_USER));
+    newline_form();
+    write_rle(fn_user_at, NOUSER, nextid, NULL, compress);
+    space_form();
+    space_form();
+    end_form();
+    end_form();
+    newline_form();
 }
 
 static void
-write_area_terrain(compress)
-int compress;
+write_area_terrain(int compress)
 {
     int t;
 
@@ -957,8 +957,7 @@ int compress;
 }
 
 static void
-write_area_aux_terrain(compress)
-int compress;
+write_area_aux_terrain(int compress)
 {
     int t;
 
@@ -981,8 +980,7 @@ int compress;
 }
 
 static void
-write_area_features(compress)
-int compress;
+write_area_features(int compress)
 {
     Feature *feature;
 
@@ -1028,8 +1026,7 @@ fn_elevation_at_offset(int x, int y)
 }
 
 static void
-write_area_elevations(compress)
-int compress;
+write_area_elevations(int compress)
 {
     if (!elevations_defined())
       return;
@@ -1056,8 +1053,7 @@ int compress;
 /* Write out people sides for the area. */
 
 static void
-write_area_people_sides(compress)
-int compress;
+write_area_people_sides(int compress)
 {
     Side *side;
 
@@ -1098,8 +1094,7 @@ int compress;
 /* Write out control sides for the area. */
 
 static void
-write_area_control_sides(compress)
-int compress;
+write_area_control_sides(int compress)
 {
     Side *side;
 
@@ -1138,8 +1133,7 @@ int compress;
 }
 
 static void
-write_area_materials(compress)
-int compress;
+write_area_materials(int compress)
 {
     int m;
 
@@ -1162,8 +1156,7 @@ int compress;
 }
 
 static void
-write_area_temperatures(compress)
-int compress;
+write_area_temperatures(int compress)
 {
     if (!temperatures_defined())
       return;
@@ -1180,8 +1173,7 @@ int compress;
 }
 
 static void
-write_area_clouds(compress)
-int compress;
+write_area_clouds(int compress)
 {
     if (clouds_defined()) {
 	start_form(key(K_AREA));
@@ -1368,7 +1360,7 @@ write_sides(Module *module)
     add_to_form("sides including the independent 0 side.");
     newline_form();
     Dprintf("Will try to write %d sides ...\n", numtotsides);
-    for_all_sides(side) {
+    for_all_real_sides(side) {
 	start_form(key(K_SIDE));
 	add_num_to_form(side->id);
 	if (symbolp(side->symbol))
@@ -1383,9 +1375,8 @@ write_sides(Module *module)
 	  write_side_view(side, module->compress_layers);
 	Dprintf("  Wrote side %s\n", side_desig(side));
     }
-
-#if 0		/* The independent side is now handled as side 0 above. */
-
+    /* Even though the indepside is another side, the properties of
+       independent units are a separate type of form. */
     start_form(key(K_INDEPENDENT_UNITS));
     newline_form();
     write_side_properties(indepside);
@@ -1393,9 +1384,6 @@ write_sides(Module *module)
     end_form();
     newline_form();
     Dprintf("  Wrote independent unit properties\n");
-
-#endif
-
     Dprintf("... Done writing sides\n");
 }
 
@@ -1887,7 +1875,7 @@ write_units(Module *module)
     /* Make a consistent ordering. */
     sort_units(module->def_all || module->def_unit_ids);
     numtowrite = 0;
-    for_all_sides_plus_indep(loopside) {
+    for_all_sides(loopside) {
 	for_all_side_units(loopside, unit) {
 	    if (alive(unit))
 	      ++numtowrite;
@@ -1903,7 +1891,7 @@ write_units(Module *module)
     end_form();
     newline_form();
     Dprintf("Writing %d units ...\n", numliveunits);
-    for_all_sides_plus_indep(loopside) {
+    for_all_sides(loopside) {
 	for_all_side_units(loopside, unit) {
 	    if (alive(unit)) {
 		/* K_AT always written */
@@ -2226,7 +2214,7 @@ write_historical_event(HistEvent *hevt)
 }
 
 static void
-write_namers()
+write_namers(void)
 {
     extern Obj *namerlist;
     Obj *rest, *namer;
@@ -2361,8 +2349,7 @@ int (*datafn)(int, int), lo, hi, (*translator)(int), compress;
    0 - 29 is 'a' - '~', 30 - 63 is ':' - '[' */ 
 
 static void
-write_run(run, val)
-int run, val;
+write_run(int run, int val)
 {
     if (run > 1) {
 	add_num_to_form_no_space(run);
@@ -2382,8 +2369,7 @@ int run, val;
 /* Compute and return the corresponding point in an area being reshaped. */
 
 static int
-reshaped_point(x1, y1, x2p, y2p)
-int x1, y1, *x2p, *y2p;
+reshaped_point(int x1, int y1, int *x2p, int *y2p)
 {
     *x2p = (((x1 - reshaper->subarea_x) * reshaper->final_subarea_width )
 	    / reshaper->subarea_width ) + reshaper->final_subarea_x;
@@ -2393,8 +2379,7 @@ int x1, y1, *x2p, *y2p;
 }
 
 static int
-original_point(x1, y1, x2p, y2p)
-int x1, y1, *x2p, *y2p;
+original_point(int x1, int y1, int *x2p, int *y2p)
 {
     *x2p = (((x1 - reshaper->final_subarea_x) * reshaper->subarea_width )
 	    / reshaper->final_subarea_width ) + reshaper->subarea_x;
@@ -2406,8 +2391,7 @@ int x1, y1, *x2p, *y2p;
 /* Little routines to do low-level syntax to either file or remote machine. */
 
 static void
-start_form(hd)
-char *hd;
+start_form(char *hd)
 {
     if (wfp) {
 	fprintf(wfp, "(%s", hd);
@@ -2418,8 +2402,7 @@ char *hd;
 }
 
 static void
-add_to_form(x)
-char *x;
+add_to_form(char *x)
 {
     if (wfp) {
 	fprintf(wfp, " %s", x);
@@ -2430,8 +2413,7 @@ char *x;
 }
 
 static void
-add_to_form_no_space(x)
-char *x;
+add_to_form_no_space(char *x)
 {
     if (wfp) {
 	fputs(x, wfp);
@@ -2441,8 +2423,7 @@ char *x;
 }
 
 static void
-add_char_to_form(x)
-int x;
+add_char_to_form(int x)
 {
     char buf[2];
 
@@ -2456,8 +2437,7 @@ int x;
 }
 
 static void
-add_num_to_form(x)
-int x;
+add_num_to_form(int x)
 {
     char buf[30];
 
@@ -2470,8 +2450,7 @@ int x;
 }
 
 static void
-add_num_to_form_no_space(x)
-int x;
+add_num_to_form_no_space(int x)
 {
     char buf[30];
 
@@ -2486,13 +2465,17 @@ int x;
 /* Write either a normal value or a dice spec, as appropriate. */
 
 static void
-add_num_or_dice_to_form(x, valtype)
-int x, valtype;
+add_num_or_dice_to_form(int x, int valtype)
 {
     char buf[100];
+    int addend;
 
     if (valtype == TABDICE && x >> 14 == 1) {
-	sprintf(buf, " %dd%d+%d", (x >> 11) & 0x07, (x >> 7) & 0x0f, x & 0x7f);
+	addend = x & 0x7f;
+	if (addend > 0)
+	  sprintf(buf, " %dd%d+%d", (x >> 11) & 0x07, (x >> 7) & 0x0f, addend);
+	else
+	  sprintf(buf, " %dd%d", (x >> 11) & 0x07, (x >> 7) & 0x0f);
     } else {
 	sprintf(buf, " %d", x);
     }
@@ -2506,8 +2489,7 @@ int x, valtype;
 char *onemorebuf;
 
 static void
-add_form_to_form(x)
-Obj *x;
+add_form_to_form(Obj *x)
 {
     if (wfp) {
 	fprintlisp(wfp, x);
@@ -2515,14 +2497,14 @@ Obj *x;
 	/* Even this might not be enough (should have a better strategy
 	   for downloading large Lisp objects) */
 	if (onemorebuf == NULL)
-	  onemorebuf = xmalloc(16000);
-	sprintlisp(onemorebuf, x, 16000);
+	  onemorebuf = xmalloc(50000);
+	sprintlisp(onemorebuf, x, 50000);
 	add_to_packet(onemorebuf);
     }
 }
 
 static void
-end_form()
+end_form(void)
 {
     if (wfp) {
 	fputs(")", wfp);
@@ -2532,7 +2514,7 @@ end_form()
 }
 
 static void
-newline_form()
+newline_form(void)
 {
     if (wfp) {
 	fprintf(wfp, "\n");
@@ -2542,7 +2524,7 @@ newline_form()
 }
 
 static void
-space_form()
+space_form(void)
 {
     if (wfp) {
 	fputs(" ", wfp);
@@ -2552,9 +2534,8 @@ space_form()
 }
 
 static void
-write_bool_prop(name, value, dflt, nodefaulting, addnewline)
-char *name;
-int value, dflt, nodefaulting, addnewline;
+write_bool_prop(char *name, int value, int dflt, int nodefaulting,
+		int addnewline)
 {
     if (nodefaulting || value != dflt) {
 	space_form();
@@ -2569,9 +2550,8 @@ int value, dflt, nodefaulting, addnewline;
 }
 
 static void
-write_num_prop(name, value, dflt, nodefaulting, addnewline)
-char *name;
-int value, dflt, nodefaulting, addnewline;
+write_num_prop(char *name, int value, int dflt, int nodefaulting,
+	       int addnewline)
 {
     if (nodefaulting || value != dflt) {
 	space_form();
@@ -2588,9 +2568,8 @@ int value, dflt, nodefaulting, addnewline;
 /* Handle the writing of a single string-valued property. */
 
 static void
-write_str_prop(name, value, dflt, nodefaulting, addnewline)
-char *name, *value, *dflt;
-int nodefaulting, addnewline;
+write_str_prop(char *name, char *value, char *dflt, int nodefaulting,
+	       int addnewline)
 {
     if (nodefaulting || string_not_default(value, dflt)) {
 	space_form();
@@ -2605,8 +2584,7 @@ int nodefaulting, addnewline;
 }
 
 static int
-string_not_default(str, dflt)
-char *str, *dflt;
+string_not_default(char *str, char *dflt)
 {
     if (empty_string(dflt)) {
 	if (empty_string(str)) {
@@ -2624,10 +2602,8 @@ char *str, *dflt;
 }
 
 static void
-write_lisp_prop(name, value, dflt, nodefaulting, as_cdr, addnewline)
-char *name;
-Obj *value, *dflt;
-int nodefaulting, as_cdr, addnewline;
+write_lisp_prop(char *name, Obj *value, Obj *dflt, int nodefaulting,
+		int as_cdr, int addnewline)
 {
     Obj *rest;
 
@@ -2657,10 +2633,7 @@ int nodefaulting, as_cdr, addnewline;
 }
 
 static void
-write_utype_value_list(name, arr, dflt, addnewline)
-char *name;
-short *arr;
-int dflt, addnewline;
+write_utype_value_list(char *name, short *arr, int dflt, int addnewline)
 {
     int u, writeany;
 
@@ -2688,10 +2661,7 @@ int dflt, addnewline;
 }
 
 static void
-write_mtype_value_list(name, arr, dflt, addnewline)
-char *name;
-short *arr;
-int dflt, addnewline;
+write_mtype_value_list(char *name, short *arr, int dflt, int addnewline)
 {
     int m, writeany;
 
@@ -2719,10 +2689,7 @@ int dflt, addnewline;
 }
 
 static void
-write_atype_value_list(name, arr, dflt, addnewline)
-char *name;
-short *arr;
-int dflt, addnewline;
+write_atype_value_list(char *name, short *arr, int dflt, int addnewline)
 {
     int a, writeany;
 
@@ -2750,10 +2717,7 @@ int dflt, addnewline;
 }
 
 static void
-write_side_value_list(name, arr, dflt, addnewline)
-char *name;
-short *arr;
-int dflt, addnewline;
+write_side_value_list(char *name, short *arr, int dflt, int addnewline)
 {
     int s, writeany;
 
@@ -2781,10 +2745,7 @@ int dflt, addnewline;
 }
 
 static void
-write_utype_string_list(name, arr, dflt, addnewline)
-char *name;
-char **arr, *dflt;
-int addnewline;
+write_utype_string_list(char *name, char **arr, char *dflt, int addnewline)
 {
     int u, writeany;
 
@@ -2815,8 +2776,7 @@ int addnewline;
    unit type. */
 
 char *
-shortest_escaped_name(u)
-int u;
+shortest_escaped_name(int u)
 {
     char *typename = u_internal_name(u);
 
