@@ -36,6 +36,12 @@ extern short initialvrefnum;
 
 char *connection_method_name;
 
+extern void auto_pick_side_research(Side *side);
+extern void show_research_dialog();
+extern void draw_research_dialog(int force);
+extern int do_key_down_research(char key);
+extern void hit_research_dialog(int ditem);
+
 extern void recalc_spacing(void);
 extern void invert_map(Map *map, int x, int y, int r);
 
@@ -544,6 +550,8 @@ event_loop()
 		if (IsDialogEvent(&event) && DialogSelect(&event, &dialog, &itemhit)) {
 				if (dialog == playersetupwin) {
 				hit_player_setup_dialog(itemhit, mouse);
+			} else if (dialog == researchwin) {
+				hit_research_dialog(itemhit);
 			} else if (topFloat && unit_closeup_from_window(topFloat)) {
 				hit_closeup_dialog(topFloat, itemhit, mouse);
 				}
@@ -553,6 +561,7 @@ event_loop()
 				if (gotevent)
 				  continue;
 			}
+		
 		if (gotevent) {
 
 #if 0			/* Redundant, adjust_cursor is now always called above. */
@@ -639,8 +648,15 @@ handle_keystroke(EventRecord *event)
 			}
 		} else if (topFloat == helpwin) {
 			handled = do_key_down_help(charCode);		
+		} else if (topFloat == researchwin) {
+			handled = do_key_down_research(charCode);		
 		}
 	}
+	/* Special use of the numeric keypad and arrow keys for 
+	scrolling of maps. */
+	if (!handled && (frontmap || worldmap)) {
+		handled = handle_numeric_keypad(event);
+	}
 	/* Key commands for normal windows. */
 	if (!handled && topWindow) {
 		list = list_from_window(topWindow);
@@ -652,11 +668,6 @@ handle_keystroke(EventRecord *event)
 			handled = do_key_down_command(charCode);
 		}
 	}
-	/* Special use of the numeric keypad and arrow keys for 
-	scrolling of maps. */
-	if (!handled && (frontmap || worldmap)) {
-		handled = handle_numeric_keypad(event);
-	}
 	/* All other keys are interpreted as keyboard commands. */
 	if (!handled) {
 		do_keyboard_command(charCode);
@@ -1217,6 +1228,11 @@ update_window(WindowPtr win)
 	} else if (win == scoreswin) {
 		draw_scores();
 		growbox = TRUE;
+	} else if (win == researchwin) {
+		/* Update events don't always work with dialogs, but setting the force 
+		flag forces redrawing. */
+		draw_research_dialog(true);
+		controls = FALSE;
 #ifdef DESIGNERS
 	} else if (win == designwin) {
 		draw_design_window();
@@ -1792,12 +1808,15 @@ update_side_display(Side *side, Side *side2, int rightnow)
 	GrafPtr oldport;
 	extern int gamenumsides;
 
-	if (active_display(side) && side2 != indepside) {
-		GetPort(&oldport);
-		if (gamewin != nil && ((WindowPeek) gamewin)->visible) {
+	if (active_display(side)) {
+		if (gamewin != nil
+		    && side2 != indepside 
+		    && ((WindowPeek) gamewin)->visible) {
 			if (gamenumsides == numsides) {
+				GetPort(&oldport);
 				SetPort(gamewin);
 				draw_side_status(side2);
+				SetPort(oldport);		
 			} else {
 				/* A side must have been added recently; redraw
 				   the entire window this time. */
@@ -1806,7 +1825,25 @@ update_side_display(Side *side, Side *side2, int rightnow)
 				draw_game();
 			}
 		}
-		SetPort(oldport);
+		/* Handle the research window if necessary. */
+		if (numatypes > 0 && g_side_can_research()) {
+			/* Research is under human control and we need a new topic. */
+			if (!side_has_ai(dside) && dside->research_topic == NOADVANCE) {
+				 if (dside->autoresearch) {
+					auto_pick_side_research(dside);
+					if (researchwin)
+					    /* We call draw_research_dialog here passing false instead of 
+					    update_window, which would force redrawing. */
+					    draw_research_dialog(false);
+				/* Pick new topic manually. */
+				} else {
+					show_research_dialog();
+				}
+			/* Always update the window, but only if it exists. */
+			} else if (researchwin) {
+				draw_research_dialog(false);
+			}
+		}
 		if (side2 == dside && !side->ingame && side->status == 0 && wasingame) {
 			/* (should be able to quit from here?) */
 			CautionAlert(aOutOfGame, nil); 
