@@ -433,7 +433,9 @@ extern MacImage **tcolors;
 extern WindowPtr helpwin;
 extern char *helpstring;
 extern TEHandle helptext;
+extern DialogPtr researchwin;
 
+extern WindowPtr commandwin;
 extern WindowPtr instructionswin;
 extern WindowPtr gamewin;
 extern WindowPtr constructionwin;
@@ -468,7 +470,7 @@ extern WindowPtr *winmenuwins;
 
 extern int default_draw_grid;
 extern int default_draw_names;
-extern int default_draw_latlong;
+extern int default_draw_meridians;
 
 extern int map_modal;
 
@@ -569,7 +571,7 @@ extern short title_line_spacing;
 extern int gamewinw;
 extern int topunithgt;
 
-extern int default_latlong_interval;
+extern int default_meridian_interval;
 
 extern int use_colornames;			/* Save and read colors and colorschemes by name */
 extern int use_RGB_values;			/* Save and read RGB colors in XCol resource */
@@ -989,6 +991,8 @@ extern void draw_unit_closeup(UnitCloseup *unitcloseup);
 extern UnitCloseup *unit_closeup_from_window(WindowPtr win);
 extern int do_mouse_down_unit_closeup(UnitCloseup *unitcloseup, Point mouse, int mods);
 extern void destroy_unit_closeup(UnitCloseup *unitcloseup);
+extern MenuHandle build_construction_menu(Unit *unit);
+extern MenuHandle build_research_menu(Side *side);
 
 extern void show_history_window(void);
 extern void create_history_window(void);
@@ -1020,7 +1024,11 @@ extern void do_mouse_down_scores(Point mouse, int mods);
 extern void grow_scores(int h, int v);
 extern void zoom_scores(int part);
 
-extern WindowPtr commandwin;
+extern void show_research_dialog();
+extern void draw_research_dialog(int force);
+extern int do_key_down_research(char key);
+extern void hit_research_dialog(int ditem);
+
 extern void draw_command(void);
 extern void activate_command(int activate);
 extern int do_key_down_command(int key);
@@ -1109,7 +1117,7 @@ extern void toggle_shorelines(Map *map);
 extern void toggle_simple_borders(Map *map);
 extern void toggle_optimize_fonts(Map *map);
 extern void toggle_erase_names(Map *map);
-extern void toggle_draw_latlong(Map *map);
+extern void toggle_draw_meridians(Map *map);
 extern void toggle_solid_color_terrain(Map *map);
 extern void toggle_list_sidecolors(List *list);
 extern void toggle_list_draw_emblems(List *list);
