@@ -167,11 +167,12 @@ any later version.  See the file COPYING.  */
 #define miSideSound 8
 /* 9 */
 /* 10 is AI Type submenu */
-/* 11 */
-#define miSideDoctrine 12
-/* 13 */
-#define miSideSendMessage 14
-#define miSideRename 15
+#define miSideAutoResearch 11
+/* 12 */
+#define miSideDoctrine 13
+/* 14 */
+#define miSideSendMessage 15
+#define miSideRename 16
 
 #define miWindowsGame 1
 #define miWindowsNotices 2
@@ -418,7 +419,7 @@ any later version.  See the file COPYING.  */
 #define diPrefsNames (diPrefsCommon + 2)
 #define diPrefsFeatureNames (diPrefsCommon + 3)
 #define diPrefsFeatureBorders (diPrefsCommon + 4)
-#define diPrefsLatLong (diPrefsCommon + 5)
+#define diPrefsMeridians (diPrefsCommon + 5)
 #define diPrefsIncrText (diPrefsCommon + 6)
 #define diPrefsIncr (diPrefsCommon + 7)
 #define diPrefsSideColors (diPrefsCommon + 8)
@@ -848,6 +849,16 @@ any later version.  See the file COPYING.  */
 
 #define dCloseup 810
 
+#define dSideResearch 811
+
+#define diSideResearchClose 1
+#define diSideResearchHelp 2
+#define diSideResearchPopup 3
+#define diSideResearchCheck 4
+#define diSideResearchText1 5
+#define diSideResearchText2 6
+#define diSideResearchWizard 7
+
 #define MAXPROJMENUS 9		/* Max number of project menus (excluding Idle units) and associated items. */
 
 /* Alerts. */
