@@ -108,6 +108,7 @@ enable_designing(int forsure)
 	for_all_maps(map) {
 		if (!map->see_all) {
 			map->see_all = TRUE;
+			map->vp->show_all = TRUE;
 			force_update(map->window);
 		}
 	}
@@ -234,7 +235,7 @@ create_design_window()
 	enabledtooltype[temperaturetool] = any_temp_variation;
 	enabledtooltype[cloudstool] = any_clouds;
 	enabledtooltype[windstool] = any_wind_variation;
-	enabledtooltype[viewtool] = !all_see_all;
+	enabledtooltype[viewtool] = !g_see_all();
 
 	/* Count the number of tools in use and size window accordingly. */
 	for (i = 0; i < numtooltypes; ++i) {
