@@ -1,5 +1,5 @@
 /* Low-level drawing for the Mac interface to Xconq.
-   Copyright (C) 1992-1998 Stanley T. Shebs.
+   Copyright (C) 1992-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,85 +64,71 @@ static Image **best_unseen_images = NULL;
 void
 draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int mod, int emblem)
 {
-	int ex, ey, ew, eh, bx, by, bw, bh, overlap, desperate, sx2, sy2;
+	int ex, ey, ew, eh, bx, by, bw, bh, sx2, sy2;
+	int desperate = FALSE;
+	int sidecolors = FALSE;
+	int iconmasks = FALSE;
 	char *ename;
-
-// --- GRAYOUT BUG FIX ----------------------------------------------------
-
 	Rect srcrect, imagerect, fullrect;
-
-//	Rect srcrect, imagerect;
-
-// --------------------------------------------------------------------
-
 	CIconHandle cicnhandle;
 	Image *uimg;
 	MacImage *macuimg;
 	Map *curmap;
 	List *curlist;
 	BitMap portbits;			/* Target BitMap for CopyBits */
-	BitMap bm, mm;				/* icon BitMap & MaskMap */
-	PixMap pm;					/* icon PixMap */
-	
+	BitMap bm, mm;			/* icon BitMap & MaskMap */
+	PixMap pm;			/* icon PixMap */
+
 	/* Filter out very small images. */
 	if (sw <= 1)
 	  return; 
 
 	/* Find current map or list. */
-	/* (inefficient, should pass in from above) */
 	curmap = map_from_window(win);
 	curlist = list_from_window(win);
-	
+
 	/* Default colors used in the absence of defined side colors. */
 	RGBForeColor(&forecolor);
 	RGBBackColor(&maskcolor);
-	
-	if (curmap && curmap->sidecolors) {
-		/* Set main icon color & mask color when plotting to maps. */
-		if (main_icon_color[e])
-		  RGBForeColor(&(get_sideColor(e, main_icon_color[e])));
-		if (icon_mask_color[e])
-		  RGBBackColor(&(get_sideColor(e, icon_mask_color[e])));
 
-	} else if (curlist && curlist->sidecolors) {
-		/* Set main icon color when plotting to lists. */
+	/* Optionally set side colors and sidecolors flag. */
+	if (curmap && curmap->sidecolors
+	    || curlist && curlist->sidecolors
+	    || (!curmap && !curlist && default_sidecolors)) {
+		sidecolors = TRUE;
 		if (main_icon_color[e])
-		  RGBForeColor(&(get_sideColor(e, main_icon_color[e])));
-	}	
+			RGBForeColor(&(get_sideColor(e, main_icon_color[e])));
+		if (icon_mask_color[e])
+			RGBBackColor(&(get_sideColor(e, icon_mask_color[e])));
+	}	    	
+	/* Optionally set the iconmasks flag. */
+	if (curmap && curmap->iconmasks
+	    || (!curmap && default_iconmasks)) {
+		iconmasks = TRUE;
+	}	    	
 	/* Set destination rectangle. */
 	SetRect(&imagerect, sx, sy, sx + sw, sy + sh);
-
-// --- GRAYOUT BUG FIX ----------------------------------------------------
-
 	if (mod)
 		SetRect(&fullrect, sx, sy, sx + sw, sy + sh);
 
-// --------------------------------------------------------------------
-
 	/* Plot squares if the picture is too small. */
 	if (sw <= 4) {
 		FillRect(&imagerect, QDPat(black));
-		/* Optionally use a second color to plot the right half of the square */
-		if (curmap->sidecolors && half_icon_color[e] && split_icon[e]) {
+		/* Optionally use a second color to plot the right half of the square. */
+		if (sidecolors && half_icon_color[e] && split_icon[e]) {
 			RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
 			/* Restrict plotting to right half of image. */
-			imagerect.left = imagerect.left + sw / 2;
+			imagerect.left += sw / 2;
 			FillRect(&imagerect, QDPat(black));
 		}
-
-// --- GRAYOUT BUG FIX ----------------------------------------------------
-
-		if (mod)
-			gray_out_rect(&fullrect);
-
-// --------------------------------------------------------------------
-
-		/* Restore colors before returning! */
+		/* Restore colors before calling gray_out_rect! */
 		ForeColor(blackColor);
 		BackColor(whiteColor);
+		/* Gray out incomplete units. */
+		if (mod)
+			gray_out_rect(&fullrect);
 		return;
 	}
-	desperate = FALSE;
 
 	/* Get best unit image from family */
 	uimg = best_image(uimages[u], sw, sh);
@@ -162,16 +148,9 @@ draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int
 			    sh = uimg->h;
 			}
 			SetRect(&imagerect, sx, sy, sx + sw, sy + sh);
-
-// --- GRAYOUT BUG FIX ----------------------------------------------------
-
 			if (mod)
 				SetRect(&fullrect, sx, sy, sx + sw, sy + sh);
-
-// --------------------------------------------------------------------
-
 		}
-
 		portbits = QD(thePort)->portBits;
 
 		/* Use pict resource if available */
@@ -192,88 +171,48 @@ draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int
 			bm = (*(cicnhandle))->iconBMap;
 			mm = (*(cicnhandle))->iconMask;
 
-			/* cicns in maps */
-			if (curmap) {
-
-				/* Always use the MaskMap as mask if iconmasks is on */
-				if (curmap->iconmasks) {
-					/* First plot the MaskMap srcBic using mask color */
+			/* Always use the MaskMap as mask if iconmasks is on. */
+			if (iconmasks) {
+				/* First plot the MaskMap srcBic using mask color. */
+				CopyBits(&mm, &portbits, &srcrect, &imagerect, srcBic, 0);
+			}
+			/* Plot the PixMap if color images are preferred and sidecolors is off. */
+			if (pref_color_unit_images &! sidecolors) {
+				/* Use white backColor and black forecolor to avoid color distortion. */
+				BackColor(whiteColor);	
+				ForeColor(blackColor);
+				/* Optionally use the BitMap as mask here. This makes it possible to use
+				a single "unified" cicn instead of the the "standard" and "color" cicns. It 
+				also allows usemasks to control B/W "color" cicns, which otherwise are 
+				plotted with a white mask (if available) even if usemasks is off. */
+				if (unified_cicns) {
+					 CopyBits(&bm, &portbits, &srcrect, &imagerect, srcBic, 0);
+				} else {
 					CopyBits(&mm, &portbits, &srcrect, &imagerect, srcBic, 0);
 				}
-
-				/* Plot the PixMap if color images are preferred and side colors are off */
-				if (pref_color_unit_images &! curmap->sidecolors) {
-					/* Use white backColor and black forecolor to avoid color distortion */
-					BackColor(whiteColor);	
-					ForeColor(blackColor);
-					/* Optionally use the BitMap as mask here. This makes it possible to use */
-					/* a single "unified" cicn instead of the the "standard" and "color" cicns. */
-					/* It also allows usemasks to control B/W "color" cicns, which otherwise */
-					/* are plotted with a white mask (if available) even if usemasks is off. */
-					if (unified_cicns) {
-						 CopyBits(&bm, &portbits, &srcrect, &imagerect, srcBic, 0);
-					} else {
-						CopyBits(&mm, &portbits, &srcrect, &imagerect, srcBic, 0);
-					}
-					/* Then plot the PixMap itself in its native (non-side) color */
-					CopyBits((BitMap*) &pm, &portbits, &srcrect, &imagerect, srcOr, 0);
-
-				/* Plot the BitMap in all other cases */
-				} else {
-					CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
-
-					/* Optionally use a second side color to plot the right half of the icon */
-					if (curmap->sidecolors && half_icon_color[e] && split_icon[e]) {
-						RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
-						/* Restrict plotting to right half of image */
-						srcrect.left 	= srcrect.right / 2;
-						imagerect.left 	= imagerect.left + sw/2;
-						CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
-					}
-				}
-			} else if (curlist) {
-				/* cicns in lists (no need for masks) */
-
-				/* Plot the PixMap if color images are preferred and side colors are off */
-				if (pref_color_unit_images &! curlist->sidecolors) {
-					/* Use black forecolor to avoid color distortion */
-					 ForeColor(blackColor);
-					 CopyBits((BitMap*) &pm, &portbits, &srcrect, &imagerect, srcOr, 0);
-
-				} else {
-					/* Plot the BitMap in all other cases  */
-					CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0); 			
-					
-					/* Optionally use a second side color to plot the right half of the icon */
-					if (curlist->sidecolors && half_icon_color[e] && split_icon[e]) {
-						RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
-						/* Restrict plotting to right half of image */
-						srcrect.left 	= srcrect.right/2;
-						imagerect.left 	= imagerect.left + sw/2;
-						CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
-					}
-				}
-			
+				/* Then plot the PixMap itself in its native (non-side) color. */
+				CopyBits((BitMap*) &pm, &portbits, &srcrect, &imagerect, srcOr, 0);
+			/* Plot the BitMap in all other cases. */
 			} else {
-				/* cicns in help window etc (no need for masks or side colors) */
-				/* Plot the PixMap if color images are preferred */
-				if (pref_color_unit_images) {
-					 ForeColor(blackColor);					
-					 CopyBits((BitMap*)&pm, &portbits, &srcrect, &imagerect, srcOr, 0);
-				} else {
-					/* Plot the BitMap in all other cases */
+				CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
+				/* Optionally use a second side color to plot the right half of the icon. */
+				if (sidecolors && half_icon_color[e] && split_icon[e]) {
+					RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
+					/* Restrict plotting to right half of image. */
+					srcrect.left = srcrect.right / 2;
+					imagerect.left += sw/2;
 					CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
 				}
 			}
-						
+
 		/* Use ICON if no pict or cicn exists (or when cicn does but drawing is in B/W) */
 		} else if (macuimg->monoicon != nil) {
 			SetRect(&srcrect, 0, 0, 32, 32);
 			bm.rowBytes = 4;
 			bm.bounds = srcrect;
 
-			/* Plot the mask ICON if iconmasks is on and plotting is to map */
-			if (curmap && curmap->iconmasks) {
+			/* Plot the mask ICON if iconmasks is on. */
+			if (iconmasks) {
 				if (macuimg->maskicon != nil) {
 					bm.baseAddr = *(macuimg->maskicon);
 					CopyBits(&bm, &portbits, &srcrect, &imagerect, srcBic, 0);
@@ -282,17 +221,15 @@ draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int
 					FillRect(&imagerect, QDPat(white));
 				}
 			}
-
 			/* Now plot the real ICON */ 
 			bm.baseAddr = *(macuimg->monoicon);
 			CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
 			/* Optionally use a second color to plot the right half of the SICN */
-			if (((curmap && curmap->sidecolors) || (curlist && curlist->sidecolors)) 
-				&& half_icon_color[e] && split_icon[e]) {
+			if (sidecolors && half_icon_color[e] && split_icon[e]) {
 				RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
 				/* Restrict plotting to right half of image */
-				srcrect.left 	= srcrect.right/2;
-				imagerect.left 	= imagerect.left + sw/2;
+				srcrect.left = srcrect.right/2;
+				imagerect.left += sw/2;
 				CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
 			}
 
@@ -303,7 +240,7 @@ draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int
 			bm.bounds = srcrect;
 
 			/* Plot the mask SICN if iconmasks is on and plotting is to map */
-			if (curmap && curmap->iconmasks) {
+			if (iconmasks) {
 				if (macuimg->masksicn != nil) {
 					bm.baseAddr = *(macuimg->masksicn);
 					CopyBits(&bm, &portbits, &srcrect, &imagerect, srcBic, 0);
@@ -312,71 +249,50 @@ draw_unit_image(WindowPtr win, int sx, int sy, int sw, int sh, int u, int e, int
 					FillRect(&imagerect, QDPat(white));
 				}
 			}
-
 			/* Now plot the real SICN */
 			bm.baseAddr = *(macuimg->monosicn);
 			CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
 			/* Optionally use a second color to plot the right half of the SICN */
-			if (((curmap && curmap->sidecolors) || (curlist && curlist->sidecolors)) 
-				&& half_icon_color[e] && split_icon[e]) {
+			if (sidecolors && half_icon_color[e] && split_icon[e]) {
 				RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
 				/* Restrict plotting to right half of image. */
-				srcrect.left 	= srcrect.right / 2;
-				imagerect.left 	= imagerect.left + sw / 2;
+				srcrect.left = srcrect.right / 2;
+				imagerect.left += sw / 2;
 				CopyBits(&bm, &portbits, &srcrect, &imagerect, srcOr, 0);
 			}
 
-		/* Use box if no pict, cicn, ICON or SICN was found */
+		/* Use box if no pict, cicn, ICON or SICN was found. */
 		} else {
 			desperate = TRUE;
 		}
+	/* And also if the unit image does not exist at all. */
 	} else {
 		desperate = TRUE;
 	}
-	/* If nothing is working, draw a simple black box. */
+
 	if (desperate) {
 		FillRect(&imagerect, QDPat(black));
 		/* Optionally use a second color to plot the right half of the square */
-		if (((curmap && curmap->sidecolors) || (curlist && curlist->sidecolors)) 
-			&& half_icon_color[e] && split_icon[e]) {
+		if (sidecolors && half_icon_color[e] && split_icon[e]) {
 			RGBForeColor(&(get_sideColor(e, half_icon_color[e])));
 			/* Restrict plotting to right half of image */
-			imagerect.left = imagerect.left + sw/2;
+			imagerect.left += sw/2;
 			FillRect(&imagerect, QDPat(black));
 		}
 	}
 
-	/* Gray out units under construction. */
-	if (mod != 0) {
-
-// --- GRAYOUT BUG FIX ----------------------------------------------------
-
-		/* Make sure the whole unit is grayed out, not just the right half. */
-		gray_out_rect(&fullrect);
-
-//		gray_out_rect(&imagerect);
-
-// --------------------------------------------------------------------
-
-	}
-
 	/* Restore colors before proceeding. */
 	BackColor(whiteColor);							
 	ForeColor(blackColor);							
-
+	/* Gray out units under construction. */
+	if (mod) {
+		gray_out_rect(&fullrect);
+	}
 	/* Now draw a side emblem if asked for. */
-
-// --- USER CONTROL OF EMBLEMS -----------------------------------------
-
 	if (between(0, e, numsides) && emblem 
 	    && (curmap && curmap->draw_emblems) || (curlist && curlist->draw_emblems)) {
-
-//	if (between(0, e, numsides) && emblem) {
-
-// ------------------------------------------------------------------
-
 		ename = (side_n(e) ? side_n(e)->emblemname : NULL);
-		if (emblem_position(uimg, ename, /*eimg*/ NULL, sw, sh, &ex, &ey, &ew, &eh)) {
+		if (emblem_position(uimg, ename, eimages[e], sw, sh, &ex, &ey, &ew, &eh)) {
 			/* Do the drawing proper. */
 			draw_side_emblem(win, sx + ex, sy + ey, ew, eh, e, plain_emblem);
 		}
@@ -532,14 +448,14 @@ calc_best_terrain_images()
 	best_terrain_images = (Image **) xmalloc(NUMPOWERS * numttypes * sizeof(Image *));
 	for_all_terrain_types(t) {
 		for (p = 0; p < NUMPOWERS; ++p) {
-			timg = best_image(timages[t], hws[p], hcs[p]);
+			timg = best_image(timages[t], hws[p], hhs[p]);
 			best_terrain_images[p * numttypes + t] = timg;
 		}
 	}
 	best_unseen_images = (Image **) xmalloc(NUMPOWERS * sizeof(Image *));
 	if (unseen_image != NULL) {
 		for (p = 0; p < NUMPOWERS; ++p) {
-			timg = best_image(unseen_image, hws[p], hcs[p]);
+			timg = best_image(unseen_image, hws[p], hhs[p]);
 			best_unseen_images[p] = timg;
 		}
 	}
@@ -649,10 +565,11 @@ draw_cell_block(int sx, int sy, int n, int power, int t, int over, int angle, in
 /* Draw the given terrain type into a hexagonal region of the given size and position. */
 
 void
-draw_hex_region(int sx, int sy, int power, int t, int over, int angle, int dogrid, int dosolid)
+draw_hex_region(int sx, int sy, int power, int t, int over, int angle,
+				int dogrid, int dosolid, int var)
 {
 	int paintcolor = FALSE;
-	Image *timg;
+	Image *timg, *subimg;
 	MacImage *mactimg;
 	RGBColor hexcolor, oldcolor;
 	RgnHandle rgn;
@@ -718,12 +635,31 @@ draw_hex_region(int sx, int sy, int power, int t, int over, int angle, int dogri
 			mactimg = tcolors[t];
 		}
 	}
-	if (timg && timg->hook && mactimg == NULL)
-	  mactimg = (MacImage *) timg->hook;
+	subimg = timg;
+	if (timg->numsubimages > 0 && timg->subimages)
+	  subimg = timg->subimages[var % timg->numsubimages];
+	if (subimg && subimg->hook && mactimg == NULL)
+	  mactimg = (MacImage *) subimg->hook;
 	if (mactimg) {
 		if (hasColorQD) {
 			if (dosolid && minscreendepth > 1) {
 				paintcolor = TRUE;
+			} else if (mactimg->colricon != nil && (minscreendepth > 1 || !mactimg->patdefined)) {
+				Rect srcrect, imagerect;
+				CIconHandle cicnhandle;
+				BitMap portbits;	/* Target BitMap for CopyBits */
+				BitMap mm;			/* icon BitMap & MaskMap */
+				PixMap pm;			/* icon PixMap */
+
+				SetRect(&srcrect, 0, 0, hws[power], hhs[power]);
+				SetRect(&imagerect, sx, sy, sx + hws[power], sy + hhs[power]);
+				portbits = QD(thePort)->portBits;
+				cicnhandle = (CIconHandle) mactimg->colricon;
+				/* Get pixmap & maskmap from cicn. */
+				pm = (*(cicnhandle))->iconPMap;
+				mm = (*(cicnhandle))->iconMask;
+				/* Draw it, using the mask as the copy mask. */
+				CopyMask((BitMap *) &pm, &mm, &portbits, &srcrect, &srcrect, &imagerect);
 			} else if (mactimg->colrpat != nil && (minscreendepth > 1 || !mactimg->patdefined)) {
 				FillCRgn(rgn, mactimg->colrpat);
 			} else if (minscreendepth > 1) {
@@ -1001,7 +937,7 @@ void
 draw_connection_line_multiple(WindowPtr win, int sx, int sy, int bitmask, int power, int t, int angle, int over, int dosolid)
 {
 	int dir, wid = cwid[power], lh, ly, xoff, yoff, paintcolor = FALSE, tweakedcolor = FALSE;
-	Image *timg;
+	Image *timg, *subimg;
 	MacImage *mactimg;
 	RGBColor cellcolor, oldcolor;				
 
@@ -1019,8 +955,41 @@ draw_connection_line_multiple(WindowPtr win, int sx, int sy, int bitmask, int po
 		CopyBits(&(connbitmaps[4]), winbits, &srcrect, &destrect, srcOr, nil);
 		return;
 	}
-	PenSize(wid, wid);
+	if (best_terrain_images == NULL)
+	  calc_best_terrain_images();
+	timg = best_terrain_images[power * numttypes + t];
+	/* If we have an actual connection image with all the subimages, draw it. */
+	if (timg != NULL
+		&& timg->isconnection
+		&& timg->subimages != NULL) {
+		subimg = timg->subimages[bitmask];
+		if (subimg && subimg->hook)
+		  mactimg = (MacImage *) subimg->hook;
+		if (mactimg
+			&& hasColorQD
+			&& mactimg->colricon != nil
+			&& (minscreendepth > 1 || !mactimg->patdefined)) {
+			Rect srcrect, imagerect;
+			CIconHandle cicnhandle;
+			BitMap portbits;	/* Target BitMap for CopyBits */
+			BitMap mm;			/* icon BitMap & MaskMap */
+			PixMap pm;			/* icon PixMap */
+
+			SetRect(&srcrect, 0, 0, hws[power], hhs[power]);
+			SetRect(&imagerect, sx, sy, sx + hws[power], sy + hhs[power]);
+			portbits = QD(thePort)->portBits;
+			cicnhandle = (CIconHandle) mactimg->colricon;
+			/* Get pixmap & maskmap from cicn. */
+			pm = (*(cicnhandle))->iconPMap;
+			mm = (*(cicnhandle))->iconMask;
+			/* Draw it, using the mask as the copy mask. */
+			CopyMask((BitMap *) &pm, &mm, &portbits, &srcrect, &srcrect, &imagerect);
+		}
+		return;
+	}
+	/* Otherwise try drawing a connection the old way, as a patterned line. */
 	timg = best_image(timages[t], wid, wid);
+	PenSize(wid, wid);
 	mactimg = NULL;
 	if (hasColorQD
 		&& (dosolid || timg == NULL || timg->hook == NULL)
@@ -1119,16 +1088,16 @@ draw_terrain_sample(WindowPtr win, Rect tmprect, int t)
 
 	switch (t_subtype(t)) {
 		case cellsubtype:
-			draw_hex_region(tmprect.left, tmprect.top, 4, t, 0, 90, FALSE, dosolid);
+			draw_hex_region(tmprect.left, tmprect.top, 4, t, 0, 90, FALSE, dosolid, 0);
 			break;
 		case bordersubtype:
-			draw_border_line_multiple(win, tmprect.left, tmprect.top, -1, 4, t, 90, 0, dosolid);
+			draw_border_line_multiple(win, tmprect.left, tmprect.top, 63, 4, t, 90, 0, dosolid);
 			break;
 		case connectionsubtype:
-			draw_connection_line_multiple(win, tmprect.left, tmprect.top, -1, 4, t, 90, 0, dosolid);
+			draw_connection_line_multiple(win, tmprect.left, tmprect.top, 63, 4, t, 90, 0, dosolid);
 			break;
 		case coatingsubtype:
-			draw_hex_region(tmprect.left, tmprect.top, 4, t, 0, 90, FALSE, dosolid);
+			draw_hex_region(tmprect.left, tmprect.top, 4, t, 0, 90, FALSE, dosolid, 0);
 			/* Make it a 50% pattern. (should make more obvious somehow?) */
 			gray_out_rect(&tmprect);
 			break;
