@@ -1188,10 +1188,10 @@ set_meridians(Map *map)
 	SetPort(win);
 
 	GetDItem(win, diMeridiansOnOff, &itemtype, &itemhandle, &itemrect);
-	SetCtlValue((ControlHandle) itemhandle, map->vp->draw_latlong);
+	SetCtlValue((ControlHandle) itemhandle, map->vp->draw_meridians);
 
 	GetDItem(win, diMeridiansInterval, &itemtype, &itemhandle, &itemrect);
-	NumToString(map->vp->latlong_interval, tmpstr);
+	NumToString(map->vp->meridian_interval, tmpstr);
 	SetIText(itemhandle, tmpstr);
 
 	ShowWindow(win);
@@ -1209,12 +1209,12 @@ set_meridians(Map *map)
 
 			case diMeridiansOK:
 				GetDItem(win, diMeridiansOnOff, &itemtype, &itemhandle, &itemrect);
-				map->vp->draw_latlong = GetCtlValue((ControlHandle) itemhandle);
+				map->vp->draw_meridians = GetCtlValue((ControlHandle) itemhandle);
 				GetDItem(win, diMeridiansInterval, &itemtype, &itemhandle, &itemrect);
 	        			GetIText(itemhandle,tmpstr);
 				StringToNum(tmpstr, itemnum);
 				/* Dont allow negative values */
-				map->vp->latlong_interval = max(*itemnum, 0);
+				map->vp->meridian_interval = max(*itemnum, 0);
 
 				/* Redraw the gworld (and the map) */
 				force_map_update(map);
