@@ -12,7 +12,6 @@ any later version.  See the file COPYING.  */
 static pascal void help_vscroll_fn(ControlHandle control, short code);
 static void insert_newlines(TEHandle te, int n);
 
-
 /* Globals for the instructions window. */
 
 WindowPtr instructionswin = nil;
@@ -384,19 +383,19 @@ create_help_window()
 	SetPort(helpwin);
 	TextFont(title_font_id);
 	TextSize(title_font_size);
-	SetRect(&helptopicrect, 45, 45, 305, 75); 
+	SetRect(&helptopicrect, 45, 45, 220, 75); 
 	helptopic = TENew(&helptopicrect, &helptopicrect);
 	TextFont(small_font_id);
 	TextSize(small_font_size);
 	h = window_width(helpwin);  v = window_height(helpwin);
-	SetRect(&viewrect, 5, 75, h - sbarwid, v - sbarwid); 
+	SetRect(&viewrect, 5, 75, h - floatsbarwid, v); 
 	destrect = viewrect;
 	helptext = TENew(&destrect, &destrect);
 	/* Set up a vertical scrollbar. */
 	vscrollrect = helpwin->portRect;
-	vscrollrect.top = 75;
-	vscrollrect.bottom -= sbarwid - 1;
-	vscrollrect.left = vscrollrect.right - sbarwid;
+	vscrollrect.top = -1;
+	vscrollrect.bottom -= floatsbarwid - 1;
+	vscrollrect.left = vscrollrect.right - floatsbarwid;
 	vscrollrect.right += 1;
 	helpvscrollbar =
 		NewControl(helpwin, &vscrollrect, "\p", TRUE, 0, 0, 0, scrollBarProc, 0L);
@@ -416,6 +415,9 @@ create_help_window()
 	  nodestack = (HelpNode **) xmalloc(NODESTACKSIZE * sizeof(HelpNode *));
 	nodestackpos = 0;
 	add_window_menu_item("Help", helpwin);
+
+	/* Finally make it floating. */
+	MakeFloat(helpwin);
 }
 
 void
@@ -468,7 +470,7 @@ draw_help()
 	SetPort(helpwin);
 	/* Draw a horizontal line under the navigation buttons. */
 	MoveTo(0, 30);
-	LineTo(helpwin->portRect.right - sbarwid, 30);
+	LineTo(helpwin->portRect.right - floatsbarwid, 30);
 	SetRect(&tmprect, 5, 40, 5 + 32, 40 + 32);
 	/* Grow so as to erase extra junk that may have been drawn. */
 	InsetRect(&tmprect, -2, -2);
@@ -490,6 +492,15 @@ draw_help()
 	TextFont(small_font_id);
 	TextSize(small_font_size);
 	TEUpdate(&(helpwin->portRect), helptext);
+
+	/* Draw a default line around the close button. */
+	DrawControls(helpwin);
+	tmprect = (*closebutton)->contrlRect;
+	PenSize(3, 3);
+	InsetRect(&tmprect, -4, -4);
+	FrameRoundRect(&tmprect, 16, 16);
+	InsetRect(&tmprect,  4,  4);
+	PenNormal();
 	SetPort(oldport);
 	adjust_help_scrollbar();
 }
@@ -537,13 +548,13 @@ help_vscroll_fn(ControlHandle control, short code)
 			jump = pagesize;
 			break;
 		case inDownButton:
-			jump = 1;
+			jump = 2;
 			break;
 		case inPageUp:
 			jump = - pagesize;
 			break;
 		case inUpButton:
-			jump = -1;
+			jump = -2;
 			break;
 		default:
 			jump = 0;
@@ -558,6 +569,57 @@ help_vscroll_fn(ControlHandle control, short code)
 	  TEScroll(0, - jump * (*helptext)->lineHeight, helptext);
 }
 
+int 
+do_key_down_help(char key)
+{
+	HelpNode 	*prevhelpnode = cur_help_node;
+	int		i, handled = TRUE;
+	GrafPtr	oldport;
+
+	GetPort(&oldport);
+	SetPort(helpwin);
+
+	switch (key) {
+		case 3:		/* Enter. */
+		case 13:		/* Return. */
+		case 27:		/* Escape. */
+			close_window(helpwin);
+			break;
+		case 0x1F:		/* Down Arrow */
+			help_vscroll_fn(helpvscrollbar, inDownButton);
+			break;
+		case 0x1E:		/* Up Arrow */
+			help_vscroll_fn(helpvscrollbar, inUpButton);
+			break;
+		case 0x1C:		/* Left Arrow */
+			cur_help_node = cur_help_node->prev;
+			break;
+		case 0x1D:		/* Right Arrow */
+			cur_help_node = cur_help_node->next;
+			break;
+		case 0x0C:		/* Page Down */
+			help_vscroll_fn(helpvscrollbar, inPageDown);
+			break;
+		case 0x0B:		/* Page Up */
+			help_vscroll_fn(helpvscrollbar, inPageUp);
+			break;
+		default:
+			handled = FALSE;
+			break;
+	}
+	/* If we changed help nodes, get its contents and record on the node stack. */
+	if (prevhelpnode != cur_help_node) {
+		set_help_content(cur_help_node);
+		if (nodestackpos >= NODESTACKSIZE) {
+			for (i = 1; i < NODESTACKSIZE; ++i) nodestack[i - 1] = nodestack[i];
+			nodestackpos = NODESTACKSIZE - 1;
+		}
+		nodestack[nodestackpos++] = prevhelpnode;
+	}
+	SetPort(oldport);
+	return handled;
+}
+
 /* Respond to an event occurring in the help window. */
 
 void
@@ -667,11 +729,11 @@ grow_help(int h, int v)
 {
 	EraseRect(&helpwin->portRect);
 	SizeWindow(helpwin, h, v, 1);
-	MoveControl(helpvscrollbar, h - sbarwid, 75);
-	SizeControl(helpvscrollbar, sbarwid + 1, v - 75 - sbarwid + 1);
-	(*helptext)->viewRect.right = h - sbarwid;
-	(*helptext)->viewRect.bottom = v - sbarwid;
-	(*helptext)->destRect.right = h - sbarwid;
+	MoveControl(helpvscrollbar, h - floatsbarwid, -1);
+	SizeControl(helpvscrollbar, floatsbarwid + 1, v  - floatsbarwid + 2);
+	(*helptext)->viewRect.right = h - floatsbarwid;
+	(*helptext)->viewRect.bottom = v;
+	(*helptext)->destRect.right = h - floatsbarwid;
 	TECalText(helptext);
 	InvalRect(&helpwin->portRect);
 }					
@@ -706,12 +768,12 @@ zoom_help(int part)
 	}
 	ZoomWindow(helpwin, part, false);
 	h = window_width(helpwin);  v = window_height(helpwin);
-	MoveControl(helpvscrollbar, h - sbarwid, 0);
-	SizeControl(helpvscrollbar, sbarwid + 1, v - sbarwid + 1);
+	MoveControl(helpvscrollbar, h - floatsbarwid, -1);
+	SizeControl(helpvscrollbar, floatsbarwid + 1, v - floatsbarwid + 2);
 	adjust_help_scrollbar();
-	(*helptext)->viewRect.right = h - sbarwid;
-	(*helptext)->viewRect.bottom = v - sbarwid;
-	(*helptext)->destRect.right = h - sbarwid;
+	(*helptext)->viewRect.right = h - floatsbarwid;
+	(*helptext)->viewRect.bottom = v;
+	(*helptext)->destRect.right = h - floatsbarwid;
 	TECalText(helptext);
 	/* This will force a full redraw at the next update. */
 	InvalRect(&helpwin->portRect);
