@@ -2070,7 +2070,10 @@ hit_player_setup_dialog(int ditem, Point mouse)
 		case diPlayerSetupAdd:
 			add_side_and_player();
 			/* Select the newly-created side/player pair. */
-			select_player(numsides - 1);
+			select_player(numsides);
+			/* Put it under mplayer control by default. */
+			tmpplayer = selected_player();
+			tmpplayer->aitypename = "mplayer";
 			init_emblem_images();
 			changedall = TRUE;
 			break;
