@@ -9,7 +9,6 @@ any later version.  See the file COPYING.  */
 #include "conq.h"
 #include "macconq.h"
 
-extern void scroll_list_using_key(List *list, char key);
 static pascal void list_vscroll_fn(ControlHandle control, short code);
 static pascal void list_hscroll_fn(ControlHandle control, short code);
 
@@ -685,37 +684,45 @@ list_hscroll_fn(ControlHandle control, short code)
 
 }
 
-void
-scroll_list_using_key(List *list, char key)
+int
+do_key_down_list(List *list, char key)
 {
+	int		handled = TRUE;
 	GrafPtr	oldport;
 
 	GetPort(&oldport);
-	/* Set current port to the list window. */
 	SetPort(list->window);
 	curlist = list;
+
 	switch (key) {
-		case 0x7D:		/* Down Arrow */
-		case 0x54:		/* Keypad 2 */
+		case 27:		/* Escape key. */
+			close_window(curlist->window);
+			break;
+		case 0x1F:		/* Down Arrow. */
 			list_vscroll_fn(curlist->vscrollbar, inDownButton);
 			break;
-		case 0x7E:		/* Up Arrow */
-		case 0x5B:		/* Keypad 8 */
+		case 0x1E:		/* Up Arrow. */
 			list_vscroll_fn(curlist->vscrollbar, inUpButton);
 			break;
-		case 0x7C:		/* Right Arrow */
-		case 0x58:		/* Keypad 6 */
+		case 0x1D:		/* Right Arrow. */
 			list_hscroll_fn(curlist->hscrollbar, inDownButton);
 			break;
-		case 0x7B:		/* Left Arrow */
-		case 0x56:		/* Keypad 4 */
+		case 0x1C:		/* Left Arrow. */
 			list_hscroll_fn(curlist->hscrollbar, inUpButton);
 			break;
+		case 0x0C:		/* Page Down. */
+			list_vscroll_fn(curlist->vscrollbar, inPageDown);
+			break;
+		case 0x0B:		/* Page Up. */
+			list_vscroll_fn(curlist->vscrollbar, inPageUp);
+			break;
 		default:
-			beep();
+			/* The key was not handled here. */
+			handled = FALSE;
 			break;
 	}
 	SetPort(oldport);
+	return handled;
 }
 
 
