@@ -23,7 +23,7 @@ any later version.  See the file COPYING.  */
 
 static void draw_feature_names(Map *map, Rect drawrect);
 static void update_grid_leakage(Map *map);
-static void adjust_latlong_interval(Map *map);
+static void adjust_meridian_interval(Map *map);
 static void draw_meridians(Map *map, Rect drawrect);
 static void draw_info_text(Map *map, int x, int y, int len, char *buf);
 static void draw_unit_names_only(Map *map, int x, int y);
@@ -341,7 +341,7 @@ create_map(int power, int id)
 	map->optimize_fonts = default_optimize_fonts;
 	map->max_bufx = default_max_bufx;
 	map->max_bufy = default_max_bufy;	
-	map->vp->draw_latlong = default_draw_latlong;
+	map->vp->draw_meridians = default_draw_meridians;
 	map->solid_color_terrain = pref_solid_color_terrain;
 	map->draw_topline = default_draw_topline;
 	map->draw_topunit = default_draw_topunit;
@@ -359,9 +359,10 @@ create_map(int power, int id)
 	/* Override default and turn on other-map boxes for world map. */
 	if (map == worldmap)
 		map->vp->draw_other_maps = TRUE;
-	map->vp->latlong_interval = default_latlong_interval;
-	/* Adjust the default latlong interval so that it is appropriate for this magnification. */
-	adjust_latlong_interval(map);
+	map->vp->meridian_interval = default_meridian_interval;
+	/* Adjust the default meridian interval so that it is
+           appropriate for this magnification. */
+	adjust_meridian_interval(map);
 	map->autoselect = defaultautoselect;
 	map->moveonclick = defaultmoveonclick;
 	map->drawsizes = default_drawsizes;
@@ -560,39 +561,40 @@ set_map_power(Map *map, int power)
 {
 	set_view_power(map->vp, power);
 
-	/* Make sure the latlong interval is appropriate for the new magnification. */
-	adjust_latlong_interval(map);
+	/* Make sure the meridian interval is appropriate for the new
+           magnification. */
+	adjust_meridian_interval(map);
 
 	if (power >= 4 && cellrgns[power] == nil)
 	  make_cell_clip(power);
 }
 
 void
-adjust_latlong_interval(Map *map)
+adjust_meridian_interval(Map *map)
 {
 	/* Skip if meridians are not defined. */
 	if (world.circumference <= 0)
 		return;
 	/* First set the interval so that it corresponds to 64 pixels. */
-	map->vp->latlong_interval = 64 * 21600 / (world.circumference * map->vp->hw);
+	map->vp->meridian_interval = 64 * 21600 / (world.circumference * map->vp->hw);
 	/* Then adjust it upwards to an even number of degrees or minutes. */
-	if (map->vp->latlong_interval <= 10)
-	      	map->vp->latlong_interval = 10;
-	else if (map->vp->latlong_interval <= 30)
-		map->vp->latlong_interval = 30;
-	else if (map->vp->latlong_interval <= 60)
-		map->vp->latlong_interval = 60;
-	else if (map->vp->latlong_interval <= 120)
-		map->vp->latlong_interval = 120;
-	else if (map->vp->latlong_interval <= 300)
-		map->vp->latlong_interval = 300;
-	else if (map->vp->latlong_interval <= 600)
-		map->vp->latlong_interval = 600;
-	else if (map->vp->latlong_interval <= 1200)
-		map->vp->latlong_interval = 1200;
-	else if (map->vp->latlong_interval <= 3600)
-		map->vp->latlong_interval = 3600;
-	else	map->vp->latlong_interval = 0;
+	if (map->vp->meridian_interval <= 10)
+	      	map->vp->meridian_interval = 10;
+	else if (map->vp->meridian_interval <= 30)
+		map->vp->meridian_interval = 30;
+	else if (map->vp->meridian_interval <= 60)
+		map->vp->meridian_interval = 60;
+	else if (map->vp->meridian_interval <= 120)
+		map->vp->meridian_interval = 120;
+	else if (map->vp->meridian_interval <= 300)
+		map->vp->meridian_interval = 300;
+	else if (map->vp->meridian_interval <= 600)
+		map->vp->meridian_interval = 600;
+	else if (map->vp->meridian_interval <= 1200)
+		map->vp->meridian_interval = 1200;
+	else if (map->vp->meridian_interval <= 3600)
+		map->vp->meridian_interval = 3600;
+	else	map->vp->meridian_interval = 0;
 }
 
 /* This is the old set_focus from maccmd.c moved here and renamed for consistency. */
@@ -1110,7 +1112,7 @@ Map *map;
 	if (features_defined() && map->featurenames && map->vp->hh > 3)
 		draw_feature_names(map, map->gworldPortPtr->portRect);
 	/* Now draw the lat-long grid if asked to do so. */
-	if (map->vp->draw_latlong && map->vp->latlong_interval > 0)
+	if (map->vp->draw_meridians && map->vp->meridian_interval > 0)
 	 	 draw_meridians(map, map->gworldPortPtr->portRect);
 }
 
@@ -1174,7 +1176,7 @@ draw_meridians(Map *map, Rect drawrect)
 	if (world.circumference <= 0)
 		return;
 	/* Compute the interval between meridians in pixels. */
-	incr = map->vp->latlong_interval;
+	incr = map->vp->meridian_interval;
 	interval = (incr * world.circumference * map->vp->hw) / 21600;
 	
 	/* Return if this interval is too small. */
@@ -2407,7 +2409,7 @@ update_cell(Map *map, int x, int y)
 					draw_feature_names(map, sourceRect));
 
 	/* Redraw any meridians that will fall within destRect. */ 
-	if (map->vp->draw_latlong && map->vp->latlong_interval > 0) {
+	if (map->vp->draw_meridians && map->vp->meridian_interval > 0) {
 		/* Use red color if debugging the graphics. */
 		/* (black color is always restored by draw_meridians). */
 		if (DebugG)
