@@ -768,6 +768,12 @@ do_menu_command(long which)
 					ui_update_state();
 					save_preferences();
 					break;
+				case miSideAutoResearch:
+					if (numatypes > 0 && g_side_can_research()) {
+						net_set_autoresearch(dside, !dside->autoresearch);
+						draw_research_dialog(true);
+					}
+					break;
 				case miSideSendMessage:
 					do_message(dside);
 					break;
@@ -807,7 +813,13 @@ do_menu_command(long which)
 					show_command_window();
 					break;
 				case miWindowsResearch:
-					side_research_dialog(dside, NULL, -1);
+					if (numatypes > 0) {
+						/* Do side research if defined. */
+						if (g_side_can_research())
+							show_research_dialog();
+						/* Else do unit based research. */
+						else	side_research_dialog(dside, NULL, -1);
+					}
 					break;
 				case miWindowsScores:
 					show_scores_window();
@@ -1989,6 +2001,13 @@ adjust_menus()
 					  (map ? map->autoselect : defaultautoselect));
 			CheckItem(menu, miSideAutoFinish, dside->autofinish);
 			CheckItem(menu, miSideSound, playsounds);
+			if (numatypes > 0
+	    		    && g_side_can_research()) {
+				EnableItem(menu, miSideAutoResearch);
+				CheckItem(menu, miSideAutoResearch, dside->autoresearch);
+			} else {
+				DisableItem(menu, miSideAutoResearch);
+			}
 			if (dside->nameslocked) {
 				DisableItem(menu, miSideRename);
 			} else {
@@ -2020,12 +2039,18 @@ adjust_menus()
 				DisableItem(menu, miWindowsConstruction);
 			}
 			DisableItem(menu, miWindowsResearch);
-			for_all_side_units(dside, unit) {
+			if (numatypes > 0) {
+				if (g_side_can_research()) {
+					EnableItem(menu, miWindowsResearch);
+				} else for_all_side_units(dside, unit) {
 				if (u_advanced(unit->type)) {
 					EnableItem(menu, miWindowsResearch);
 					break;
 				}
 			}
+			}
+			CheckItem(menu, miWindowsResearch,
+				(researchwin && ((WindowPeek) researchwin)->visible));
 			CheckItem(menu, miWindowsScores,
 				(scoreswin && ((WindowPeek) scoreswin)->visible));
 #ifdef DESIGNERS
