@@ -687,9 +687,9 @@ toggle_optimize_fonts(Map *map)
 }
 
 void
-toggle_draw_latlong(Map *map)
+toggle_draw_meridians(Map *map)
 {
-	map->vp->draw_latlong = !map->vp->draw_latlong;
+	map->vp->draw_meridians = !map->vp->draw_meridians;
 	force_map_update(map);
 }
 
