@@ -50,10 +50,10 @@ int default_draw_unit_numbers = FALSE;
 int default_draw_feature_names = FALSE;
 
 /* True if should display latitude and longitude of locations. */
-int default_draw_latlong = TRUE;
+int default_draw_meridians = TRUE;
 
 /* Spacing, in minutes, of latitude/longitude lines. */
-int default_latlong_interval = 300;
+int default_meridian_interval = 300;
 
 int
 open_preferences()
@@ -193,10 +193,10 @@ interp_mac_ui_data(Obj *uispec)
 				default_draw_grid = numval;
 			} else if (strcmp(name, "default-draw-names") == 0) {
 				default_draw_names = numval;
-			} else if (strcmp(name, "default-draw-latlong") == 0) {
-				default_draw_latlong = numval;
-			} else if (strcmp(name, "default-latlong-interval") == 0) {
-				default_latlong_interval = numval;
+			} else if (strcmp(name, "default-draw-meridians") == 0) {
+				default_draw_meridians = numval;
+			} else if (strcmp(name, "default-meridian-interval") == 0) {
+				default_meridian_interval = numval;
 			} else if (strcmp(name, "color-unit-images") == 0) {
 				pref_color_unit_images = numval;
 			} else if (strcmp(name, "solid-color-terrain") == 0) {
@@ -349,8 +349,8 @@ ui_update_state()
 	push_binding(&state, intern_symbol("checkpoint-interval"), new_number(checkpoint_interval));
 	push_binding(&state, intern_symbol("default-draw-grid"), new_number(default_draw_grid));
 	push_binding(&state, intern_symbol("default-draw-names"), new_number(default_draw_names));
-	push_binding(&state, intern_symbol("default-draw-latlong"), new_number(default_draw_latlong));
-	push_binding(&state, intern_symbol("default-latlong-interval"), new_number(default_latlong_interval));
+	push_binding(&state, intern_symbol("default-draw-meridians"), new_number(default_draw_meridians));
+	push_binding(&state, intern_symbol("default-meridian-interval"), new_number(default_meridian_interval));
 	push_binding(&state, intern_symbol("color-unit-images"), new_number(pref_color_unit_images));
 	push_binding(&state, intern_symbol("solid-color-terrain"), new_number(pref_solid_color_terrain));
 	push_binding(&state, intern_symbol("small-font-size"), new_number(small_font_size));
@@ -561,12 +561,12 @@ set_preferences()
 						default_draw_names = GetCtlValue((ControlHandle) itemhandle);
 						GetDItem(win, diPrefsSolidColorTerrain, &itemtype, &itemhandle, &itemrect);
 						pref_solid_color_terrain = GetCtlValue((ControlHandle) itemhandle);
-						GetDItem(win, diPrefsLatLong, &itemtype, &itemhandle, &itemrect);
-						default_draw_latlong = GetCtlValue((ControlHandle) itemhandle);
+						GetDItem(win, diPrefsMeridians, &itemtype, &itemhandle, &itemrect);
+						default_draw_meridians = GetCtlValue((ControlHandle) itemhandle);
 						get_number_from_ditem(diPrefsIncr, new_incr);
 						/* Can't use directly in get_number_from_ditem macro, can't
 						   guarantee size of variable being written into. */
-						default_latlong_interval = new_incr;
+						default_meridian_interval = new_incr;
 
 						GetDItem(win, diPrefsSideColors, &itemtype, &itemhandle, &itemrect);
 						default_sidecolors = GetCtlValue((ControlHandle) itemhandle);
@@ -810,7 +810,7 @@ set_preferences()
 							case diPrefsGrid:
 							case diPrefsNames:
 							case diPrefsSolidColorTerrain:
-							case diPrefsLatLong:
+							case diPrefsMeridians:
 							case diPrefsSideColors:
 							case diPrefsIconMasks:
 							case diPrefsBoxMasks:
@@ -1223,9 +1223,9 @@ add_preferences_topic_items(DialogPtr win)
 			SetCtlValue((ControlHandle) itemhandle, default_draw_names);
 			GetDItem(win, diPrefsSolidColorTerrain, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, pref_solid_color_terrain);
-			GetDItem(win, diPrefsLatLong, &itemtype, &itemhandle, &itemrect);
-			SetCtlValue((ControlHandle) itemhandle, default_draw_latlong);
-			put_number_into_ditem(diPrefsIncr, default_latlong_interval);
+			GetDItem(win, diPrefsMeridians, &itemtype, &itemhandle, &itemrect);
+			SetCtlValue((ControlHandle) itemhandle, default_draw_meridians);
+			put_number_into_ditem(diPrefsIncr, default_meridian_interval);
 			GetDItem(win, diPrefsSideColors, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_sidecolors);
 			GetDItem(win, diPrefsIconMasks, &itemtype, &itemhandle, &itemrect);
