@@ -167,9 +167,8 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 		/* Draw connections and borders. */
 		if (any_aux_terrain_defined()) {
 			if (bords_to_draw(map)) {
-				for_all_terrain_types(t) {
+				for_all_border_types(t) {
 					if (map->vp->draw_aux_terrain[t] 
-						&& t_is_border(t) 
 						&& aux_terrain_defined(t)) {
 							draw_borders(map, x, y, t);
 					}
@@ -177,9 +176,8 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 			}
 			/* Connections should always be drawn on top of borders. */
 			if (conns_to_draw(map)) {
-				for_all_terrain_types(t) {
+				for_all_connection_types(t) {
 					if (map->vp->draw_aux_terrain[t] 
-						&& t_is_connection(t) 
 						&& aux_terrain_defined(t)) {
 							draw_connections(map, x, y, t);
 					}
@@ -307,9 +305,8 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 	/* Draw connections and borders. */
 	if (any_aux_terrain_defined()) {
 		if (bords_to_draw(map)) {
-			for_all_terrain_types(t) {
+			for_all_border_types(t) {
 				if (map->vp->draw_aux_terrain[t] 
-					&& t_is_border(t) 
 					&& aux_terrain_defined(t)) {
 						for (x = x0; x < x0 + len; ++x)
 							draw_borders(map, x, y, t);
@@ -318,9 +315,8 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 		}
 		/* Connections should always be drawn on top of borders. */
 		if (conns_to_draw(map)) {
-			for_all_terrain_types(t) {
+			for_all_connection_types(t) {
 				if (map->vp->draw_aux_terrain[t] 
-					&& t_is_connection(t) 
 					&& aux_terrain_defined(t)) {
 						for (x = x0; x < x0 + len; ++x)
 							draw_connections(map, x, y, t);
