@@ -30,7 +30,6 @@ extern void mac_init_cicn(Image *img);
 extern void unit_research_dialog(Unit *unit);			
 extern void unit_plan_dialog(Unit *unit);
 extern int unit_build_dialog(Unit *unit);
-extern int has_advance_to_research(Side *side, int atype);
 
 static void draw_simple_closeup(UnitCloseup *closeup);
 static void draw_advanced_closeup(UnitCloseup *closeup);
@@ -39,8 +38,6 @@ static void draw_closeup_content(DialogPtr win, Unit *unit);
 static void plot_resource_cicns(Map *map, Rect plotrect, int x, int y);
 static void draw_landuse_near_unit(Map *map, WindowPtr win, Rect itemrect, Unit *unit, int near);
 static void toggle_landuse_one_cell(Map *map, WindowPtr win, Rect itemrect, Unit *unit, int x, int y);
-static MenuHandle build_construction_menu(Unit *unit);
-static MenuHandle build_research_menu(Side *side);
 
 DialogPtr unit_advance_win = nil;
 DialogPtr unit_build_win = nil;
