@@ -11,7 +11,6 @@ extern char *curdatestr;
 extern char *goal_desc(char *buf, Goal *goal);
 extern int update_total_hist_lines(Side *side);
 extern int build_hist_contents(Side *side, int n, HistEvent **histcontents, int numvis);
-extern int has_advance_to_research(Side *side, int atype);
 extern void side_research_dialog(Side *side, Unit *unit, int advance);			
 
 static int get_selected_construction_advance();
@@ -38,6 +37,10 @@ static pascal void scores_vscroll_fn(ControlHandle control, short code);
 static void calc_history_layout(void);
 static void set_history_scrollbar(void);
 
+/* Globals for the research window. */
+
+WindowPtr researchwin = nil;
+
 /* Globals for the game window. */
 
 WindowPtr gamewin = nil;
@@ -956,6 +959,7 @@ int key;
 	CharsHandle text;
 
 	if (isdigit(key)) {
+		/* Feed digits to the run length field. */
 		TEKey(key, run_length_text);
 		text = TEGetText(run_length_text);
 		/* Pick out only the initial digits (up to 9). */
@@ -968,6 +972,10 @@ int key;
 			editedrunlength = runlength;
 			return TRUE;
 		}
+	} else if (key == 8) {
+		/* Also feed erase key the run length field. */
+		TEKey(key, run_length_text);
+		return TRUE;
 	} else if (key == 13 || key == 3) {
 		/* Pass enters and returns back to Dialog Manager. */
 		return FALSE;
@@ -980,14 +988,6 @@ int key;
 				return TRUE;
 			}
 		}
-		/* If not recognized as a unit type shortcut, hand it to the
-		   run length field. */
-		if (isalpha(key)) {
-			beep();
-			return FALSE;
-		}
-		TEKey(key, run_length_text);
-
 	}
 	return FALSE;
 }
@@ -1318,6 +1318,185 @@ adjust_construction_items()
 	LCellSize(cellsize, construction_advance_list);
 }
 
+/* This is the top-level access to bring up the research window, can be called
+   anywhere, anytime. */
+
+void
+show_research_dialog()
+{
+	int		height, mainheight;
+
+	if (!active_display(dside))
+	    return;
+	/* Create it if necessary. */
+	if (researchwin == nil) {
+		researchwin = GetNewDialog(dSideResearch, NULL, NULL);
+		SetWTitle(researchwin, "\pResearch");
+		/* Put it at the bottom adjacent to noticewin. */
+		get_main_screen_size(NULL, &mainheight);
+		height = researchwin->portRect.bottom - researchwin->portRect.top;
+		MoveWindow(researchwin, 411, mainheight - height - 5, false);
+		MakeDialogFloat(researchwin);
+	}
+	SelectTheWindow(researchwin);
+	ActivateWindow(researchwin, true);
+	draw_research_dialog(true);
+}
+
+void
+draw_research_dialog(int force)
+{
+	char			buf1[BUFSIZE], buf2[BUFSIZE], buf3[BUFSIZE];
+	short 		i, m;
+	Str255 		pname;
+	Handle 		itemhandle; 
+	MenuHandle	advanceMenu;
+	GrafPtr 		oldport;
+	
+	/* Skip if we lack display or research window. */
+	if (!active_display(dside) || !researchwin)
+		return;
+	GetPort(&oldport);
+	SetPort(researchwin);
+
+	/* Set the autoresearch checkbox. */
+	GetDItem(researchwin, diSideResearchCheck, NULL, &itemhandle, NULL);
+	SetCtlValue((ControlHandle) itemhandle, dside->autoresearch);
+
+	/* Get the current research topic, if any. */
+	if (dside->research_topic != NOADVANCE) { 
+	   	 strcpy(buf1, a_type_name(dside->research_topic));
+	} else strcpy(buf1, "Idle"); 
+
+	/* Set the popup menu to the current research topic. */
+	advanceMenu = build_research_menu(dside);
+	m = CountMItems(advanceMenu);
+	GetDItem(researchwin, diSideResearchPopup, NULL, &itemhandle, NULL);
+	SetCtlMax((ControlHandle) itemhandle, m);	/* Important! */
+	for (i = 1; i <= m; i++) {
+		GetItem(advanceMenu, i, pname);
+		p2c(pname, buf2);
+		if (strcmp(buf1, buf2) != 0)
+			continue;
+		SetCtlValue((ControlHandle) itemhandle, i);
+	}
+	/* Build the two text fields. */
+	if (dside->research_topic == NOADVANCE) {
+		strcpy(buf1, "Your wise men are\r\r\r");
+		strcpy(buf2, "Pick a new research topic");
+	} else {
+		strcpy(buf1, "You are researching\r\r\r"); 
+		NumToString(dside->advance[dside->research_topic], pname);
+		p2c(pname, buf3);
+		strcpy(buf2, buf3);
+		strcat(buf2, " of ");
+		NumToString(a_rp(dside->research_topic), pname);
+		p2c(pname, buf3);
+		strcat(buf2, buf3);
+		strcat(buf2, " points completed");
+	}
+	/* Check if either text field needs an update. */
+	GetDItem(researchwin, diSideResearchText1, NULL, &itemhandle, NULL);
+	GetIText(itemhandle, pname);
+	p2c(pname, buf3);
+	if (strcmp(buf1, buf3) != 0) {
+		c2p(buf1, pname);
+		SetIText(itemhandle, pname);
+		force = TRUE;
+	}
+	GetDItem(researchwin, diSideResearchText2, NULL, &itemhandle, NULL);
+	GetIText(itemhandle, pname);
+	p2c(pname, buf3);
+	if (strcmp(buf2, buf3) != 0) { 
+		c2p(buf2, pname);
+		SetIText(itemhandle, pname);
+		force = TRUE;
+	}
+	if (force) {
+		DrawDialog(researchwin);
+		draw_default_button(researchwin, OkButton);
+	}
+	SetPort(oldport);
+}	
+
+int 
+do_key_down_research(char key)
+{
+	/* Use the Enter or Return key to exit. */
+	if (key == 3 || key == 13) {
+		hit_research_dialog(diSideResearchClose);
+		return TRUE;
+	/* Use the Escape key for the Help button. */
+	} else if (key == 27) {
+		hit_research_dialog(diSideResearchHelp);
+		return TRUE;
+	} else return FALSE;
+}
+
+void
+hit_research_dialog(int ditem)
+{
+	short			autoresearch, advance, mitem, done = FALSE, a, i, m;
+	char			sname[32], cname[32];
+	MenuHandle	advanceMenu;
+	HelpNode 		*helpnode;
+	Str255 		pname;
+	Handle 		itemhandle;  
+	GrafPtr 		oldport;
+
+	GetPort(&oldport);	
+	SetPort(researchwin);
+
+	switch (ditem) {
+
+		/* Toggle autoresearch. */
+		case diSideResearchCheck: 		
+			GetDItem(researchwin, ditem, NULL, &itemhandle, NULL);
+			SetCtlValue((ControlHandle) itemhandle, !GetCtlValue((ControlHandle) itemhandle));
+			autoresearch = GetCtlValue((ControlHandle) itemhandle);
+			net_set_autoresearch(dside, autoresearch);
+		break;
+
+		/* Pick a new research topic. */
+		case diSideResearchPopup: 		
+			advanceMenu = build_research_menu(dside);
+			GetDItem(researchwin, ditem, NULL, &itemhandle, NULL);
+			mitem = GetCtlValue((ControlHandle) itemhandle);
+			GetItem(advanceMenu, mitem, pname);
+			p2c(pname, sname);
+			advance = NOADVANCE;
+			for_all_advance_types(a) {
+				if (strcmp(a_type_name(a), sname) == NULL) {
+					advance = a;
+					break;
+				}
+			}
+			net_set_side_research(dside, advance);
+		break;
+
+		case diSideResearchHelp:
+			if (dside->research_topic != NOADVANCE) {	
+				helpnode = find_help_node(first_help_node, a_type_name(dside->research_topic));
+				if (helpnode)
+					show_help_window(helpnode);
+				else 	beep();
+			}
+		break;
+
+		case 	diSideResearchClose:
+			done = TRUE;
+		break;
+		
+		default:
+		break;
+	}
+	/* Force a redrawing of the dialog. */
+	draw_research_dialog(true);
+	if (done)
+	    	close_window(researchwin);
+	SetPort(oldport);
+}
+
 /*
 	Research dialog for all advanced units belonging to a side. Unit is the city that just made a
 	discovery and advance the discovery itself. Set to NULL and (-1) if no discovery was made. 
