@@ -10,6 +10,7 @@ any later version.  See the file COPYING.  */
 #include "kpublic.h"
 #include "tkconq.h"
 Unit *embarkation_unit(Unit *unit);
+#include "print.h"
 
 void really_do_design(Side *side);
 
@@ -928,9 +929,9 @@ do_map(Side *side)
 	  vp->vertscale = map->prefixarg;
 	redraw_map(map);
     } else if (strcmp(cmdargstr, "meridians") == 0) {
-	vp->draw_latlong = !vp->draw_latlong;
+	vp->draw_meridians = !vp->draw_meridians;
 	if (map->prefixarg > 0)
-	  vp->latlong_interval = map->prefixarg;
+	  set_meridian_interval(vp, map->prefixarg);
 	redraw_map(map);
     } else if (strcmp(cmdargstr, "over") == 0) {
 	vp->isometric = FALSE;
@@ -1175,7 +1176,31 @@ aux_others(Side *side, Map *map, int cancel)
 void
 do_print_view(Side *side)
 {  
-    cmd_error(side, "Not implemented.");
+    double conv;
+    PrintParameters *ps_pp;
+
+    ps_pp = (PrintParameters *) xmalloc(sizeof(PrintParameters));
+
+    init_ps_print(ps_pp);
+
+    /* convert to cm or in */
+    if (ps_pp->cm) {
+	conv = 72 / 2.54;
+    } else {
+	conv = 72;
+    }
+    ps_pp->cell_size /= conv;
+    ps_pp->cell_grid_width /= conv;
+    ps_pp->border_width /= conv;
+    ps_pp->connection_width /= conv;
+    ps_pp->page_width /= conv;
+    ps_pp->page_height /= conv;
+    ps_pp->top_margin /= conv;
+    ps_pp->bottom_margin /= conv;
+    ps_pp->left_margin /= conv;
+    ps_pp->right_margin /= conv;
+
+    dump_ps_view(dside, ps_pp, "view.ps");
 }
 
 void
@@ -1311,6 +1336,11 @@ do_refresh(Side *side)
 {
     Map *map;
 
+    reset_coverage();
+    reset_all_views();
+    dside->ui->legends = NULL;
+    compute_all_feature_centroids();
+    place_legends(dside);
     for_all_maps(map) {
 	redraw_map(map);
     }
@@ -1635,7 +1665,7 @@ do_survey(Side *side)
 	map->autoselect = !map->autoselect;
 	map->move_on_click = !map->move_on_click;
     }
-    set_tool_cursor(side, map);
+    set_tool_cursor(map, 0);
     if (!map->autoselect && map->curunit != NULL)
       update_at_unit(map, map->curunit);
     if (map->mode == move_mode)
@@ -1773,8 +1803,14 @@ do_design(Side *side)
 	eval_tcl_cmd("update_show_all_info %d", dside->may_set_show_all);
 	for_all_maps(map2) {
 	    set_show_all(map2, side->show_all);
-	    redraw_map(map);
+	    /* Force back to survey mode; would be perhaps spiffier to
+	       switch back to pre-design mode, but given the effects
+	       of design mode, not much reason to bother. */
+	    map->mode = survey_mode;
+	    set_tool_cursor(map, 0);
 	}
+	/* Just redo every display. */
+	do_refresh(side);
 	eval_tcl_cmd("dismiss_design_palette");
     }
 }
