@@ -1,5 +1,5 @@
 /* Definitions for the tcl/tk interface to Xconq.
-   Copyright (C) 1998, 1999 Stanley T. Shebs.
+   Copyright (C) 1998-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -10,6 +10,7 @@ any later version.  See the file COPYING.  */
 #include <tk.h>
 
 #include <math.h>
+#include <sys/time.h>
 
 #include "imf.h"
 #include "ui.h"
@@ -22,8 +23,15 @@ any later version.  See the file COPYING.  */
 enum mapmode {
   survey_mode,
   move_mode,
+  no_tmp_mode,
+  attack_mode,
   fire_mode,
   build_mode,
+  no_scroll_mode,
+  scroll_up_mode,
+  scroll_right_mode,
+  scroll_down_mode,
+  scroll_left_mode,
 #ifdef DESIGNERS
   cell_paint_mode,
   bord_paint_mode,
@@ -125,7 +133,7 @@ typedef struct a_ui {
     XColor **numunitcolors;
     short dflt_color_embl_images;
     short pref_solid_color_terrain;
-    short default_latlong_interval;
+    short default_meridian_interval;
 
     /* Map-related slots. */
     struct a_map *maps;		/* Chain of maps that are up */
@@ -190,19 +198,6 @@ typedef struct a_ui {
     Font flegendfids[6];
 #endif
     Legend *legends;
-    int numfeatures;
-    /* Side closeup list */
-    struct a_side_closeup *sidecloseuplist;
-    /* Unit list */
-    struct a_unit_list *unitlistlist;
-    /* Unit closeup list */
-    struct a_unit_closeup *unitcloseuplist;
-    /* Unit closeup summary */
-    struct a_closeup_summary *closeupsummary;
-
-    StandingOrder *sorder_edit;
-    char *sorder_types_edit;
-    Task *sorder_task_edit;
 
     int *grok_p1;
     int *grok_p2;
@@ -221,7 +216,8 @@ typedef struct a_ui {
 
 typedef struct a_map {
     int number;
-    enum mapmode mode;
+    enum mapmode mode;		/* User's main interaction mode */
+    enum mapmode tmp_mode;	/* Action possible at mouse position */
     int autoselect;
     int move_on_click;
     int show_all;
@@ -253,7 +249,10 @@ typedef struct a_map {
     char answer[BUFSIZE];	/* string being typed in */
     int tmpint;
 
-    int lastrawx, lastrawy;
+    int last_rawx[2], last_rawy[2];
+    enum mapmode scroll_mode[2];
+    int autoscroll_delaying[2];
+    struct timeval autoscroll_start_time[2];
 
     short anim_state;
 
@@ -277,6 +276,7 @@ extern int in_middle(Map *map, int x, int y);
 
 extern void redraw_map(Map *map);
 extern VP *widget_vp(Map *map);
+extern VP *worldw_vp(Map *map);
 
 extern void eval_tcl_cmd(char *fmt, ...);
 
@@ -295,7 +295,7 @@ extern void update_action_controls_info(Map *map);
 extern void update_view_controls_info(void);
 extern void draw_fire_line(Map *map, Unit *unit, Unit *unit2, int x2, int y2);
 extern void draw_blast(Map *map, Unit *unit, int blasttype, int duration);
-extern void set_tool_cursor(Side *side, Map *map);
+extern void set_tool_cursor(Map *map, int which);
 
 extern void initial_ui_init(void);
 extern void init_display(void);
