@@ -393,7 +393,7 @@ static XImage *xim;
 static void
 tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 {
-    int r, ri, rc, depth, c, rmask, pix;
+    int r, ri, rc, depth, c, rmask, pix, use_images_here;
     XColor col, *color;
     char *rp;
     GC gc;
@@ -459,7 +459,10 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	imdepth = 32;
 #endif
     }
-    if (use_images) {
+    use_images_here = use_images;
+    if ((img->w & 1) == 1 || (img->h & 1) == 1)
+      use_images_here = FALSE;
+    if (use_images_here) {
 #ifdef UNIX
 	ximbuf = (char *) xmalloc(img->w * img->h * (imdepth / 8));
 #else
@@ -485,7 +488,7 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	    pix = 0;
 	    if (tkimg->cmap[rc] && rc < 256)
 	      pix = tkimg->cmap[rc]->pixel;
-	    if (use_images) {
+	    if (use_images_here) {
 		if (imdepth == 16) {
 #if 1
 		    *(((short *) ximbuf) + (img->w * r + c)) = pix;
@@ -506,7 +509,7 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	    rp++;
 	}
     }
-    if (use_images) {
+    if (use_images_here) {
 #if 0 /* this is probably the right approach to use someday */
 	int numvisuals;
 	XVisualInfo visinfo, *visinfoptr;
@@ -533,7 +536,7 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 static void
 tk_make_mono_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 {
-    int r, ri, rc, depth, c, rmask, pix;
+    int r, ri, rc, depth, c, rmask, pix, use_images_here;
     XColor col;
     char *rp;
     GC gc;
@@ -578,7 +581,10 @@ tk_make_mono_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	use_images = TRUE;
 #endif
     }
-    if (use_images) {
+    use_images_here = use_images;
+    if ((img->w & 1) == 1 || (img->h & 1) == 1)
+      use_images_here = FALSE;
+    if (use_images_here) {
 	ximbuf = (char *) xmalloc(img->w * img->h * 2 * sizeof(char));
     }
     for (r = 0; r < img->h; r++) {
@@ -593,7 +599,7 @@ tk_make_mono_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 		rp++;
 	    }
 	    pix = (rc ? blackcolor : whitecolor)->pixel;
-	    if (use_images) {
+	    if (use_images_here) {
 		ximbuf[(img->w * r + c) * 2 + 0] = pix & 0xff;
 		ximbuf[(img->w * r + c) * 2 + 1] = pix >> 8;
 	    } else {
@@ -605,7 +611,7 @@ tk_make_mono_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	    rp++;
 	}
     }
-    if (use_images) {
+    if (use_images_here) {
 	Visual *vis;
 
 	vis = Tk_Visual(rootwin);
@@ -623,7 +629,7 @@ tk_make_mono_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 static void
 tk_make_mask_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 {
-    int r, ri, rc, depth, c, rmask, pix;
+    int r, ri, rc, depth, c, rmask, pix, use_images_here;
     XColor col;
     char *rp;
     GC gc;
@@ -665,7 +671,10 @@ tk_make_mask_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	use_images = TRUE;
 #endif
     }
-    if (use_images) {
+    use_images_here = use_images;
+    if ((img->w & 1) == 1 || (img->h & 1) == 1)
+      use_images_here = FALSE;
+    if (use_images_here) {
 	ximbuf = (char *) xmalloc(img->w * img->h * 2 * sizeof(char));
     }
     for (r = 0; r < img->h; r++) {
@@ -680,7 +689,7 @@ tk_make_mask_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 		rp++;
 	    }
 	    pix = (rc ? blackcolor : whitecolor)->pixel;
-	    if (use_images) {
+	    if (use_images_here) {
 		ximbuf[(img->w * r + c) * 2 + 0] = pix & 0xff;
 		ximbuf[(img->w * r + c) * 2 + 1] = pix >> 8;
 	    } else {
@@ -692,7 +701,7 @@ tk_make_mask_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	    rp++;
 	}
     }
-    if (use_images) {
+    if (use_images_here) {
 	Visual *vis;
 
 	vis = Tk_Visual(rootwin);
