@@ -1,5 +1,5 @@
 /* Initialization for the tcl/tk interface to Xconq.
-   Copyright (C) 1998, 1999 Stanley T. Shebs.
+   Copyright (C) 1998-2000 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -62,8 +62,20 @@ int min_h_for_unit_image = 16;
 #endif
 #include "bitmaps/shootcurs.b"
 #include "bitmaps/shootmask.b"
+#include "bitmaps/attackcurs.b"
+#include "bitmaps/attackmask.b"
 #include "bitmaps/buildcurs.b"
 #include "bitmaps/buildmask.b"
+
+#include "bitmaps/scursup.b"
+#include "bitmaps/scursupm.b"
+#include "bitmaps/scursright.b"
+#include "bitmaps/scursrightm.b"
+#include "bitmaps/scursdown.b"
+#include "bitmaps/scursdownm.b"
+#include "bitmaps/scursleft.b"
+#include "bitmaps/scursleftm.b"
+
 #include "bitmaps/return.b"
 #include "bitmaps/sleep.b"
 #include "bitmaps/delay.b"
@@ -195,7 +207,7 @@ init_display(void)
 
     /* Set up things shared by all the windows. */
     dside->ui->dflt_color_embl_images = TRUE;
-    dside->ui->default_latlong_interval = 600;
+    dside->ui->default_meridian_interval = 600;
     for (p = 0; p < NUMPOWERS; ++p) {
 	for_all_terrain_types(t) {
 	    /* Decide what display technique to use at each power. */
@@ -236,6 +248,10 @@ init_display(void)
     update_view_controls_info();
     eval_tcl_cmd("update_show_all_info %d", dside->may_set_show_all);
     eval_tcl_cmd("set designer %d", is_designer(dside));
+    eval_tcl_cmd("set any_elev_variation %d", any_elev_variation);
+    eval_tcl_cmd("set any_temp_variation %d", any_temp_variation);
+    eval_tcl_cmd("set any_wind_variation %d", any_wind_variation);
+    eval_tcl_cmd("set any_clouds %d", any_clouds);
 
     /* Compute the position of each unit type in the list of unit types. */
     {
@@ -291,6 +307,7 @@ set_colors(void)
     dside->ui->badcolor = dside->ui->whitecolor;
     dside->ui->warncolor = dside->ui->whitecolor;
     dside->ui->goodcolor = dside->ui->whitecolor;
+    dside->ui->unit_name_color = dside->ui->whitecolor;
     dside->ui->grid_color = dside->ui->fgcolor;
     dside->ui->unseen_color = dside->ui->fgcolor;
     dside->ui->contour_color = dside->ui->fgcolor;
@@ -299,7 +316,6 @@ set_colors(void)
     dside->ui->frontline_color = dside->ui->fgcolor;
     dside->ui->meridian_color = dside->ui->fgcolor;
     dside->ui->shoreline_color = dside->ui->fgcolor;
-    dside->ui->unit_name_color = dside->ui->fgcolor;
     /* Set colors to distinctive default; will set usefully later. */
     for_all_terrain_types(t) {
 	dside->ui->cellcolor[t] = NULL;
@@ -403,17 +419,27 @@ init_cursors(void)
     dside->ui->cursors[move_mode] =
       make_cursor(rootwin, shootcursor_bits, shootmask_bits,
 		  shootcursor_x_hot, shootcursor_y_hot);
-#if 0
-    dside->ui->cursors[unitmovetool] =
-      make_cursor(rootwin, movecursor_bits, movemask_bits,
-		  movecursor_x_hot, movecursor_y_hot);
-#endif
+    dside->ui->cursors[attack_mode] =
+      make_cursor(rootwin, attackcurs_bits, attackmask_bits,
+		  attackcurs_x_hot, attackcurs_y_hot);
     dside->ui->cursors[fire_mode] =
       make_cursor(rootwin, shootcursor_bits, shootmask_bits,
 		  shootcursor_x_hot, shootcursor_y_hot);
     dside->ui->cursors[build_mode] =
       make_cursor(rootwin, buildcursor_bits, buildmask_bits,
 		  buildcursor_x_hot, buildcursor_y_hot);
+    dside->ui->cursors[scroll_up_mode] =
+      make_cursor(rootwin, scursup_bits, scursupm_bits,
+		  scursup_x_hot, scursup_y_hot);
+    dside->ui->cursors[scroll_right_mode] =
+      make_cursor(rootwin, scursright_bits, scursrightm_bits,
+		  scursright_x_hot, scursright_y_hot);
+    dside->ui->cursors[scroll_down_mode] =
+      make_cursor(rootwin, scursdown_bits, scursdownm_bits,
+		  scursdown_x_hot, scursdown_y_hot);
+    dside->ui->cursors[scroll_left_mode] =
+      make_cursor(rootwin, scursleft_bits, scursleftm_bits,
+		  scursleft_x_hot, scursleft_y_hot);
 #ifdef DESIGNERS
     dside->ui->cursors[cell_paint_mode] =
       make_cursor(rootwin, curscell_bits, curscellm_bits,
@@ -811,17 +837,6 @@ init_material_images(void)
 	for (p = 0; p < NUMPOWERS; ++p) {
 	    mimg = best_image(dside->ui->mimages[m], hws[p], hhs[p]);
 	    dside->ui->bestmimages[p][m] = mimg;
-#if 0
-	    if (mimg != NULL) {
-		tkimg = (TkImage *) timg->hook;
-		if (tkimg != NULL) {
-		    if (!dside->ui->monochrome && tkimg->colr != None)
-		      dside->ui->terrpics[p][t] = tkimg->colr;
-		    else
-		      dside->ui->terrpics[p][t] = tkimg->mono;
-		}
-	    }
-#endif
 	}
 	/* Look for a solid color. */
 	mimg = NULL;
