@@ -315,7 +315,7 @@ Side *side;
     side->ui->dflt_color_terr_images = TRUE;
     side->ui->dflt_color_unit_images = TRUE;
     side->ui->dflt_color_embl_images = TRUE;
-    side->ui->default_latlong_interval = 600;
+    side->ui->default_meridian_interval = 600;
     side->ui->bonw = BLACKONWHITE;
     depth = XDisplayCells(dpy, side->ui->screen);
     DGprintf("%d different colors available ...\n", depth);
